# Documentation of LLJ WFP archive
This archive documents the steps to reproduce the simulations in Larsén and Fischereit (2021).


## WPS steps
* The WPS-namelist is included as `namelist.wps`
* The geogrid files for the WRF simulations are located in `geogrid/`
* Tables for running metgrid, ungrib and REAL are located in `tables/`
* The required ERA5 data can be downloaded using `get_era5_check_first.py` and the modified Vtable for ERA5 data is included in `tables/`

## WRF simulations
Namelists and turbine-files to reproduce the simulations with EWP (`EWP_simulation/`), Fitch (`Fitch_simulation/`) and No wind farm simulation (`NWF_simulation/`) are included in the respective sub-directories.

## Mapping EWP and Fitch turbine files

| Fitch turbine       | EWP turbine     | Info                                                      |
| --------------------| ----------------| ----------------------------------------------------------|
| wind-turbine-1.tbl  | SWT-4.0-130     |                                                           |
| wind-turbine-2.tbl  | SWT-3.6-120     |                                                           |
| wind-turbine-3.tbl  | V80-2.0         |                                                           |
| wind-turbine-4.tbl  | SWT-2.3-93      |                                                           |
| wind-turbine-6.tbl  | M5000-116       |                                                           |
| wind-turbine-7.tbl  | SWT-6.0-154     | 106 m hub height                                          |
| wind-turbine-8.tbl  | SWT-4.0-120     |                                                           |
| wind-turbine-9.tbl  | 6.2M126_84      | All 6.2M126 models have identical thrust and power curves |
| wind-turbine-10.tbl | 6.2M126_95      | All 6.2M126 models have identical thrust and power curves |
| wind-turbine-16.tbl | 6.2M126_90      | All 6.2M126 models have identical thrust and power curves |
| wind-turbine-19.tbl | SWT-6.0-154_110 | same thrust and power curve as SWT-6.0-154                |
| wind-turbine-20.tbl | Senvion_5M      | same thrust and power curve as M5000-116                  |

The locations of the turbines are included in `EWP_simulation/all_farms_corr_2017_new_LLJ_corrected.real` and `Fitch_simulation/windturbines.txt`, respectively. 
The turbine characteristics have been extracted from https://www.wasp.dk/dataandtools#power-curves


## Fitch simulation with TKE advection bugfix
In addition to a simulation with TKE advection off (`Fitch_simulation/namelist.input.Fitch`), two additional simulations have been conducted with TKE advection on and including the bugfix for the bug reported in Archer et al. (2020) (`Fitch_simulation/namelist.input.Fitch_adv_on_ctke_1` and `Fitch_simulation/namelist.input.Fitch_adv_on_ctke_025`). They differ in the used value for CTKE, which is a new wrf-namelist variable introduced by Archer et al. (2020). To conduct the simulations, the WRF v3.7.1 source code was modified according to https://github.com/wrf-model/WRF/pull/1235 for those two simulations.

To include the bugfix the following steps have been performed:
1. git clone https://github.com/wrf-model/WRF.git
2. git checkout V3.7.1
3. git cherry-pick 962288fe (and resolve merge conflict for run/README.namelist)

For convienence the changed files are provided along the EWP source code in `modified_WRF/`

## Modified WRF v3.7.1
The code changes made to WRF 3.7.1 are included in the directory `modified_WRF/`. The structure in this directory is the same as in the normal WRF 3.7.1. To reproduce the simulations modified files have been added in the respective sub-directories.

To reproduce the simulations use
1. git clone https://github.com/wrf-model/WRF.git
2. git checkout V3.7.1
3. add the files below (files with `..._EWP_FITCH_bugfixed` contain EWP and Fitch bugfix, whereas files without that addition will provide the Fitch version including the bugfix)


For EWP in total 10 changes/additions are required:
* 3 new files: `phys/module_wf_ewp.F` (core EWP module), `README.EWP` (README for this version of EWP) and `Registry/Registry.turbine` (EWP-specific namelist options)
* In `phys/module_physics_init.F` EWP is initialised alongside wind_fitch
* In `phys/module_pbl_driver.F` is called alongside wind_fitch
* In `phys/Makefile` `module_wf_ewp.F` has been added for compilation
* In `dyn_em/module_first_rk_step_part1.F` `R0frac` has to be added to the argument list
* Registry modifications include `Registry/Registry.EM`, which needs to include `Registry.turbine` and `Registry/Registry.EM`, which sets `ewpscheme` as `windfarm_opt=2`
* In `main/depend.common` dependencies for `module_wf_ewp.F` are listed

For the TKE advection bugfix for the Fitch scheme:
* 5 files are changed in accordance with https://github.com/wrf-model/WRF/pull/1235 These are called `..._EWP_FITCH_bugfixed`

## PostProcessing of WRF outputs
In the directory post_processing are: a mathematica script and two sub-folders [Toshare_MATLAB_scripts] and [Toshare_MATLAB_data]. Once the WRF simulations are done, using this mathematica script, one can extract data needed for relevant analysis and for making the figures in the paper. The script shows what data are extracted, how they are extracted and saved.

Data that are prepared from the mathematica script are stored in the directory [Toshare_MATLAB_data]. The directory [Toshare_MATLAB_scripts] includes a number of matlab scripts which use the data from [Toshare_MATLAB_data] and plots figures.

To reproduce Figure 1 of the paper, use `process_sar_paper.py`

## References
Archer, C. L., Wu, S., and Ma, Y.: Two corrections for turbulent kinetic energy generated by wind farms in the WRF model, Monthly WeatherReview, DOI 10.1175/MWR-D-20-0097.1, 2020.

Larsén and Fischereit: A case study of wind farm effects using two wake parameterizations in WRF (V3.7) in the presence of low level jets., submitted to GMD, 2021
