(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    539040,      11689]
NotebookOptionsPosition[    525809,      11323]
NotebookOutlinePosition[    526156,      11338]
CellTagsIndexPosition[    526113,      11335]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Codes for preparing to plot the figures", "Text",
 CellChangeTimes->{{3.789797091402213*^9, 3.7897971031744423`*^9}, {
  3.8128763089684525`*^9, 3.812876325153076*^9}, {3.8128872806721416`*^9, 
  3.8128872853603244`*^9}, {3.8161513208983283`*^9, 3.8161513462122517`*^9}}],

Cell[CellGroupData[{

Cell["Functions", "Section",
 CellChangeTimes->{{3.787482251010126*^9, 3.787482254955355*^9}, {
  3.7880909454743395`*^9, 3.7880909640633664`*^9}, {3.788779526673837*^9, 
  3.788779528962552*^9}, {3.816151354016706*^9, 3.8161513553935566`*^9}}],

Cell["\<\
1. Find the position of the point/site of interest over the model grid:\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.816151548992342*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"findpos", "[", 
    RowBox[{"latin_", ",", "lonin_", ",", "latlon_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd", ",", "gp1", ",", "gp2"}], "}"}], ",", 
     RowBox[{
      RowBox[{"dd", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"latin", "-", 
            RowBox[{"latlon", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}]}], ")"}], 
          "^", "2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"lonin", "-", 
            RowBox[{"latlon", "[", 
             RowBox[{"[", 
              RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}]}], ")"}], 
          "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"gp1", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Position", "[", 
         RowBox[{"dd", ",", 
          RowBox[{"Min", "[", "dd", "]"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "gp1", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"latlon", "[", 
        RowBox[{"[", 
         RowBox[{
          RowBox[{"gp1", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"gp1", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"N", "[", "latin", "]"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"N", "[", "lonin", "]"}], "}"}]}], "]"}], ";", "gp1"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.431929480319173*^9, 3.431929623882592*^9}, {
  3.4385919407978373`*^9, 3.4385919487195096`*^9}}],

Cell["2. Calculate the direction", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.816151573042681*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ObtainDir", "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
        RowBox[{"270", "-", 
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
          RowBox[{"180", "/", "Pi"}]}]}], ",", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], ",", 
        RowBox[{"90", "-", 
         RowBox[{
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "/", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "*", 
          RowBox[{"180", "/", "Pi"}]}]}], ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ">", "0"}]}], ")"}], ",", "180", 
        ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], " ", "&&", " ", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "<", "0"}]}], ")"}], ",", "0"}], 
       "]"}], "&"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"u", ",", "v"}], "}"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4322803296540685`*^9, 3.4322803807946935`*^9}}],

Cell["\<\
3. Get the time series from the given position from the WRF output files, \
with input of the position, the WRF-file, wished data length and wished \
vertical level number\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.8161516548656297`*^9, 3.816151693175099*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getwrfts", "[", 
    RowBox[{"pos_", ",", "fil_", ",", "dLen_", ",", "verL_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "id", ",", "u", ",", "v", ",", "Qke", ",", "ws", ",", "dir", ",", "T"}],
       "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"id", "=", 
       RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"u", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"v", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"T", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Qke", "=", 
       RowBox[{"Flatten", "[", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"dLen", ",", "verL", ",", "1", ",", "1"}], "}"}]}], "]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ws", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"u", "^", "2"}], "+", 
         RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"dir", "=", 
       RowBox[{"ObtainDir", "[", 
        RowBox[{"u", ",", "v"}], "]"}]}], ";", 
      RowBox[{"{", 
       RowBox[{"ws", ",", "dir", ",", "T", ",", "Qke"}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.7886014426837015`*^9, 
   3.7886015328228106`*^9}, {3.788601865896428*^9, 3.7886018688855944`*^9}, {
   3.7886742652759285`*^9, 3.788674269599454*^9}, {3.789190998737625*^9, 
   3.78919101026676*^9}, 3.8161516169609995`*^9}],

Cell["\<\
4. Get 2D data (x-y) for one or more z-levels and one or more time stamps \
from the WRF output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.816151772730195*^9}, {3.816151807435397*^9, 
  3.8161518267697444`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfAREA1", "[", 
     RowBox[{"fil_", ",", "startz_", ",", "startt_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "id", ",", "u", ",", "v", ",", "zidx", ",", "ws", ",", "dir", ",", "T",
         ",", "sst", ",", "T2", ",", "qke"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"T", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"sst", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<SST\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "90", ",", "95"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"T2", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<T2\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "90", ",", "95"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"startt", ",", "startz", ",", "90", ",", "95"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "1", ",", "150", ",", "150"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"dir", "=", 
          RowBox[{"ObtainDir", "[", 
           RowBox[{"u", ",", "v"}], "]"}]}], ";"}], "*)"}], 
       RowBox[{"{", 
        RowBox[{"ws", ",", "T", ",", "sst", ",", "T2", ",", "qke"}], 
        "}"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.7898056049910245`*^9, 
   3.7898056490401936`*^9}, {3.790502325714153*^9, 3.790502354001898*^9}}],

Cell["\<\
5. Get a row of data for one or more z-levels and one time stamp from the WRF \
output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.8161518300820913`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfrow", "[", 
     RowBox[{"pos_", ",", "fil_", ",", "startz_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"id", ",", "u", ",", "v", ",", "ws", ",", "qke", ",", "lat"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6", ",", "5", ",", "30", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"lat", "=", 
        RowBox[{"latd03", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", 
           RowBox[{
            RowBox[{"pos", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ";;", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "+", "29"}]}], ",", 
           RowBox[{"pos", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ws", ",", "qke", ",", "lat"}], "}"}]}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.788692497122455*^9, 3.788692498656822*^9}, {
   3.7886925376409807`*^9, 3.7886925746154704`*^9}, {3.788692650780055*^9, 
   3.788692656906662*^9}, {3.7886927181696396`*^9, 3.7886927335383844`*^9}, {
   3.7886929139747543`*^9, 3.788692919884385*^9}, 3.7886930616160383`*^9, {
   3.788693139257899*^9, 3.7886931444536104`*^9}, {3.7886946726054535`*^9, 
   3.7886946970836563`*^9}, {3.7898159073342123`*^9, 
   3.7898160383490295`*^9}, {3.789816135301789*^9, 3.789816136288871*^9}, {
   3.789885704498333*^9, 3.789885710923794*^9}}],

Cell["\<\
6. Get a transect of data for one or more z-levels and one time stamp from \
the WRF output file\
\>", "Text",
 CellChangeTimes->{{3.8161515198992233`*^9, 3.8161516137395134`*^9}, {
  3.81615169947922*^9, 3.816151888717077*^9}, {3.816151931023254*^9, 
  3.816151948633963*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{"pos_", ",", "fil_", ",", "startz_", ",", "nLa_", ",", "nT_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"id", ",", "u", ",", "v", ",", "ws", ",", "qke"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"id", "=", 
        RowBox[{"NCOpen", "[", "fil", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"u", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<U\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"v", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<V\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"qke", "=", 
        RowBox[{"NCGetVarA", "[", 
         RowBox[{"id", ",", "\"\<QKE\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"nT", "-", "1"}], ",", "startz", ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "39", ",", "nLa", ",", "1"}], "}"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ws", "=", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"u", "^", "2"}], "+", 
          RowBox[{"v", "^", "2"}]}], "]"}]}], ";", 
       RowBox[{"{", 
        RowBox[{"ws", ",", "qke"}], "}"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.469429044322689*^9, 3.4694291179802036`*^9}, {
   3.4869715972641225`*^9, 3.4869717503568926`*^9}, {3.486972297337767*^9, 
   3.4869723347281528`*^9}, {3.487057012653102*^9, 3.487057025246772*^9}, {
   3.4870578396321845`*^9, 3.4870578571789474`*^9}, 3.6412891148981733`*^9, {
   3.6412892982501736`*^9, 3.641289416210794*^9}, {3.641290260574444*^9, 
   3.6412902843901587`*^9}, {3.641293236787573*^9, 3.641293257287573*^9}, {
   3.641293409799573*^9, 3.6412934800275726`*^9}, {3.6616815228218594`*^9, 
   3.661681546406329*^9}, {3.6623568106483173`*^9, 3.6623568119553614`*^9}, {
   3.6623569125667667`*^9, 3.6623569309653883`*^9}, {3.7874883345290823`*^9, 
   3.787488514762437*^9}, {3.787489563981533*^9, 3.787489849687229*^9}, {
   3.787489906845042*^9, 3.787489941557982*^9}, {3.787489974896849*^9, 
   3.78749000170476*^9}, {3.7874900376943903`*^9, 3.787490061628025*^9}, {
   3.787545874497195*^9, 3.7875459179982543`*^9}, {3.7880708098894434`*^9, 
   3.788070810366099*^9}, {3.7880708641500373`*^9, 3.7880708749959755`*^9}, {
   3.7880776670851755`*^9, 3.788077671147296*^9}, {3.788077815858596*^9, 
   3.7880778183836346`*^9}, {3.7880916085465174`*^9, 3.788091678702027*^9}, {
   3.788091947604705*^9, 3.788091950927874*^9}, {3.7881631340765915`*^9, 
   3.7881631532332387`*^9}, {3.788164733619755*^9, 3.7881647833993673`*^9}, {
   3.7881648162083955`*^9, 3.788164831007166*^9}, {3.7886739458765717`*^9, 
   3.7886740147401237`*^9}, {3.7886740964525337`*^9, 
   3.7886742180606556`*^9}, {3.7886742827436447`*^9, 
   3.7886743038508434`*^9}, {3.788692497122455*^9, 3.788692498656822*^9}, {
   3.7886925376409807`*^9, 3.7886925746154704`*^9}, {3.788692650780055*^9, 
   3.788692656906662*^9}, {3.7886927181696396`*^9, 3.7886927335383844`*^9}, {
   3.7886929139747543`*^9, 3.788692919884385*^9}, 3.7886930616160383`*^9, {
   3.788693139257899*^9, 3.7886931444536104`*^9}, {3.7886946726054535`*^9, 
   3.7886946970836563`*^9}, {3.788698072256164*^9, 3.7886980757957983`*^9}, {
   3.788698117320114*^9, 3.788698130106768*^9}, {3.790423995331352*^9, 
   3.7904240173696747`*^9}, {3.7904245500353355`*^9, 3.790424568664999*^9}, {
   3.7904902252951813`*^9, 3.790490250107786*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fetch the relevant data ", "Section",
 CellChangeTimes->{{3.8169226115569353`*^9, 3.8169226182678227`*^9}, 
   3.8169228523021884`*^9}],

Cell[CellGroupData[{

Cell["\<\
1. Relevant data are extracted from the WRF output files (which are of huge \
size) and saved, which will be used in MATLAB scripts for making the plots \
for the paper\
\>", "Subsection",
 CellChangeTimes->{{3.788163918661662*^9, 3.788163931491914*^9}, {
  3.7881639716451907`*^9, 3.7881639777880516`*^9}, {3.789189898143958*^9, 
  3.7891899178443146`*^9}, {3.789301153246876*^9, 3.7893011536225786`*^9}, {
  3.7897970722829833`*^9, 3.7897970754730883`*^9}, {3.790338399121682*^9, 
  3.790338405441382*^9}, {3.8135744508878717`*^9, 3.8135744566540775`*^9}, {
  3.8169236017760177`*^9, 3.8169236816555943`*^9}, {3.816923719682855*^9, 
  3.8169237201915035`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<F:/OFFSHOREWAKE/LLJ/\>\"", "]"}], ";", 
  RowBox[{"(*", 
   RowBox[{
   "THIS", " ", "IS", " ", "THE", " ", "DIRECTORY", " ", "WHERE", " ", "YOU", 
    " ", "HAVE", " ", "YOUR", " ", "WRF", " ", "OUTPUTS"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.787485621916165*^9, 3.7874856530469522`*^9}, {
   3.788090985513077*^9, 3.788091014475787*^9}, 3.7880910468156767`*^9, {
   3.788164107476652*^9, 3.7881641349431367`*^9}, {3.788600705558346*^9, 
   3.7886007056720085`*^9}, {3.7891899221637697`*^9, 3.789189923228917*^9}, {
   3.7893011589092956`*^9, 3.789301159370511*^9}, {3.790338622745055*^9, 
   3.7903386452483025`*^9}, {3.8135744865647793`*^9, 
   3.8135745065520997`*^9}, {3.813574577004174*^9, 3.813574582809127*^9}, {
   3.81580862877312*^9, 3.8158086291512046`*^9}, {3.815808717797425*^9, 
   3.815808734044216*^9}, {3.8158090708142705`*^9, 3.8158090761857433`*^9}, {
   3.81692324933827*^9, 3.8169232748970385`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", "\"\<wrfinput*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.78748628641158*^9, 3.787486289535822*^9}, {
  3.788091051257616*^9, 3.7880910585262365`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"wrfinput_d01\"\>", ",", "\<\"wrfinput_d02\"\>", 
   ",", "\<\"wrfinput_d03\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.787486290259783*^9, 3.788091058888834*^9, 
  3.788162039033719*^9, 3.7881641375737686`*^9, 3.7886007195813303`*^9, 
  3.788666342038563*^9, 3.789189925469874*^9, 3.7893011763945246`*^9, 
  3.789725218142014*^9, 3.790338647084059*^9, 3.790501157163348*^9, 
  3.8063051283311567`*^9, 3.812876348906002*^9, 3.8130475682309647`*^9, 
  3.8135747848169456`*^9, 3.8158087364991465`*^9, 3.8158090784443574`*^9, 
  3.8158093625251756`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"latd03", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<wrfinput_d03\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Datasets\>\"", ",", "\"\<XLAT\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.727761284390641*^9, 3.7277613059998016`*^9}, 
   3.751859817894703*^9, {3.7874857105254774`*^9, 3.7874858157885103`*^9}, {
   3.788091144979847*^9, 3.788091161919414*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lond03", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<wrfinput_d03\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Datasets\>\"", ",", "\"\<XLONG\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091175163989*^9, 3.7880911807073693`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HGTd03", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<wrfinput_d03\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Datasets\>\"", ",", "\"\<HGT\>\""}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788162225205003*^9, 3.788162230351393*^9}, {
  3.7881622658781567`*^9, 3.7881622683280544`*^9}, {3.788162405143283*^9, 
  3.788162410037403*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.789805710103634*^9, 3.7898057101504865`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xlatlongd03", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"latd03", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i", ",", "j"}], "]"}], "]"}], ",", 
       RowBox[{"lond03", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "i", ",", "j"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "300"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "300"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.438591350086874*^9, 3.4385914277599835`*^9}, {
  3.463471465095724*^9, 3.463471485282191*^9}, {3.4685789779027405`*^9, 
  3.468578980641263*^9}, {3.474964934386197*^9, 3.474964935823596*^9}, {
  3.4761781992397346`*^9, 3.4761782145362177`*^9}, {3.4761782544726954`*^9, 
  3.476178262613112*^9}, {3.486966161752035*^9, 3.486966171392598*^9}, {
  3.7518598448529286`*^9, 3.751859852612842*^9}, {3.7874862048472004`*^9, 
  3.787486222061079*^9}, {3.788091238829426*^9, 3.788091273846731*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FINO1pos", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"54.014", ",", "6.588", ",", "xlatlongd03"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"For", " ", "profile"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7874882053725214`*^9, 3.787488289123462*^9}, {
  3.788091432834153*^9, 3.7880914405155773`*^9}, {3.78809153779632*^9, 
  3.788091550913003*^9}, {3.7881693509177475`*^9, 3.7881693515028715`*^9}, {
  3.788601600541546*^9, 3.7886016130538993`*^9}, {3.788602146873712*^9, 
  3.7886021574134626`*^9}, {3.788602224710693*^9, 3.788602230057116*^9}, {
  3.7886678761851096`*^9, 3.7886678853755817`*^9}, {3.7886679948784237`*^9, 
  3.788667998790357*^9}, {3.7898157785803947`*^9, 3.7898157831077375`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"144", ",", "154"}], "}"}]], "Print",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705949583*^9, 
  3.7898153438728905`*^9, 3.790339105360832*^9, 3.790505182921477*^9, 
  3.806305143444745*^9, 3.8069834871608562`*^9, 3.8075914241139183`*^9, 
  3.8128763910190578`*^9, 3.8130475818663387`*^9, 3.813565775254693*^9, 
  3.8135748049191976`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"54.00916290283203`", ",", "6.5950927734375`"}], "}"}]], "Print",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705949583*^9, 
  3.7898153438728905`*^9, 3.790339105360832*^9, 3.790505182921477*^9, 
  3.806305143444745*^9, 3.8069834871608562`*^9, 3.8075914241139183`*^9, 
  3.8128763910190578`*^9, 3.8130475818663387`*^9, 3.813565775254693*^9, 
  3.8135748049231863`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "54.014`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "6.588`", "}"}]}],
  SequenceForm[{54.014}, {6.588}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705949583*^9, 
  3.7898153438728905`*^9, 3.790339105360832*^9, 3.790505182921477*^9, 
  3.806305143444745*^9, 3.8069834871608562`*^9, 3.8075914241139183`*^9, 
  3.8128763910190578`*^9, 3.8130475818663387`*^9, 3.813565775254693*^9, 
  3.813574804926178*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"144", ",", "154"}], "}"}]], "Output",
 CellChangeTimes->{3.7886680003400264`*^9, 3.789190705956563*^9, 
  3.789815343889019*^9, 3.79033910537649*^9, 3.7905051829294124`*^9, 
  3.8063051434527583`*^9, 3.8069834871708307`*^9, 3.807591424124873*^9, 
  3.8128763910300875`*^9, 3.8130475818663387`*^9, 3.813565775261674*^9, 
  3.813574804930169*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8075915308143263`*^9, 3.807591536843319*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P2", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"54.0676", ",", "7.02", ",", "xlatlongd03"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.807591527126793*^9, 3.807591533694563*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"147", ",", "168"}], "}"}]], "Print",
 CellChangeTimes->{3.8075915380820456`*^9, 3.8128763925343895`*^9, 
  3.81304758460814*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"54.067630767822266`", ",", "7.023895263671875`"}], "}"}]], "Print",
 CellChangeTimes->{3.8075915380820456`*^9, 3.8128763925343895`*^9, 
  3.8130475846111326`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "54.0676`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "7.02`", "}"}]}],
  SequenceForm[{54.0676}, {7.02}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8075915380820456`*^9, 3.8128763925343895`*^9, 
  3.813047584614126*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"147", ",", "168"}], "}"}]], "Output",
 CellChangeTimes->{3.807591538095969*^9, 3.8128763925453606`*^9, 
  3.8130475846181135`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pos1", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"53.85", ",", "7.02", ",", "xlatlongd03"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "For", " ", "the", " ", "row", " ", "to", " ", "the", " ", "right"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7886926216680627`*^9, 3.7886926378725204`*^9}, {
  3.789815791206093*^9, 3.78981579535979*^9}, {3.78983453875928*^9, 
  3.7898345410110435`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "168"}], "}"}]], "Print",
 CellChangeTimes->{{3.788692623887805*^9, 3.7886926385892076`*^9}, 
   3.788692706622134*^9, 3.7886929848919525`*^9, 3.789190003688696*^9, 
   3.7898155979652023`*^9, 3.806983654042763*^9, 3.8075917028551493`*^9, 
   3.809423267494117*^9, 3.812876394962427*^9, 3.8130475867675023`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"53.85099411010742`", ",", "7.029022216796875`"}], "}"}]], "Print",
 CellChangeTimes->{{3.788692623887805*^9, 3.7886926385892076`*^9}, 
   3.788692706622134*^9, 3.7886929848919525`*^9, 3.789190003688696*^9, 
   3.7898155979652023`*^9, 3.806983654042763*^9, 3.8075917028551493`*^9, 
   3.809423267494117*^9, 3.812876394962427*^9, 3.8130475867675023`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "53.85`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "7.02`", "}"}]}],
  SequenceForm[{53.85}, {7.02}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.788692623887805*^9, 3.7886926385892076`*^9}, 
   3.788692706622134*^9, 3.7886929848919525`*^9, 3.789190003688696*^9, 
   3.7898155979652023`*^9, 3.806983654042763*^9, 3.8075917028551493`*^9, 
   3.809423267494117*^9, 3.812876394962427*^9, 3.8130475867675023`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "168"}], "}"}]], "Output",
 CellChangeTimes->{{3.788692623925606*^9, 3.7886926386048293`*^9}, 
   3.788692706637756*^9, 3.7886929849075737`*^9, 3.789190003695677*^9, 
   3.7898155979773655`*^9, 3.806983654051739*^9, 3.807591702870111*^9, 
   3.809423267506048*^9, 3.8128763949733973`*^9, 3.8130475867831235`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pos1", "=", 
   RowBox[{"{", 
    RowBox[{"135", ",", "168"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.815809299784129*^9, 3.8158093065088987`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pos2", "=", 
  RowBox[{"findpos", "[", 
   RowBox[{"53.85", ",", "7.0", ",", "xlatlongd03"}], "]"}], 
  RowBox[{"(*", 
   RowBox[{
   "For", " ", "the", " ", "row", " ", "to", " ", "the", " ", "left"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.7886926216680627`*^9, 3.7886926378725204`*^9}, {
  3.7886960865741806`*^9, 3.7886960942504654`*^9}, {3.7898157973334923`*^9, 
  3.7898158017008862`*^9}, {3.7898345339642544`*^9, 3.7898345362157593`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "167"}], "}"}]], "Print",
 CellChangeTimes->{3.788696094666705*^9, 3.7891900047169447`*^9, 
  3.789815599642437*^9, 3.806983655152795*^9, 3.8075917036170073`*^9, 
  3.8128763959999943`*^9, 3.813047587470873*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"53.85074234008789`", ",", "6.9984130859375`"}], "}"}]], "Print",
 CellChangeTimes->{3.788696094666705*^9, 3.7891900047169447`*^9, 
  3.789815599642437*^9, 3.806983655152795*^9, 3.8075917036170073`*^9, 
  3.8128763959999943`*^9, 3.813047587470873*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"{", "53.85`", "}"}], "\[InvisibleSpace]", 
   RowBox[{"{", "7.`", "}"}]}],
  SequenceForm[{53.85}, {7.}],
  Editable->False]], "Print",
 CellChangeTimes->{3.788696094666705*^9, 3.7891900047169447`*^9, 
  3.789815599642437*^9, 3.806983655152795*^9, 3.8075917036170073`*^9, 
  3.8128763959999943`*^9, 3.813047587486539*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"135", ",", "167"}], "}"}]], "Output",
 CellChangeTimes->{3.7886960946823254`*^9, 3.789190004724923*^9, 
  3.7898155996580715`*^9, 3.8069836551647644`*^9, 3.8075917036290092`*^9, 
  3.812876396009966*^9, 3.813047587486539*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"link", "=", 
  RowBox[{"Install", "[", "\"\<NetCDF.exe\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4761779532304077`*^9, 3.476177962073931*^9}, 
   3.4761780970548506`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["LinkObject",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{12., {0., 12.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 
             3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              StyleBox[
               
               PaneBox["\<\"\\\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\10.0\\\\AddOns\\\\Applications\\\\NetCDF.exe\\\"\"\
\>",
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0,
                ImageSize->{{1, 300}, Automatic},
                ScrollPosition->{0., 0.},
                StripOnInput->True],
               LineBreakWithin->False],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 
             3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              
              PaneBox["\<\"\\\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\10.0\\\\AddOns\\\\Applications\\\\NetCDF.exe\\\"\"\
\>",
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0,
               ImageSize->{{1, 500}, Automatic},
               StripOnInput->True],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link protocol: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"SharedMemory\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  LinkObject[
  "\"C:\\Program Files\\Wolfram \
Research\\Mathematica\\10.0\\AddOns\\Applications\\NetCDF.exe\"", 26315, 11],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.476178097507964*^9, 3.4761783124868355`*^9, 3.486964973947137*^9, 
   3.4869662234391403`*^9, 3.4870428749299607`*^9, 3.487042981929276*^9, 
   3.4870639511555705`*^9, 3.4874811255072365`*^9, 3.4874814456125145`*^9, 
   3.4874834798833504`*^9, 3.487484279138745*^9, 3.487487224460419*^9, 
   3.4874887330817337`*^9, 3.487489675725918*^9, 3.4874918982912183`*^9, 
   3.4874948024279737`*^9, 3.4875623853000603`*^9, 3.487563697173893*^9, 
   3.48756661337094*^9, 3.4875751539334946`*^9, 3.4875786880132575`*^9, 
   3.487579120460847*^9, 3.4875805498019266`*^9, 3.487581426446955*^9, 
   3.487583204377322*^9, 3.4875836764650297`*^9, 3.4876480103301487`*^9, 
   3.487661762649942*^9, 3.4891200181553793`*^9, 3.4918978371347637`*^9, 
   3.5051269957484736`*^9, 3.513326887232905*^9, 3.518405708390625*^9, 
   3.5320803054415903`*^9, 3.535267652168561*^9, 3.536311947611122*^9, 
   3.5377834467706823`*^9, 3.5502075533734202`*^9, 3.5902076858457727`*^9, 
   3.5902077266291046`*^9, 3.6412891008581734`*^9, 3.6412896844831624`*^9, 
   3.6412921056238136`*^9, 3.642405138429744*^9, 3.6615904642509823`*^9, 
   3.6615918924914427`*^9, 3.6615919600403476`*^9, 3.66159200734477*^9, 
   3.661667458257818*^9, 3.6616805360916276`*^9, 3.6616815734699345`*^9, 
   3.6623568724994116`*^9, 3.6623569378376217`*^9, 3.6635862303901606`*^9, 
   3.787487902082675*^9, 3.78754582104467*^9, 3.7880709073960495`*^9, 
   3.7880798758101916`*^9, 3.7880919051406827`*^9, 3.7881631564223595`*^9, 
   3.7881631951691647`*^9, 3.7881633041538615`*^9, 3.7881643573169193`*^9, 
   3.7886017176771517`*^9, 3.7886664129278393`*^9, 3.7886732254457097`*^9, 
   3.78869297153722*^9, 3.7891899881322975`*^9, 3.7891901483075686`*^9, 
   3.78919185012755*^9, 3.7893012269686947`*^9, 3.789301278516947*^9, 
   3.789470475457145*^9, 3.789813737230014*^9, 3.7898751914038987`*^9, 
   3.7899035591074467`*^9, 3.7903387924621534`*^9, 3.790501696695236*^9, 
   3.7906718795239573`*^9, 3.790672935793503*^9, 3.806983494183407*^9, 
   3.813568167516866*^9, 3.8135750332967944`*^9, 3.8158087504984107`*^9, 
   3.8158090867384133`*^9, 3.8158093994434443`*^9, 3.8243488023970795`*^9, {
   3.8243548325938406`*^9, 3.824354861567325*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415A", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_old_off_rep/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.813574947430013*^9, 3.813574986868154*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414A", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_old_off_rep/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.813574947430013*^9, 3.813574986868154*^9}, {
  3.815809143738614*^9, 3.8158091509505634`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewparea1415A", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_ewp_off_rep/wrfout_d03_20171014_150000.nc\>\"", ",", "24", 
     ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.821360926782358*^9, 3.8213609382442875`*^9}, 
   3.824355393355937*^9}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.824355013325262*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
   "SetDirectory", "[", "\"\<Z:/AirSea/xiaoli/LLJS_2017101406\>\"", "]"}], 
   ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Sophia", " ", "/", "groups"}], "/"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.824354779472623*^9, 3.824354803225875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415B", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.8128816202013288`*^9, 3.8128816258601503`*^9}, {
  3.8135749916642246`*^9, 3.8135750141159554`*^9}, {3.8243487103084984`*^9, 
  3.8243487263191514`*^9}, {3.824354824652746*^9, 3.8243548256760387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415C", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", "24",
      ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135750231318417`*^9, 3.813575028201887*^9}, {
  3.824348729696335*^9, 3.824348735912963*^9}, {3.824354875482583*^9, 
  3.824354876909387*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415D", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",",
      "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243487795320663`*^9, 3.8243487928050413`*^9}, {
  3.8243548841119213`*^9, 3.82435488506579*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.824348798682027*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414B", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.8128816202013288`*^9, 3.8128816258601503`*^9}, {
  3.8135749916642246`*^9, 3.8135750141159554`*^9}, {3.815809146104535*^9, 
  3.8158091533651614`*^9}, {3.8243549212268486`*^9, 3.824354939801179*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414C", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",", "24",
      ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135750231318417`*^9, 3.813575028201887*^9}, {
  3.8158091480122805`*^9, 3.81580915578129*^9}, {3.8243549468363423`*^9, 
  3.824354949353675*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414D", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",",
      "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243549563065186`*^9, 3.82435496871533*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.8243549705934563`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewparea1415C", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", "24", 
     ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.821360926782358*^9, 3.8213609382442875`*^9}, {
  3.824355264706197*^9, 3.824355316646578*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewparea1415D", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_ewp_off_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.821360926782358*^9, 3.8213609382442875`*^9}, {
  3.824355264706197*^9, 3.8243552776169214`*^9}, {3.8243553580290995`*^9, 
  3.824355358789485*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.824355370981436*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415B", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.8128816202013288`*^9, 3.8128816258601503`*^9}, {
  3.8135749916642246`*^9, 3.8135750141159554`*^9}, {3.8243487103084984`*^9, 
  3.8243487263191514`*^9}, {3.824354824652746*^9, 3.8243548256760387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415C", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", "24",
      ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135750231318417`*^9, 3.813575028201887*^9}, {
  3.824348729696335*^9, 3.824348735912963*^9}, {3.824354875482583*^9, 
  3.824354876909387*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1415D", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",",
      "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243487795320663`*^9, 3.8243487928050413`*^9}, {
  3.8243548841119213`*^9, 3.82435488506579*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.824348798682027*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414B", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886744348319855`*^9, 3.788674456440688*^9}, {
  3.7891900455248156`*^9, 3.7891900487422476`*^9}, {3.7891926354625597`*^9, 
  3.7891926594035196`*^9}, {3.7891933111264524`*^9, 3.789193343869792*^9}, {
  3.7891935186339207`*^9, 3.789193518778531*^9}, {3.789301263359474*^9, 
  3.7893012637491345`*^9}, {3.7905017146564007`*^9, 3.7905017447936497`*^9}, {
  3.790501835090846*^9, 3.7905018352521453`*^9}, {3.790502412280261*^9, 
  3.790502416640252*^9}, {3.8128816202013288`*^9, 3.8128816258601503`*^9}, {
  3.8135749916642246`*^9, 3.8135750141159554`*^9}, {3.815809146104535*^9, 
  3.8158091533651614`*^9}, {3.8243549212268486`*^9, 3.824354939801179*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414C", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",", "24",
      ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135750231318417`*^9, 3.813575028201887*^9}, {
  3.8158091480122805`*^9, 3.81580915578129*^9}, {3.8243549468363423`*^9, 
  3.824354949353675*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea1414D", "=", 
   RowBox[{"getwrfAREA1", "[", 
    RowBox[{
    "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",",
      "24", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243549563065186`*^9, 3.82435496871533*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.8243549705934563`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea141710mB", "=", 
   RowBox[{"getwrfU10V10AREA", "[", 
    RowBox[{
    "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", ",", 
     "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.824355816463727*^9, 3.8243558291272674`*^9}, {
  3.824356088706305*^9, 3.8243560928052845`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea141710mC", "=", 
   RowBox[{"getwrfU10V10AREA", "[", 
    RowBox[{
    "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", ",", 
     "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243558389961023`*^9, 3.8243558438325386`*^9}, {
  3.8243560953349366`*^9, 3.824356102214007*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitcharea141710mD", "=", 
   RowBox[{"getwrfU10V10AREA", "[", 
    RowBox[{
    "\"\<results_ewp_off_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", ",", 
     "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.824355848256708*^9, 3.8243558602325826`*^9}, {
  3.82435609780824*^9, 3.8243561050194626`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewparea141710mC", "=", 
   RowBox[{"getwrfU10V10AREA", "[", 
    RowBox[{
    "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", ",", "1"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.821360926782358*^9, 3.8213609382442875`*^9}, {
  3.824355264706197*^9, 3.824355316646578*^9}, {3.824355716469863*^9, 
  3.8243557822120514`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewparea141710mD", "=", 
   RowBox[{"getwrfU10V10AREA", "[", 
    RowBox[{
    "\"\<results_ewp_off_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", ",", 
     "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.821360926782358*^9, 3.8213609382442875`*^9}, {
  3.824355264706197*^9, 3.8243552776169214`*^9}, {3.8243553580290995`*^9, 
  3.824355358789485*^9}, {3.824355724719428*^9, 3.824355786450815*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nwfarea141710mC", "=", 
   RowBox[{"getwrfU10V10AREA", "[", 
    RowBox[{
    "\"\<results_no_farm_tke_on_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", 
     ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243560296372137`*^9, 3.8243560640154653`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nwfarea141710mD", "=", 
   RowBox[{"getwrfU10V10AREA", "[", 
    RowBox[{
    "\"\<results_no_farm_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", ",", 
     "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243560521408424`*^9, 3.8243560525556793`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/fitch_ws_10m_1710_adv_off.dat\>\"", ",", 
    RowBox[{"fitcharea141710mD", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/fitch_ws_10m_1710_adv1.dat\>\"", ",", 
    RowBox[{"fitcharea141710mB", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/fitch_ws_10m_1710_adv025.dat\>\"", ",", 
    RowBox[{"fitcharea141710mC", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ewp_ws_10m_1710_adv1.dat\>\"", ",", 
    RowBox[{"ewparea141710mC", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ewp_ws_10m_1710_adv_off.dat\>\"", ",", 
    RowBox[{"ewparea141710mD", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/nofarms_ws_10m_1710_adv1.dat\>\"", ",", 
    RowBox[{"nwfarea141710mC", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/nofarms_ws_10m_1710_adv_off.dat\>\"", ",", 
    RowBox[{"nwfarea141710mD", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7905013656361103`*^9, 3.7905014442929783`*^9}, {
  3.8128837854034815`*^9, 3.8128838189552054`*^9}, {3.823702516772688*^9, 
  3.8237025968343973`*^9}, {3.823743026035784*^9, 3.8237430742539434`*^9}, {
  3.823743183729618*^9, 3.823743185005179*^9}, {3.823743324327567*^9, 
  3.823743340606435*^9}, {3.823743750976739*^9, 3.8237437591202087`*^9}, {
  3.8243565810598807`*^9, 3.8243566603214655`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<c:/testdata/fitch_ws10m_1710_adv1.dat\>\"", ",", 
   RowBox[{
    RowBox[{"fitcharea1417Cat10m", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.823701712902659*^9, 3.823701736256991*^9}}],

Cell[BoxData["\<\"c:/testdata/fitch_ws10m_1710_adv1.dat\"\>"], "Output",
 CellChangeTimes->{3.8237017688404913`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_Fitch_1530_adv025.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{
      RowBox[{"fitcharea1415B", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775050472994`*^9}, {3.813577603276939*^9, 
  3.813577605571189*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_Fitch_1530_adv100.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{
      RowBox[{"fitcharea1415C", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775106915092`*^9}, {3.8135776081008635`*^9, 
  3.813577609764115*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_Fitch_1530_adv000.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{
      RowBox[{"fitcharea1415D", "[", 
       RowBox[{"[", "5", "]"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{3.8243591853275223`*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7905025435950336`*^9, 3.7905025452445736`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS250m_Fitch_1530_adv025.dat\>\"", ",", 
    RowBox[{
     RowBox[{"fitcharea1415B", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775050472994`*^9}, {3.813577603276939*^9, 
  3.813577605571189*^9}, {3.821356802696929*^9, 3.821356823602883*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS250m_Fitch_1530_adv100.dat\>\"", ",", 
    RowBox[{
     RowBox[{"fitcharea1415C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775106915092`*^9}, {3.8135776081008635`*^9, 
  3.813577609764115*^9}, {3.821356806178275*^9, 3.8213568261561966`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS250m_Fitch_1530_adv000.dat\>\"", ",", 
    RowBox[{
     RowBox[{"fitcharea1415D", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.790502565913134*^9, 3.7905026143340483`*^9}, {
  3.813577464857074*^9, 3.8135775023289895`*^9}, {3.821356792432789*^9, 
  3.821356820438294*^9}, {3.824359200750999*^9, 3.8243592011539464`*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.824359217436756*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE250m_EWP_1530_adv100.dat\>\"", ",", 
    RowBox[{
     RowBox[{"ewparea1415C", "[", 
      RowBox[{"[", "5", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8213609757075295`*^9, 3.821360985466715*^9}, {
  3.8243592073684225`*^9, 3.824359253422658*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE250m_EWP_1530_adv000.dat\>\"", ",", 
    RowBox[{
     RowBox[{"ewparea1415D", "[", 
      RowBox[{"[", "5", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8243592252822037`*^9, 3.824359255972561*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS250m_EWP_1530_adv100.dat\>\"", ",", 
    RowBox[{
     RowBox[{"ewparea1415C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8213609757075295`*^9, 3.821360985466715*^9}, {
  3.8243592073684225`*^9, 3.824359214471944*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS250m_EWP_1530_adv000.dat\>\"", ",", 
    RowBox[{
     RowBox[{"ewparea1415D", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8243592252822037`*^9, 3.8243592308555737`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PL1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"140", "-", "5"}], ",", "168"}], "}"}]}], ";", 
  RowBox[{"PL2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"144", "-", "5"}], ",", "174"}], "}"}]}], ";", 
  RowBox[{"PL3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"148", "-", "5"}], ",", "180"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7904240398813066`*^9, 3.790424070387413*^9}, {
  3.7904242273466377`*^9, 3.790424246035637*^9}, {3.7904249630882735`*^9, 
  3.7904249917825966`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredEWPC", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL1", ",", "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_150000.nc\>\"",
       ",", "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775919690084`*^9}, {3.824360929305004*^9, 3.824360933251979*^9}, {
   3.8243609878596787`*^9, 3.8243609883978996`*^9}, {3.824361319832543*^9, 
   3.824361336731988*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchB", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL1", ",", 
      "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775919690084`*^9}, {3.824360929305004*^9, 3.824360933251979*^9}, {
   3.8243609878596787`*^9, 3.8243609883978996`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchC", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL1", ",", 
      "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775977124696`*^9}, {3.8243609365233583`*^9, 3.824360940532735*^9}, {
   3.824360994087829*^9, 3.824360994626082*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LredFitchD", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL1", ",", 
      "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", 
      ",", "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.813577561496483*^9}, {3.824360905934886*^9, 3.824360924242814*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LblueEWPC", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL2", ",", "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_150000.nc\>\"",
       ",", "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775919690084`*^9}, {3.824360929305004*^9, 3.824360933251979*^9}, {
   3.8243609878596787`*^9, 3.8243609883978996`*^9}, {3.824361319832543*^9, 
   3.824361336731988*^9}, {3.824361472127869*^9, 3.82436148914643*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LblueFitchB", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL2", ",", 
      "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775919690084`*^9}, {3.824360929305004*^9, 3.824360933251979*^9}, {
   3.8243609878596787`*^9, 3.8243609883978996`*^9}, {3.8243614762048745`*^9, 
   3.8243614914145746`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LblueFitchC", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL2", ",", 
      "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
      "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.8135775977124696`*^9}, {3.8243609365233583`*^9, 3.824360940532735*^9}, {
   3.824360994087829*^9, 3.824360994626082*^9}, {3.8243614806789856`*^9, 
   3.8243614939221554`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"NLA", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LblueFitchD", "=", 
   RowBox[{
    RowBox[{"getwrfTRANSECT1", "[", 
     RowBox[{
     "PL2", ",", 
      "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", 
      ",", "1", ",", "NLA", ",", "3"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1", ",", "All", ",", "All", ",", "1"}], "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7904240242167797`*^9, 3.7904240273872757`*^9}, {
   3.7904242494825487`*^9, 3.7904243288817663`*^9}, {3.7904245741929584`*^9, 
   3.7904245991718507`*^9}, {3.7904249951050873`*^9, 
   3.7904250017837486`*^9}, {3.7904251894932585`*^9, 3.790425191414386*^9}, 
   3.7904254224114*^9, {3.7904901676171675`*^9, 3.7904901677174115`*^9}, {
   3.790490257094805*^9, 3.7904902593690643`*^9}, {3.813577541904599*^9, 
   3.813577561496483*^9}, {3.824360905934886*^9, 3.824360924242814*^9}, {
   3.8243614847353663`*^9, 3.824361496384307*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X1", "=", 
   RowBox[{
    RowBox[{"xlatlongd03", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"PL1", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ";;", 
        RowBox[{
         RowBox[{"PL1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "NLA", "-", "1"}]}], ",", 
       RowBox[{"PL1", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y1", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"z", ",", "39"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Z1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"X1", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"Y1", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "X1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"Length", "[", "Y1", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7904244359100437`*^9, 3.79042454348353*^9}, {
  3.790424586903467*^9, 3.7904246151183257`*^9}, {3.7904249193160133`*^9, 
  3.7904249288616333`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_WS_adv000.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchD", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_WS_adv025.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchB", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_WS_adv100.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LredFitchC", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_TKE_adv000.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchD", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_TKE_adv025.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchB", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Red_Fitch_TKE_adv100.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchC", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7904908002208557`*^9, 3.790490887334777*^9}, {
  3.7904909219215293`*^9, 3.7904909503071537`*^9}, {3.790494804332694*^9, 
  3.7904948078573165`*^9}, {3.8135777407632656`*^9, 3.813577843976175*^9}, {
  3.8243610795710144`*^9, 3.82436108401678*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Line_Red_EWP_WS_adv100.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"LredEWPC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Line_Red_EWP_TKE_adv100.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"LredEWPC", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8243613675821157`*^9, 3.8243613982202797`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_WS_adv000.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LblueFitchD", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_WS_adv025.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LblueFitchB", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_WS_adv100.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"LblueFitchC", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_TKE_adv000.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LblueFitchD", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_TKE_adv025.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LblueFitchB", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/Line_Blue_Fitch_TKE_adv100.dat\>\"", ",", 
      RowBox[{"0.5", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LblueFitchC", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7904908002208557`*^9, 3.790490887334777*^9}, {
  3.7904909219215293`*^9, 3.7904909503071537`*^9}, {3.7904910110557795`*^9, 
  3.790491022494419*^9}, {3.790491530846312*^9, 3.7904915532611685`*^9}, {
  3.79049481867085*^9, 3.7904948241523657`*^9}, {3.813579739507495*^9, 
  3.8135798159118032`*^9}, {3.824361548108838*^9, 3.824361641951696*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Line_Blue_EWP_WS_adv100.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"LblueEWPC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Line_Blue_EWP_TKE_adv100.dat\>\"", ",", 
    RowBox[{"0.5", " ", 
     RowBox[{"Transpose", "[", 
      RowBox[{"LblueEWPC", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8243613675821157`*^9, 3.8243613982202797`*^9}, {
  3.824361539573481*^9, 3.8243615451285458`*^9}, {3.824361648853908*^9, 
  3.8243616537454696`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1414B", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135850997681913`*^9, 3.813585117848398*^9}, {
   3.813585930496923*^9, 3.813585938277906*^9}, 3.824371718818595*^9, 
   3.8243721363519087`*^9, 3.8243936644964867`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1414C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135851042200336`*^9, 3.813585124099922*^9}, {
   3.8135859328515596`*^9, 3.813585940500039*^9}, 3.824371730659446*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1414D", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", 
     ",", "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886927462914467`*^9, 3.788692760004053*^9}, {
   3.7886929006146355`*^9, 3.7886929428832655`*^9}, {3.7886943602561107`*^9, 
   3.7886943688530006`*^9}, {3.788694459329028*^9, 3.788694459929224*^9}, {
   3.788694522813609*^9, 3.7886945251053*^9}, {3.7886969914063473`*^9, 
   3.788696991991601*^9}, {3.788697159319125*^9, 3.7886971595193686`*^9}, 
   3.7891900629592266`*^9, {3.789191857999507*^9, 3.789191858093261*^9}, {
   3.7891932866420135`*^9, 3.789193287463812*^9}, {3.78919345991912*^9, 
   3.7891934600318036`*^9}, {3.7893012493390903`*^9, 
   3.7893012497833767`*^9}, {3.7898155098779955`*^9, 
   3.7898155276774983`*^9}, {3.7898156223158035`*^9, 3.789815624121286*^9}, {
   3.7898164304572725`*^9, 3.7898164410612955`*^9}, {3.789903468157399*^9, 
   3.7899034684272676`*^9}, 3.789903516377197*^9, {3.790671975648992*^9, 
   3.7906719764724855`*^9}, {3.8135850828511972`*^9, 3.813585089702593*^9}, {
   3.813585927985389*^9, 3.8135859359720216`*^9}, {3.824371651764004*^9, 
   3.82437165206852*^9}, {3.8243717418949013`*^9, 3.824371760641244*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewprow1414C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_140000.nc\>\"",
      ",", "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135851042200336`*^9, 3.813585124099922*^9}, {
   3.8135859328515596`*^9, 3.813585940500039*^9}, 3.824371730659446*^9, {
   3.8243718154605827`*^9, 3.824371830360928*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nofarmrow1414C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_no_farm_tke_on_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", 
     ",", "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135851042200336`*^9, 3.813585124099922*^9}, {
   3.8135859328515596`*^9, 3.813585940500039*^9}, 3.824371730659446*^9, {
   3.8243718154605827`*^9, 3.824371830360928*^9}, {3.824394713570511*^9, 
   3.824394716393728*^9}, {3.8243947487969217`*^9, 3.824394753822149*^9}, 
   3.824394816470558*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.8243948046152735`*^9, 3.8243948141552653`*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.824371567618395*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1415B", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_025_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135850997681913`*^9, 3.813585117848398*^9}, 
   3.8243717768045435`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1415C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_1_new_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", 
     "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8135851042200336`*^9, 3.813585124099922*^9}, 
   3.8243717844946976`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitchrow1415D", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_fit_new_off_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", 
     ",", "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886927462914467`*^9, 3.788692760004053*^9}, {
   3.7886929006146355`*^9, 3.7886929428832655`*^9}, {3.7886943602561107`*^9, 
   3.7886943688530006`*^9}, {3.788694459329028*^9, 3.788694459929224*^9}, {
   3.788694522813609*^9, 3.7886945251053*^9}, {3.7886969914063473`*^9, 
   3.788696991991601*^9}, {3.788697159319125*^9, 3.7886971595193686`*^9}, 
   3.7891900629592266`*^9, {3.789191857999507*^9, 3.789191858093261*^9}, {
   3.7891932866420135`*^9, 3.789193287463812*^9}, {3.78919345991912*^9, 
   3.7891934600318036`*^9}, {3.7893012493390903`*^9, 
   3.7893012497833767`*^9}, {3.7898155098779955`*^9, 
   3.7898155276774983`*^9}, {3.7898156223158035`*^9, 3.789815624121286*^9}, {
   3.7898164304572725`*^9, 3.7898164410612955`*^9}, {3.789903468157399*^9, 
   3.7899034684272676`*^9}, 3.789903516377197*^9, {3.790671975648992*^9, 
   3.7906719764724855`*^9}, {3.8135850828511972`*^9, 3.813585089702593*^9}, 
   3.8243717500440655`*^9, 3.824371792999632*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ewprow1415C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_150000.nc\>\"",
      ",", "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.824371980219899*^9, 3.824371986534784*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nofarmrow1415C", "=", 
   RowBox[{"getwrfrow", "[", 
    RowBox[{
    "pos1", ",", 
     "\"\<results_no_farm_tke_on_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", 
     ",", "startLevel"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.82439477595749*^9, 3.824394779489793*^9}, {
  3.824394824232544*^9, 3.8243948290758705`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"II", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158200015750113`*^9, 3.8158200060490084`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
  3.8158200091128645`*^9, 3.815820009659403*^9}, {3.824393757145564*^9, 
  3.8243937571555614`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
  3.8158200116891165`*^9, 3.8158200121867847`*^9}, {3.824393757167559*^9, 
  3.824393757176557*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810187966623*^9}, {
  3.815820014508116*^9, 3.8158200151563816`*^9}, {3.824393757189554*^9, 
  3.8243937571965523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_000_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810185913125*^9}, {
  3.8158200174241033`*^9, 3.8158200180005283`*^9}, {3.8243937572085495`*^9, 
  3.824393757215548*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
  3.8158102023562*^9, 3.815810223244505*^9}, {3.81582002020265*^9, 
  3.8158200207033105`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
  3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158200227129345`*^9, 
  3.8158200232345395`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
  3.8158200252238398`*^9, 3.8158200257503967`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_025_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
  3.815820028866631*^9, 3.815820029389234*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
  3.8158102023562*^9, 3.815810223244505*^9}, {3.815810261406502*^9, 
  3.815810278822443*^9}, {3.81582003138354*^9, 3.815820031937092*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
  3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158102649129915`*^9, 
  3.8158102836780014`*^9}, {3.8158200341377716`*^9, 3.815820034667324*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
  3.8158102684974656`*^9, 3.815810289222659*^9}, {3.815820036705963*^9, 
  3.815820037191662*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/TKE_flighttrackA_adv_100_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
  3.815810272121211*^9, 3.8158102944079022`*^9}, {3.8158200392374225`*^9, 
  3.815820039717166*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"II", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158200015750113`*^9, 3.8158200060490084`*^9}, {
  3.815820110116048*^9, 3.8158201105479155`*^9}, {3.8158201915961156`*^9, 
  3.815820191732749*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
   3.8158200091128645`*^9, 3.815820009659403*^9}, 3.8158201266266136`*^9, {
   3.824393835029067*^9, 3.8243938350370655`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
   3.8158200116891165`*^9, 3.8158200121867847`*^9}, 3.8158201266385574`*^9, {
   3.824393835048063*^9, 3.824393835056061*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810187966623*^9}, {
   3.815820014508116*^9, 3.8158200151563816`*^9}, 3.815820126650551*^9, {
   3.8243938350670586`*^9, 3.8243938350760565`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_000_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414D", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414D", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810185913125*^9}, {
   3.8158200174241033`*^9, 3.8158200180005283`*^9}, 3.8158201266664734`*^9, {
   3.8243938350870533`*^9, 3.8243938350940523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
   3.8158102023562*^9, 3.815810223244505*^9}, {3.81582002020265*^9, 
   3.8158200207033105`*^9}, 3.8158201266804733`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
   3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158200227129345`*^9, 
   3.8158200232345395`*^9}, 3.815820126694454*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
   3.8158200252238398`*^9, 3.8158200257503967`*^9}, 3.815820126707424*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_025_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414B", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414B", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
   3.815820028866631*^9, 3.815820029389234*^9}, 3.815820126717349*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1500_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101029787965`*^9}, {
   3.8158102023562*^9, 3.815810223244505*^9}, {3.815810261406502*^9, 
   3.815810278822443*^9}, {3.81582003138354*^9, 3.815820031937092*^9}, 
   3.815820126731356*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1530_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1415C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158101457920237`*^9}, {
   3.8158102065657797`*^9, 3.815810229355752*^9}, {3.8158102649129915`*^9, 
   3.8158102836780014`*^9}, {3.8158200341377716`*^9, 3.815820034667324*^9}, 
   3.815820126743326*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1400_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "1", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.815810234588652*^9}, {
   3.8158102684974656`*^9, 3.815810289222659*^9}, {3.815820036705963*^9, 
   3.815820037191662*^9}, 3.8158201267572317`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/WS_flighttrackA_adv_100_1430_250m.dat\>\"", ",", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"fitchrow1414C", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"II", ",", "4", ",", "5"}], "]"}], "]"}], "]"}]}], "}"}], 
       "]"}], ",", 
      RowBox[{
       RowBox[{"53.9", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "54.25"}], "&"}]}], "]"}]}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.8158100003250976`*^9, 3.8158102399352508`*^9}, {
   3.815810272121211*^9, 3.8158102944079022`*^9}, {3.8158200392374225`*^9, 
   3.815820039717166*^9}, 3.815820126766262*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/FITCH_off_WS_ROW_250m_14PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fitchrow1414D", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414D", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806993117638302*^9, 
  3.806993141589811*^9}, {3.8069931980730276`*^9, 3.806993226112578*^9}, {
  3.8243945042269554`*^9, 3.8243945165858755`*^9}, {3.82439466397987*^9, 
  3.824394673475331*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/FITCH_off_WS_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fitchrow1415D", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415D", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806993117638302*^9, 
  3.806993141589811*^9}, {3.8069931980730276`*^9, 3.806993226112578*^9}, {
  3.8243945042269554`*^9, 3.8243945165858755`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/FITCH_off_QKE_ROW_250m_14PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fitchrow1414D", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1414D", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927304198813`*^9, 3.806992731481016*^9}, {3.806992959744997*^9, 
  3.806992974919295*^9}, {3.8069931981638427`*^9, 3.8069932333281217`*^9}, {
  3.824394508654791*^9, 3.8243945209063663`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/FITCH_off_QKE_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fitchrow1415D", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"fitchrow1415D", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806992957541885*^9, 
  3.8069929805888987`*^9}, {3.8069931981818*^9, 3.806993236342014*^9}, {
  3.824394524216056*^9, 3.824394530058786*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.8243945332183905`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<c:/testdata/EWP_WS_ROW_250m_14PM_FLIGHT.dat\>\"", ",", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ewprow1414C", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"ewprow1414C", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927304198813`*^9, 3.806992731481016*^9}, {3.8128825087874184`*^9, 
  3.812882509405167*^9}, {3.8243945390080695`*^9, 3.8243945457706337`*^9}}],

Cell[BoxData["\<\"c:/testdata/EWP_WS_ROW_250m_14PM_FLIGHT.dat\"\>"], "Output",
 CellChangeTimes->{3.8069926918297606`*^9, 3.8069927456280217`*^9, 
  3.8128776665361586`*^9, 3.81288252596589*^9, 3.8243946477889442`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<c:/testdata/EWP_WS_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ewprow1415C", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"ewprow1415C", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
   3.8069927245366135`*^9, 3.8069927484034233`*^9}, 3.812882517215892*^9, {
   3.8243945500433955`*^9, 3.8243945537253923`*^9}}],

Cell[BoxData["\<\"c:/testdata/EWP_WS_ROW_250m_15PM_FLIGHT.dat\"\>"], "Output",
 CellChangeTimes->{{3.8069927378060246`*^9, 3.8069927490123625`*^9}, 
   3.81287766742922*^9, 3.8128825267831297`*^9, 3.8243946489930487`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<c:/testdata/EWP_QKE_ROW_250m_14PM_FLIGHT.dat\>\"", ",", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ewprow1414C", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"ewprow1414C", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927304198813`*^9, 3.806992731481016*^9}, {3.806992959744997*^9, 
  3.806992974919295*^9}, {3.8243945591472077`*^9, 3.824394560744796*^9}}],

Cell[BoxData["\<\"c:/testdata/EWP_QKE_ROW_250m_14PM_FLIGHT.dat\"\>"], "Output",
 CellChangeTimes->{3.8069926918297606`*^9, 3.8069927456280217`*^9, 
  3.806992988931354*^9, 3.8128776754600353`*^9, 3.8243946500211616`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<c:/testdata/EWP_QKE_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ewprow1415C", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"ewprow1415C", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806992957541885*^9, 
  3.8069929805888987`*^9}, {3.82439456406835*^9, 3.8243945664753942`*^9}}],

Cell[BoxData["\<\"c:/testdata/EWP_QKE_ROW_250m_15PM_FLIGHT.dat\"\>"], "Output",
 CellChangeTimes->{{3.8069927378060246`*^9, 3.8069927490123625`*^9}, 
   3.806992992553482*^9, 3.812877676136647*^9, 3.8243946512366886`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_WS_ROW_250m_14PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"nofarmrow1414C", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"nofarmrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927304198813`*^9, 3.806992731481016*^9}, {3.8069931176083803`*^9, 
  3.8069931370024433`*^9}, {3.8069931980580826`*^9, 3.8069932261026044`*^9}, {
  3.806997038391674*^9, 3.806997070604472*^9}, {3.824394680365982*^9, 
  3.8243946834995584`*^9}, {3.824394792931823*^9, 3.8243947955878177`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_WS_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"nofarmrow1415C", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"nofarmrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806993117638302*^9, 
  3.806993141589811*^9}, {3.8069931980730276`*^9, 3.806993226112578*^9}, {
  3.8069970384016805`*^9, 3.8069970704438944`*^9}, {3.8243946851926312`*^9, 
  3.8243946867563734`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_QKE_ROW_250m_14PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"nofarmrow1414C", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"nofarmrow1414C", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927304198813`*^9, 3.806992731481016*^9}, {3.806992959744997*^9, 
  3.806992974919295*^9}, {3.8069931981638427`*^9, 3.8069932333281217`*^9}, {
  3.806997038322895*^9, 3.8069970705147123`*^9}, {3.824394688572414*^9, 
  3.824394690716634*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_QKE_ROW_250m_15PM_FLIGHT.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"nofarmrow1415C", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{"nofarmrow1415C", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "i", ",", "5"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8069926345087633`*^9, 3.8069926899436913`*^9}, {
  3.8069927245366135`*^9, 3.8069927484034233`*^9}, {3.806992957541885*^9, 
  3.8069929805888987`*^9}, {3.8069931981818*^9, 3.806993236342014*^9}, {
  3.8069970383338733`*^9, 3.806997070528643*^9}, {3.8243946926318645`*^9, 
  3.824394694659294*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EWPfcp1", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{
     RowBox[{"fcpPOS", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_130000.nc\>\"", ",", "6", 
     ",", "39"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8057162593917503`*^9, 3.805716274955367*^9}, {
   3.8057165686677284`*^9, 3.8057165792143974`*^9}, {3.812879935414139*^9, 
   3.8128799357974625`*^9}, 3.8243956659196587`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EWPfcp2", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{
     RowBox[{"fcpPOS", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_140000.nc\>\"", ",", "6", 
     ",", "39"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8057162593917503`*^9, 3.805716274955367*^9}, {
   3.812879872039725*^9, 3.812879872457281*^9}, 3.8243957319214883`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EWPfcp3", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{
     RowBox[{"fcpPOS", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", 
     "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_150000.nc\>\"", ",", "6", 
     ",", "39"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8057162593917503`*^9, 3.805716274955367*^9}, {
   3.805716588085929*^9, 3.80571659734926*^9}, {3.812879906436042*^9, 
   3.8128799069091425`*^9}, 3.8243956689652114`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EWPfcp4", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{
     RowBox[{"fcpPOS", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", 
     "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_160000.nc\>\"", ",", "6", 
     ",", "39"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8057162593917503`*^9, 3.805716274955367*^9}, {
   3.805716602111205*^9, 3.805716635345085*^9}, {3.812879912784129*^9, 
   3.812879913203293*^9}, 3.824395671485364*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EWPfcp5", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{
     RowBox[{"fcpPOS", "[", 
      RowBox[{"[", "5", "]"}], "]"}], ",", 
     "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_160000.nc\>\"", ",", "6", 
     ",", "39"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8057162593917503`*^9, 3.805716274955367*^9}, {
   3.805716621201132*^9, 3.8057166401363916`*^9}, {3.8128799204307685`*^9, 
   3.8128799208918104`*^9}, 3.8243956788432713`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EWPfcp6", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{
     RowBox[{"fcpPOS", "[", 
      RowBox[{"[", "6", "]"}], "]"}], ",", 
     "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_160000.nc\>\"", ",", "6", 
     ",", "39"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8057162593917503`*^9, 3.805716274955367*^9}, {
   3.805716646069275*^9, 3.8057166538925085`*^9}, {3.8128799246519156`*^9, 
   3.812879925099951*^9}, 3.824395681094331*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EWPfcp7", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{
     RowBox[{"fcpPOS", "[", 
      RowBox[{"[", "7", "]"}], "]"}], ",", 
     "\"\<results_ewp_corr_nc3/wrfout_d03_20171014_170000.nc\>\"", ",", "6", 
     ",", "39"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8057162593917503`*^9, 3.805716274955367*^9}, {
   3.8057166590188055`*^9, 3.8057166651968336`*^9}, {3.8128799283888583`*^9, 
   3.8128799288556004`*^9}, 3.8243956836520443`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_fcp_1.m\>\"", ",", "EWPfcp1"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_fcp_2.m\>\"", ",", "EWPfcp2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_fcp_3.m\>\"", ",", "EWPfcp3"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_fcp_4.m\>\"", ",", "EWPfcp4"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_fcp_5.m\>\"", ",", "EWPfcp5"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_fcp_6.m\>\"", ",", "EWPfcp6"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_fcp_7.m\>\"", ",", "EWPfcp7"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8057166759800844`*^9, 3.805716711504425*^9}, {
  3.824396544276335*^9, 3.824396552112812*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2. Relevant data are extracted from WRF outputs for the site FINO 1\
\>", "Subsection",
 CellChangeTimes->{{3.7886683763853903`*^9, 3.7886683805826197`*^9}, {
  3.8169237382980742`*^9, 3.816923758806182*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "SetDirectory", "[", "\"\<C:/Projects/ALLDATA/FINO1/201710to12\>\"", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886684726609793`*^9, 3.78866849846179*^9}, {
  3.7886689068880157`*^9, 3.7886689178951297`*^9}, {3.788670392745325*^9, 
  3.78867039610468*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fz", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<33\>\"", ",", "\"\<40\>\"", ",", "\"\<50\>\"", ",", "\"\<60\>\"", 
     ",", "\"\<70\>\"", ",", "\"\<80\>\"", ",", "\"\<90\>\"", ",", 
     "\"\<100\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7886689240031376`*^9, 3.788668961946226*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wsFINO120171014", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}], 
        "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstest14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<14\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886722400282555`*^9, 
  3.7886722455937767`*^9}, {3.8063055127385244`*^9, 3.8063055128551626`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstest15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<15\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886722400282555`*^9, 
  3.7886722455937767`*^9}, {3.789820896766125*^9, 3.7898209000706606`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstest20", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windgeschwindigkeit_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<20\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "Fz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886722400282555`*^9, 
  3.7886722455937767`*^9}, {3.789820896766125*^9, 3.7898209000706606`*^9}, {
  3.8066456128244715`*^9, 3.8066456171209607`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstestmean14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"wstest14", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "8"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.806305525064556*^9, 
  3.806305528242055*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wstestmean15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"wstest15", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "8"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.7898208649049454`*^9, 
  3.7898208794363985`*^9}, {3.7898209401256666`*^9, 3.7898209403258343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirFINO120171014", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windrichtung_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}], 
        "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "Fz", "]"}], "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788668430489108*^9, 3.788668445689642*^9}, {
  3.7886689675108285`*^9, 3.7886689825537114`*^9}, {3.7886694127133904`*^9, 
  3.7886694242498713`*^9}, {3.78866946715184*^9, 3.788669529695228*^9}, {
  3.7886704076761684`*^9, 3.7886704084629498`*^9}, {3.7886704786829033`*^9, 
  3.7886705019093876`*^9}, {3.7886705708813963`*^9, 3.7886705711503897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtest14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windrichtung_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<14\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "Fz", "]"}], "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788672432826764*^9, 3.7886724489293213`*^9}, {
  3.8063055910653973`*^9, 3.8063055912220306`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtest15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Import", "[", 
          RowBox[{"\"\<FINO1_Windrichtung_\>\"", "<>", 
           RowBox[{"Fz", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "<>", 
           "\"\<m_20171001_20171231.dat\>\""}], "]"}], ",", "6"}], "]"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "\"\<2017-10-14\>\""}],
          "&&", 
         RowBox[{
          RowBox[{"StringTake", "[", 
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", "2"}], "]"}], "\[Equal]", 
          "\"\<15\>\""}]}], "&"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "Fz", "]"}], "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788672432826764*^9, 3.7886724489293213`*^9}, {
  3.7898207458020115`*^9, 3.789820750774514*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtestmean14", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"dirtest14", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "7"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.7886724596305313`*^9, 
  3.7886724761911387`*^9}, {3.806305596486952*^9, 3.806305599564677*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dirtestmean15", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mean", "[", 
      RowBox[{"dirtest15", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "All", ",", "3"}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "7"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.788672265023011*^9, 3.7886722857642612`*^9}, {
  3.78867237398203*^9, 3.7886723781230135`*^9}, {3.7886724596305313`*^9, 
  3.7886724761911387`*^9}, {3.7898208018232*^9, 3.7898208049669085`*^9}}],

Cell["\<\
THE above are measurement data from FINO 1, the readers need to download \
themselves following the info given in the paper.\
\>", "Text",
 CellChangeTimes->{{3.816923789398501*^9, 3.816923842999169*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<J:/OFFSHOREWAKE/LLJ/\>\"", "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "THIS", " ", "IS", " ", "WHERE", " ", "THE", " ", "WRF", " ", "OUTPUTS", 
    " ", "ARE", " ", "SAVED"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.7886731910454893`*^9, 3.788673205871048*^9}, {
   3.78981690447651*^9, 3.7898169056466246`*^9}, {3.8056258545861487`*^9, 
   3.8056258585256166`*^9}, {3.806303453951067*^9, 3.806303464150792*^9}, {
   3.8130476117203856`*^9, 3.8130476167195234`*^9}, 3.813574667493128*^9, {
   3.816923850636476*^9, 3.8169238632130833`*^9}}],

Cell[BoxData["\<\"J:\\\\OFFSHOREWAKE\\\\LLJ\"\>"], "Output",
 CellChangeTimes->{
  3.7886732064937143`*^9, 3.789817009485281*^9, {3.7899848965628223`*^9, 
   3.789984906280923*^9}, 3.7905052026134777`*^9, {3.805625831639166*^9, 
   3.805625859609992*^9}, {3.806303455839028*^9, 3.806303464815981*^9}, 
   3.806304625187787*^9, 3.8063072969851804`*^9, 3.8063755444635706`*^9, {
   3.806645188491701*^9, 3.8066452131854687`*^9}, 3.807591331743722*^9, 
   3.8076795362917614`*^9, 3.807679591674693*^9, 3.8130477161828146`*^9, 
   3.813565601058965*^9, 3.813565746990775*^9, 3.8135669131409492`*^9, 
   3.8135746786817217`*^9, 3.813574754029387*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesFitch", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_fit_old_off_rep/wrfout_d03*\>\"", "]"}], 
    ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
  3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
  3.789817660121784*^9}, {3.8130476407663307`*^9, 3.8130476734359446`*^9}, {
  3.8130477083720512`*^9, 3.813047708499732*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_fit_old_off_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7891908672791452`*^9, 3.789190885619096*^9}, 
   3.7898170767521152`*^9, 3.7898176610086856`*^9, 3.790505206597246*^9, 
   3.790683499324317*^9, 3.8056351557398005`*^9, 3.8063034734180226`*^9, 
   3.8063045426625605`*^9, 3.806304626198086*^9, 3.806307299483523*^9, 
   3.8063755454489393`*^9, 3.806645215136201*^9, 3.807591334636181*^9, 
   3.807679593588579*^9, {3.813047666265327*^9, 3.813047673946203*^9}, {
   3.813047711779313*^9, 3.8130477169746847`*^9}, 3.8135656022994013`*^9, 
   3.813565748162016*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesFitchB", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_fit_025_new_rep/wrfout_d03*\>\"", "]"}], 
    ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
   3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
   3.789817660121784*^9}, {3.8130476407663307`*^9, 3.8130476734359446`*^9}, {
   3.8130477083720512`*^9, 3.813047708499732*^9}, 3.8135805999108562`*^9, 
   3.813580646056393*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_fit_025_new_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8135806528925066`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesFitchC", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_fit_1_new_rep/wrfout_d03*\>\"", "]"}], ",",
     "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.813580660969962*^9, 3.8135806648987474`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_fit_1_new_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.813580665681176*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesEWP", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
    "FileNames", "[", "\"\<results_ewp_off_rep/wrfout_d03*\>\"", "]"}], ",", 
    "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
  3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
  3.7898176741786184`*^9}, {3.8130477316515956`*^9, 3.8130477483640127`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_ewp_off_rep\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7891908672791452`*^9, 3.789190885619096*^9}, 
   3.7898170767521152`*^9, {3.7898176610086856`*^9, 3.789817675616431*^9}, 
   3.790505208074725*^9, 3.7906835013567204`*^9, 3.805635157299634*^9, 
   3.806303475348824*^9, 3.806304543534191*^9, 3.806304725922346*^9, 
   3.806307302864456*^9, 3.8066452160028763`*^9, 3.8075913357052917`*^9, 
   3.80767959441836*^9, {3.8130477406587276`*^9, 3.8130477489043493`*^9}, 
   3.8135656047551217`*^9, 3.8135657495737286`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fnamesnofarm", "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{"FileNames", "[", "\"\<results_nofarm/wrfout_d03*\>\"", "]"}], 
    ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.789190848764693*^9, 3.789190884596871*^9}, {
  3.7898170366621885`*^9, 3.7898170380189805`*^9}, {3.7898176592728453`*^9, 
  3.7898176741786184`*^9}, {3.789877510877441*^9, 3.7898775172644625`*^9}, {
  3.8063034935601892`*^9, 3.8063035154865513`*^9}, {3.8130477621491776`*^9, 
  3.8130477678212843`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"results_nofarm\\\\wrfout_d03_20171014_120000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_130000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_140000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_150000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_160000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_170000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_180000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_190000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_200000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_210000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_220000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171014_230000.nc\"\>", 
   ",", "\<\"results_nofarm\\\\wrfout_d03_20171015_000000.nc\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.789877519415598*^9, 3.7905052105222373`*^9, 3.7906835014380608`*^9, 
   3.8056351594987717`*^9, {3.806303507624556*^9, 3.806303516465951*^9}, 
   3.8063073037680564`*^9, 3.806645216923405*^9, 3.8075913368346124`*^9, 
   3.8076795952072577`*^9, 3.813047768343852*^9, 3.813565606020895*^9, 
   3.8135657507117405`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"link", "=", 
  RowBox[{"Install", "[", "\"\<NetCDF.exe\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.4761779532304077`*^9, 3.476177962073931*^9}, 
   3.4761780970548506`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["LinkObject",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False}, 
    PanelBox[
     PaneSelectorBox[{False->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquarePlusIconMedium"],
            ImageSizeCache->{12., {0., 12.}}],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = True),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 
             3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              StyleBox[
               
               PaneBox["\<\"\\\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\10.0\\\\AddOns\\\\Applications\\\\NetCDF.exe\\\"\"\
\>",
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0,
                ImageSize->{{1, 300}, Automatic},
                ScrollPosition->{0., 0.},
                StripOnInput->True],
               LineBreakWithin->False],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True->GridBox[{
        {
         PaneBox[
          ButtonBox[
           
           DynamicBox[FEPrivate`FrontEndResource[
            "FEBitmaps", "SquareMinusIconMedium"]],
           Appearance->None,
           ButtonFunction:>(Typeset`open$$ = False),
           Evaluator->Automatic,
           Method->"Preemptive"],
          Alignment->{Center, Center},
          
          ImageSize->
           Dynamic[{
            Automatic, 
             3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification])}]], 
         GraphicsBox[
          {Thickness[0.038461538461538464`], 
           {FaceForm[{GrayLevel[0.93], Opacity[1.]}], 
            FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {1, 
             3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{25.499999999999996`,
              2.5}, {25.499999999999996`, 1.3953100000000003`}, {
             24.604699999999998`, 0.49999999999999994`}, {23.5, 
             0.49999999999999994`}, {2.5, 0.49999999999999994`}, {
             1.3953100000000003`, 0.49999999999999994`}, {
             0.49999999999999994`, 1.3953100000000003`}, {
             0.49999999999999994`, 2.5}, {0.49999999999999994`, 23.5}, {
             0.49999999999999994`, 24.604699999999998`}, {1.3953100000000003`,
              25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
             25.499999999999996`}, {24.604699999999998`, 
             25.499999999999996`}, {25.499999999999996`, 
             24.604699999999998`}, {25.499999999999996`, 23.5}, {
             25.499999999999996`, 2.5}}}]}, 
           {FaceForm[{RGBColor[0.5, 0.5, 0.5], Opacity[1.]}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
             19.116799999999998`}, {16.3832, 21.876199999999997`}, {16.3832, 
             20.021499999999996`}, {6.930469999999999, 20.021499999999996`}, {
             6.930469999999999, 18.212100000000003`}, {16.3832, 
             18.212100000000003`}, {16.3832, 16.357399999999995`}, {20.5426, 
             19.116799999999998`}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {9.46445, 
             11.079700000000003`}, {9.46445, 12.933999999999997`}, {
             18.917199999999998`, 12.933999999999997`}, {18.917199999999998`, 
             14.7438}, {9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 
             13.8391}}}], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
              1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
             0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4sIjUTVcAooO8+XdOPpnKDg8YkwNXuen7JA2
W/qycJSgw5sbHEde31CB82PFhGf3n1V1aFVgVz0zR8oBrF9czWFHsFXE/9Wy
Dje0Dj4qiFWDy7cVLYptDVKH65/g6Xbu0HMNOB9sn4I23H6w+SWacD5De8DS
tDQNB7ldC/alskg4aD2+nx6joeFgnPFi/oMZog5B9vlaQa/UHao9k7f0KUhA
+D/UUPVbqML5jCB+oIpDzJHypGv8Eg4eGad3ikiqwM2T57H5LndPGW6eya7m
GzMvKcH1o4cXABG3d/Y=
             "]], 
            FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 
             1, 0}, {0, 1, 0}}}, {{{14.163129999999999`, 4.337966249999999}, {
             16.96813, 4.337966249999999}, {16.96813, 5.047809999999999}, {
             14.98813, 5.047809999999999}, {14.98813, 8.29796625}, {
             14.163129999999999`, 8.29796625}, {14.163129999999999`, 
             4.337966249999999}}}]}},
          AspectRatio->1,
          Axes->False,
          Background->GrayLevel[0.93],
          Frame->True,
          FrameStyle->Directive[
            Thickness[Tiny], 
            GrayLevel[0.7]],
          FrameTicks->None,
          ImageSize->{Automatic, 
            Dynamic[
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
              Magnification]), ImageSizeCache -> {45., {0., 9.}}]}], GridBox[{
           {
            RowBox[{
             TagBox["\<\"Name: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox[
              
              PaneBox["\<\"\\\"C:\\\\Program Files\\\\Wolfram \
Research\\\\Mathematica\\\\10.0\\\\AddOns\\\\Applications\\\\NetCDF.exe\\\"\"\
\>",
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0,
               ImageSize->{{1, 500}, Automatic},
               StripOnInput->True],
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link mode: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["Listen",
              "SummaryItem"]}]},
           {
            RowBox[{
             TagBox["\<\"Link protocol: \"\>",
              "SummaryItemAnnotation"], "\[InvisibleSpace]", 
             TagBox["\<\"SharedMemory\"\>",
              "SummaryItem"]}]}
          },
          AutoDelete->False,
          
          BaseStyle->{
           ShowStringCharacters -> False, NumberMarks -> False, 
            PrintPrecision -> 3, ShowSyntaxStyles -> False},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}
       },
       AutoDelete->False,
       BaselinePosition->{1, 1},
       GridBoxAlignment->{"Rows" -> {{Top}}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
      Typeset`open$$],
      ImageSize->Automatic],
     BaselinePosition->Baseline],
    DynamicModuleValues:>{}], "]"}],
  LinkObject[
  "\"C:\\Program Files\\Wolfram \
Research\\Mathematica\\10.0\\AddOns\\Applications\\NetCDF.exe\"", 3228, 12],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVyl1Ik2EYgOEtLGeZKzxIAw+mBspozn6GziZ7bNRcOdcWUgyjRElh5USb
WEOl/8DmCBnZWGkqOQ1SNFL8KyEy+aQsqanLKEzd971atrKlI3veg5vr5Bbl
FesL+DweLxtLB6lDPeeDhDphJ/WndtA1veoD89alVC+qGM59xF/zQWP/QDe1
eHV2eQuqTuto/oj21Hcx1EJVcNSD1ptnJZPoi76IB1Oo3fXQOE0/efk41X0s
c96LrnRm6WfQqHuJ+nX0pn3XCnVwpj2PH/SB9LPCthF1mnjqUDRjKKKSmufu
lQrQC1na+9RNkTXWMPT6F9szap1dI0pEDcxxTxI6E1B9/fPPB8HsZoUqhIUq
f/loVQwLv0vnm+N2s8Crrrn1XsbCZZHEsaBjYSr/2kIwhwWdrXR89QQL590e
/WsjC0K/eORSKQt3tvVFvRpioUE0EUNNsDiT94s42G6pvUhVr+x1y1DL86zY
nDgOwgWCwOJhDuZ6a9uW0BsafhfVKOB6qOFKtT1SzYFraYM/Gu0Oe1K2E5Ws
CZPzMzlgxuSp1D1WxtJ/hINDLcMGYQqBH+canWLU/Ni0Lk4lsGOx4rQUraiO
V8rQwJXbm0+iTFGBkFpMQmKo++LbGqjy9qeSJDkBb4frpRaFg5JoPbogLRkw
oiNpV03aNAJvNZXvDAcIjEqduioFgU9KTZHfSODXB1lTei6Bsroo69lTBDKO
1n7/doaAozU2zFpIgO0NbXqDTpT8bWWKCIiWrZNUj/luyhj6H+vkTdA=
  "]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP14", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm14", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP15", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.789818351333433*^9, 3.7898183549722424`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm15", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.789877545639567*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP20", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.8066451326032777`*^9, 3.80664513356367*^9}, {3.806645172056812*^9, 
   3.806645172856648*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm20", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}, {3.806645138716958*^9, 
   3.8066451397053156`*^9}, {3.8066451761388483`*^9, 3.8066451768130445`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.806645141998147*^9, 3.8066451429775753`*^9}, {3.806645179067955*^9, 
  3.8066451795546494`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP14Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.8056377663279004`*^9, 3.8056377795904465`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm14Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}, {3.8056377734140024`*^9, 
   3.8056377807403717`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP15Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.789818351333433*^9, 3.7898183549722424`*^9}, {3.8056377754993815`*^9, 
   3.8056377831958537`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}, {3.805637776759043*^9, 
  3.805637784424523*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm15Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.789877545639567*^9}, {3.8056377780745773`*^9, 
   3.805637785736024*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1EWP20Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesEWP", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.8056377663279004`*^9, 3.8056377795904465`*^9}, {3.806645230306546*^9, 
   3.8066452400603323`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1nofarm20Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesnofarm", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.788091860791216*^9, 3.7880918864471416`*^9}, {
   3.7881631642036505`*^9, 3.788163165222329*^9}, 3.788163288442268*^9, {
   3.788163330529791*^9, 3.788163357274649*^9}, {3.788163609130783*^9, 
   3.788163609793827*^9}, {3.78816429472077*^9, 3.7881642962478113`*^9}, {
   3.788164416038847*^9, 3.788164416855361*^9}, {3.788164487961127*^9, 
   3.788164488093034*^9}, {3.7886016509637403`*^9, 3.7886017397981596`*^9}, {
   3.7886680220926847`*^9, 3.788668031495699*^9}, {3.7886731088003783`*^9, 
   3.7886731091847186`*^9}, {3.7886731701438713`*^9, 
   3.7886731979708614`*^9}, {3.7886732798182125`*^9, 3.788673280256545*^9}, {
   3.78919159369057*^9, 3.789191611608638*^9}, {3.7898176865158243`*^9, 
   3.7898176869236574`*^9}, {3.789817917631192*^9, 3.789817918332011*^9}, {
   3.7898774996860085`*^9, 3.7898775274742594`*^9}, {3.8056377734140024`*^9, 
   3.8056377807403717`*^9}, {3.8066452336026883`*^9, 3.806645242850865*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20Left", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitch", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}, {3.80664523654875*^9, 
  3.806645246777306*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.789878558197447*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14B", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.813580726514374*^9, 3.813580731414074*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14C", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580737976027*^9, 3.8135807410321283`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15B", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}, {3.813580746764064*^9, 
  3.8135807497713056`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15C", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580759581566*^9, 3.8135807624320936`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20B", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.806645141998147*^9, 3.8066451429775753`*^9}, {3.806645179067955*^9, 
  3.8066451795546494`*^9}, {3.8135807657609744`*^9, 3.81358076859492*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20C", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1pos", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580775309825*^9, 3.8135807788448105`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14LeftB", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}, {3.813580810318684*^9, 
  3.813580812857642*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch14LeftC", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "3", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580815942842*^9, 3.813580818854536*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15LeftB", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.7898183595098286`*^9, 3.789818362868524*^9}, {3.805637776759043*^9, 
  3.805637784424523*^9}, {3.813580827989236*^9, 3.8135808318573675`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch15LeftC", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "4", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8135808358467045`*^9, 3.8135808399282026`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20LeftB", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchB", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7886732890269485`*^9, 3.7886732927872896`*^9}, {
  3.7891916181461396`*^9, 3.7891916300323515`*^9}, {3.7898177057718744`*^9, 
  3.789817713587533*^9}, {3.789817921431503*^9, 3.789817921632083*^9}, {
  3.8056377744481936`*^9, 3.805637781858385*^9}, {3.80664523654875*^9, 
  3.806645246777306*^9}, {3.8135808495311775`*^9, 3.8135808524444523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch20LeftC", "=", 
   RowBox[{"getwrfts", "[", 
    RowBox[{"FINO1posLeft", ",", 
     RowBox[{"fnamesFitchC", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "6", ",", "39"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.813580856002179*^9, 3.813580858800744*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FINO1posLeft", "=", 
   RowBox[{"{", 
    RowBox[{"144", ",", "153"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8056354517247143`*^9, 3.805635456839049*^9}, {
  3.8056354978305044`*^9, 3.805635501729127*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100m", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1pos", ",", 
       RowBox[{"fnamesFitch", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789817747849946*^9, 3.7898177576281424`*^9}, {
  3.789817874606064*^9, 3.7898178750595603`*^9}, {3.7905055057574277`*^9, 
  3.7905055059177675`*^9}, {3.813566468526078*^9, 3.8135664687105837`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100mB", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1pos", ",", 
       RowBox[{"fnamesFitchB", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789817747849946*^9, 3.7898177576281424`*^9}, {
  3.789817874606064*^9, 3.7898178750595603`*^9}, {3.7905055057574277`*^9, 
  3.7905055059177675`*^9}, {3.813566468526078*^9, 3.8135664687105837`*^9}, {
  3.813581011837861*^9, 3.813581014606733*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100mC", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1pos", ",", 
       RowBox[{"fnamesFitchC", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789817747849946*^9, 3.7898177576281424`*^9}, {
  3.789817874606064*^9, 3.7898178750595603`*^9}, {3.7905055057574277`*^9, 
  3.7905055059177675`*^9}, {3.813566468526078*^9, 3.8135664687105837`*^9}, {
  3.813581011837861*^9, 3.8135810250983844`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tsFINO1Fitch100mLeft", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"getwrftsA", "[", 
      RowBox[{"FINO1posLeft", ",", 
       RowBox[{"fnamesFitch", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "6", ",", "12"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{
        RowBox[{"Length", "[", "fnamesFitch", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8056360230439577`*^9, 3.8056360277374144`*^9}, {
  3.8135664722032175`*^9, 3.8135664725573573`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"wrftime", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"i", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"j", "-", "10"}], ")"}], "/", "60"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "12", ",", "23"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "10", ",", "60", ",", "10"}], "}"}]}], "]"}], "]"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.789824834074008*^9, 3.7898249232383366`*^9}, {
  3.7905061354386854`*^9, 3.7905061383728113`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"obstime", "=", 
   RowBox[{"N", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ToExpression", "[", 
         RowBox[{"StringTake", "[", 
          RowBox[{"#", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{
         RowBox[{"ToExpression", "[", 
          RowBox[{"StringTake", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "5"}], "}"}]}], "]"}], "]"}], "/", "60"}]}], 
       "&"}], ",", 
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7898249377799234`*^9, 3.789825017220561*^9}, {
  3.790506205827893*^9, 3.7905062095297203`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "3"}], "]"}], "]"}], ",", 
      RowBox[{"-", "72"}]}], "]"}], "-", "weightednofarm"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Mean", "[", "xx", "]"}], ",", 
    RowBox[{"StandardDeviation", "[", "xx", "]"}], ",", 
    RowBox[{"Mean", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "#", "]"}], "&"}], ",", "xx"}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.8057012466573944`*^9, 3.8057013044948387`*^9}, {
  3.8057014745592546`*^9, 3.8057014769010324`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.408314298775097`"}], ",", "0.5589603126751949`", ",", 
   "1.408314298775097`"}], "}"}]], "Output",
 CellChangeTimes->{{3.805701283742272*^9, 3.805701304983504*^9}, 
   3.8057014773348856`*^9, 3.806375600379199*^9, 3.8063847536965003`*^9, 
   3.8135667773736258`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "3"}], "]"}], "]"}], ",", 
      RowBox[{"-", "72"}]}], "]"}], "-", "weightedEWP"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Mean", "[", "xx", "]"}], ",", 
    RowBox[{"StandardDeviation", "[", "xx", "]"}], ",", 
    RowBox[{"Mean", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "#", "]"}], "&"}], ",", "xx"}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.8057012466573944`*^9, 3.805701317486081*^9}, {
  3.805701446459361*^9, 3.8057014706457167`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.19593413794988715`"}], ",", "0.5243896710071149`", ",", 
   "0.45331286453310266`"}], "}"}]], "Output",
 CellChangeTimes->{{3.805701283742272*^9, 3.805701318212141*^9}, 
   3.8057014812104745`*^9, 3.8063756017157016`*^9, 3.8063847545771513`*^9, 
   3.813566778992525*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xx", "=", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"wsFINO120171014", "[", 
       RowBox[{"[", 
        RowBox[{"8", ",", "All", ",", "3"}], "]"}], "]"}], ",", 
      RowBox[{"-", "72"}]}], "]"}], "-", "weightedFitch"}]}], ";", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Mean", "[", "xx", "]"}], ",", 
    RowBox[{"StandardDeviation", "[", "xx", "]"}], ",", 
    RowBox[{"Mean", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "#", "]"}], "&"}], ",", "xx"}], "]"}], "]"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.8057012466573944`*^9, 3.805701330139263*^9}, 
   3.805701485953803*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3035236554197806`", ",", "0.45834060883237787`", ",", 
   "0.4384417408794124`"}], "}"}]], "Output",
 CellChangeTimes->{3.8057013306269584`*^9, 3.80570148665022*^9, 
  3.806375602811886*^9, 3.806384755216728*^9, 3.8135667799912224`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EWP14", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1EWP14Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1EWP14", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EWP15", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1EWP15Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1EWP15", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch14", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch14Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch14", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch15", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch15Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch15", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NWF14", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1nofarm14Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1nofarm14", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NWF15", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1nofarm15Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1nofarm15", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8057023857040367`*^9, 3.805702508515811*^9}, {
  3.8057026696489244`*^9, 3.805702672790571*^9}, {3.813581464557933*^9, 
  3.8135814666373806`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EWP20", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1EWP20Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1EWP20", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch20", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch20Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch20", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NWF20", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1nofarm20Left", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1nofarm20", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066455240449734`*^9, 3.806645561301324*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fitch14B", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch14LeftB", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch14B", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch15B", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch15LeftB", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch15B", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch20B", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch20LeftB", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch20B", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8135814808821316`*^9, 3.8135814979696255`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fitch14C", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch14LeftC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch14C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch15C", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch15LeftC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch15C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Fitch20C", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"tsFINO1Fitch20LeftC", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".32"}], "+", 
    RowBox[{
     RowBox[{"tsFINO1Fitch20C", "[", 
      RowBox[{"[", "1", "]"}], "]"}], " ", ".68"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8135814808821316`*^9, 3.813581527272245*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "EWP14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.8066449660131216`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "EWP15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.80664498619221*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "EWP20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/EWP_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.80664498619221*^9}, {
   3.8066458659893665`*^9, 3.8066458717350583`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 3.8066449994528246`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458955972795`*^9, 3.8066458957598495`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458830488095`*^9, 3.8066458912120047`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch14B"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_14_adv025.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449994528246`*^9}, {3.8135843930574245`*^9, 3.813584423607455*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch15B"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_15_adv025.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458955972795`*^9, 3.8066458957598495`*^9}, {3.8135844176699247`*^9, 
   3.8135844285699463`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch20B"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_20_adv025.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458830488095`*^9, 3.8066458912120047`*^9}, {3.8135844319859447`*^9, 
   3.8135844379121304`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch14C"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_14_adv1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449994528246`*^9}, {3.8135843930574245`*^9, 3.813584423607455*^9}, {
   3.813584460974019*^9, 3.8135844690772047`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch15C"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_15_adv1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458955972795`*^9, 3.8066458957598495`*^9}, {3.8135844176699247`*^9, 
   3.8135844285699463`*^9}, {3.8135844633270316`*^9, 3.8135844715715213`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "Fitch20C"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/Fitch_20_adv1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.806645004773591*^9, 3.8066450138064775`*^9}, {
   3.8066458830488095`*^9, 3.8066458912120047`*^9}, {3.8135844319859447`*^9, 
   3.813584473871108*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "NWF14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.8066450238546543`*^9, 3.8066450354886084`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "NWF15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.8066450418456416`*^9, 3.8066450600948954`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "NWF20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{"XX", ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/NWF_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "YY"}], "]"}], 
     "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.788601775081045*^9, 3.7886017923675227`*^9}, {
   3.7886019071039467`*^9, 3.788601991300705*^9}, {3.7886680410887117`*^9, 
   3.78866804444166*^9}, {3.7886723032078094`*^9, 3.788672343440233*^9}, {
   3.7886733028726425`*^9, 3.7886733232967587`*^9}, {3.7891916851877823`*^9, 
   3.789191737055984*^9}, {3.7891922054970922`*^9, 3.7891922077400994`*^9}, {
   3.7891925543106165`*^9, 3.789192555567258*^9}, 3.789471265478546*^9, {
   3.7898180469408336`*^9, 3.789818092558813*^9}, {3.789818198314101*^9, 
   3.789818247429124*^9}, {3.7898183834907956`*^9, 3.789818386080798*^9}, {
   3.789820973349383*^9, 3.7898209735032*^9}, {3.7898210049294796`*^9, 
   3.789821106894457*^9}, {3.7898211769007883`*^9, 3.7898211881936655`*^9}, {
   3.789821257669681*^9, 3.7898213464813166`*^9}, {3.7898214438986692`*^9, 
   3.789821452107294*^9}, {3.7898215082344823`*^9, 3.7898215737112727`*^9}, {
   3.789821603782442*^9, 3.7898216630162725`*^9}, {3.7898216992017326`*^9, 
   3.7898218905724735`*^9}, {3.7898221399356565`*^9, 3.789822201814659*^9}, {
   3.789877659250369*^9, 3.7898777232431917`*^9}, {3.7905067305884514`*^9, 
   3.790506731327385*^9}, {3.7905067717837515`*^9, 3.790506831909546*^9}, {
   3.790506963958531*^9, 3.790506966599407*^9}, {3.790764018611129*^9, 
   3.7907640269597178`*^9}, {3.7907640976525373`*^9, 3.790764097797885*^9}, {
   3.805699051757305*^9, 3.8056991532829514`*^9}, {3.805702525896347*^9, 
   3.805702557554715*^9}, {3.8057025931314774`*^9, 3.8057026107054977`*^9}, {
   3.8063762817378736`*^9, 3.806376281832588*^9}, {3.8066448055258694`*^9, 
   3.8066448698291674`*^9}, {3.8066449295464754`*^9, 
   3.8066449660131216`*^9}, {3.8066450418456416`*^9, 
   3.8066450600948954`*^9}, {3.8066459080978384`*^9, 3.8066459134605527`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "wstest14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"XX", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/OBS_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", "YY"}], "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066465957618213`*^9, 3.806646644182521*^9}, {
  3.80664668869166*^9, 3.806646704775715*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "wstest15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"XX", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/OBS_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", "YY"}], "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066465957618213`*^9, 3.806646644182521*^9}, {
  3.80664668869166*^9, 3.806646722359767*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", "wstest20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"YY", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"XX", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "i", ",", "3"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/OBS_20.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", "YY"}], "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8066465957618213`*^9, 3.806646644182521*^9}, {
  3.80664668869166*^9, 3.8066467317566257`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP15Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_15_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056997139003973`*^9, 3.805699727071128*^9}, {
  3.805700041693468*^9, 3.8057000637644844`*^9}, {3.805700376347543*^9, 
  3.8057003773509007`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP14Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_14_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057000877643023`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP14", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.805700107376812*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1EWP15", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_EWP_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057001177660675`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch15Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_15_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056997139003973`*^9, 3.805699727071128*^9}, {
  3.805700041693468*^9, 3.8057000637644844`*^9}, {3.805700376347543*^9, 
  3.805700404227002*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch14Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_14_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057000877643023`*^9}, {3.805700404236977*^9, 
  3.805700404244955*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch14", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.805700107376812*^9}, {3.8057004042559223`*^9, 
  3.8057004042639008`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1Fitch15", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_Fitch_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057001177660675`*^9}, {3.8057004042738733`*^9, 
  3.8057004042818527`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm15Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_15_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056997139003973`*^9, 3.805699727071128*^9}, {
  3.805700041693468*^9, 3.8057000637644844`*^9}, {3.805700376347543*^9, 
  3.805700404227002*^9}, {3.8057004577923517`*^9, 3.8057004577983007`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm14Left", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_14_Left1.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057000877643023`*^9}, {3.805700404236977*^9, 
  3.805700404244955*^9}, {3.8057004578082743`*^9, 3.8057004578142586`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm14", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.805700107376812*^9}, {3.8057004042559223`*^9, 
  3.8057004042639008`*^9}, {3.8057004578242297`*^9, 3.805700457831213*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"tsFINO1nofarm15", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "39"}], "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "6"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_nofarm_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"z", "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", "39"}], "]"}], "]"}], "}"}], ",", "test"}], 
      "]"}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8056996238663044`*^9, 3.8056996623203945`*^9}, {
  3.8057000818440943`*^9, 3.8057001177660675`*^9}, {3.8057004042738733`*^9, 
  3.8057004042818527`*^9}, {3.805700457840187*^9, 3.805700457847169*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_OBS_14.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"wstest14", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "3"}], "]"}], "]"}], "]"}]}], "]"}],
      "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<c:/testdata/ts_FINO1_OBS_15.dat\>\"", ",", 
    RowBox[{"Transpose", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ToExpression", "[", "#", "]"}], "&"}], ",", "Fz"}], "]"}],
         "}"}], ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"wstest15", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "All", ",", "3"}], "]"}], "]"}], "]"}]}], "]"}],
      "]"}]}], "]"}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.8057003261936455`*^9, 3.8057003664160995`*^9}, {
  3.806376325883372*^9, 3.8063763259781218`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<c:/testdata/ws_100m_Fitch_Fino1.dat\>\"", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"wrftime", ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"tsFINO1Fitch100m", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1", ",", "All"}], "]"}], "]"}], "]"}]}], 
        "}"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.7905052884333143`*^9, 3.7905053879891605`*^9}, {
  3.79050626212634*^9, 3.7905062683697505`*^9}, {3.8135813262205944`*^9, 
  3.81358133089495*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Examples of plots: figures from the paper are prepared with the same data \
using MATLAB SCRIPTS, which is also included.\
\>", "Section",
 CellChangeTimes->{{3.816923181781724*^9, 3.8169231876966333`*^9}, {
  3.816923550665338*^9, 3.816923586911745*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XX", "=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Flatten", "[", "xlond03ToPlot", "]"}], ",", 
        RowBox[{"Flatten", "[", "xlatd03ToPlot", "]"}], ",", 
        RowBox[{"0.5", " ", 
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"fitcharea1415C", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}]}], "}"}], "]"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"6.5", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "7.5"}], "&&", 
       RowBox[{"53.8", "<", 
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "<", "54.2"}]}], "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListContourPlot", "[", 
    RowBox[{"XX", ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6.53", ",", "7.4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"53.85", ",", "54.18"}], "}"}], ",", "All"}], "}"}]}], ",", 
     RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Contours", "\[Rule]", "10"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Longitude\>\"", ",", "\"\<Latitude\>\""}], "}"}]}]}], 
    "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "3"}], "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"Drop", "[", 
          RowBox[{"farms", ",", "1"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Fitch 15:30 adv=1\>\""}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7891926883740296`*^9, 3.789192706512515*^9}, {
   3.789192838814603*^9, 3.789192881190255*^9}, {3.789192914515173*^9, 
   3.789192919379161*^9}, {3.7891929640189376`*^9, 3.789192964653288*^9}, {
   3.7891930303412685`*^9, 3.789193031172056*^9}, {3.789193178310893*^9, 
   3.7891931784495354`*^9}, {3.7891932145888805`*^9, 
   3.7891932151992598`*^9}, {3.789193317341813*^9, 3.7891933322888093`*^9}, {
   3.78919355994938*^9, 3.7891935604540243`*^9}, {3.789194581399146*^9, 
   3.7891945817820883`*^9}, {3.7891946864630933`*^9, 3.789194707541705*^9}, {
   3.789805829627242*^9, 3.7898058388326035`*^9}, {3.789805921812013*^9, 
   3.7898059235530205`*^9}, {3.7898059776089993`*^9, 3.78980603383108*^9}, 
   3.789806128712236*^9, {3.789806246139863*^9, 3.7898062465253983`*^9}, 
   3.789807046544841*^9, {3.789807388090448*^9, 3.7898073901950593`*^9}, {
   3.789813443348075*^9, 3.7898136168392515`*^9}, {3.78981375265234*^9, 
   3.7898137527682047`*^9}, {3.7898137853549557`*^9, 3.789813862301978*^9}, {
   3.789813904310199*^9, 3.7898139049429293`*^9}, {3.7898140682941294`*^9, 
   3.789814068848768*^9}, 3.7898142130008583`*^9, 3.789814569482603*^9, {
   3.7898149184411564`*^9, 3.7898149190964503`*^9}, {3.789815054050105*^9, 
   3.789815054197209*^9}, {3.789815246727021*^9, 3.7898152494776464`*^9}, {
   3.7905018642897882`*^9, 3.790501864489352*^9}, {3.7905019270047636`*^9, 
   3.7905019422972574`*^9}, {3.790502045641757*^9, 3.790502054276376*^9}, {
   3.7905022463956175`*^9, 3.790502246768867*^9}, {3.790502440570092*^9, 
   3.7905024545356026`*^9}, {3.790502548278941*^9, 3.790502548675728*^9}, {
   3.8135750935631456`*^9, 3.81357513955066*^9}, {3.813586602226976*^9, 
   3.813586622961609*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{
     GraphicsComplexBox[CompressedData["
1:eJw1nHlcjF0Ux4cWJVSi8jwTQ0r2QlrlipI2pbQomhIqqSSULNMikSiiEA2J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      "], {{{
         EdgeForm[], 
         RGBColor[0.148, 0.33, 0.54], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNmHl01dURx+/v5eXFP8QAghVFSApIcCEoGlnEkACagEVAUGgwbCJLQEAW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            "]], 
           PolygonBox[CompressedData["
1:eJwlkjkvRFEUgM+7781Mww+wFRrBWAoREcvMEDEdUUk0gihI8APUOqVQikqB
xA8QjUKEkRj7LhjbFPa18Z2c4st8Ofe+c88yxX2jXSNORKIQwKwvkueJ5MMK
vgmFeBGk8EcuL3FvER7we2e+AHf4nG/fFsAqvuaba451PAGf3P2CJH7NN0P4
MNzgl5AUi13hPWGRMX47IYLX8M0LZ69Qi98SnxSrSWvrDYls8FYWBkOGei5n
MyHrQXuJQca3GrQW7Xkcj3Jn3rMc1fgp31VyXgEn+B6U4RFI4/tQLhbTsz/Y
FquxVPul5g5nPbTiDcTeOHuHRrzJN/+AZjzDEiY8q+EZT0IC74duvM633jVH
PX7obHdawwE+zZ0Bz3Is49/EtjhLwQ8eUEOVs5rCeMy3t3UncfyceInYDi7w
J2e71RxZPBWyWWqOND4VWG36pr694+x/pDnO8JbAZh2HNnyXWI7YTHW2unPd
ve5Qd/nrrFadoc7y2NnstccjvD2wXDoTnc0/iTFf7Q==
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.31339984019106276`, 0.4138465892045269, 0.6348384326033369], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNl2lslVUQhm+/e++RtvjLNWqiCC6hFJCIGPa9lVISiSaof6DQFpTForiA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            "]], 
           PolygonBox[CompressedData["
1:eJwtlMdPVVEQhw/n3XvCE3VjjbqQhZqAiCBVabagYEwkLrBE4WEvYO8d3Cga
JSEhxhhL0Kix8AdYVkiTRE1UNFgTBBHBstEY9ZvMXfze++6cMnNm5pzYSEVR
uTXGrEAe6uCnMsqYetQHd6Fr8HHUANd6ylWoBh7vjNnFBjvRWDgfW4SxUjQX
Tsd2kLEDKBVuCxmTw1g2aoKHYdvB2HY0FJ6M9sJ7UDy8EtXDVagYTvZ0reyR
DofZ4zNxN6OvzIniu8eozYfzWHMU+xGUD2djG8naESgLno7tkNUYM+D72O6h
y+hKSM8oZ5UzFXuaE8lNIxrnGzOLNces+pgHL0Gb4FNoKfyS/zCxDJLcwq+s
cgx6DV/HRxx7hdEfvkvYsxduRolwO0rAPhhdgBc4zUUlKoQbsYXhOPQYLnA6
JjHNh5PQfngfmgpfwt/F4Ixy1lynuTmMsuG72O4Ec2RuNLZFjG1Fc+Asp3Ml
ZzPgN5JXzjIBdcKJTn1JDRPgFKe1lxiS4eXoLNyAMok3BR/TUCpKQ5XY/nL2
TlQGV3vaS9KTN+ACX8dkTgQuRd1RmoPT8Hn2GMX3aHQLfmo1NtA8gdPwX2i1
RjnwTFQBL0TOaY4l11KDOjiZhUlBjBLrB8ZOstd69D7IieRGziRnK0FXrfas
9K70tPR2ERoCL/a1dyRmiT03iFd6MgdeENJe6Gb/Ptb887W2EnOI9QP8tzDW
ir7D3UE81agHnsic3VbvZCxcLncObkWb4Q5fY5GaxvC9BjXBj9Bq6V2nc1vQ
RjiDeNJRptwVtA1bu/Sa9AQc5/Suis9JTmOW2OUOStKf8x1t9A68gMc4fSvk
zg93WvPUwIf48pzWQnr+ma93UO7iA/QQbXHqW85UAXfxf8JoDj7By7CdsVrT
2fAU1vQzNoAS4Y9WcyXzpZY1IX0LJP+18DurtZWefgv/trpW9vgFlzm927fR
KniD01w1yzrpp5D2ntQ0D+7FftNojBLrD6u1a0M/4brgPZL55+B4X+++vLkD
ntZEaiM9FXHqU3xLDaQW36zuJT6+WH0D5S2UHumH1zmNTWq8Fv4Phum73w==

            "]], 
           
           PolygonBox[{{926, 280, 892, 943, 944}, {759, 758, 760, 239, 799}, {
            826, 825, 827, 277, 885}, {1082, 318, 998, 1087, 1088}, {757, 204,
             753, 758, 759}, {816, 240, 808, 817, 818}, {1088, 1087, 1090, 
            353, 1109}, {960, 959, 964, 317, 993}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.44802477161903465`, 0.46115886542521983`, 0.5556978978341778], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxNlllsVWUUhW/vvf8RMSpQWksFLIkDoEIZOlBaaHyRFoyCLdjK1NapLYJD
RMQgsQlSWvSRdyOJgFUTE02o44P4pIkxMYbBB0LiBC2OMbEl+i32evBhZf1n
n/1Pe6+9z5nXvWvDznwul/sGFMCiLJfrxbACXgk3gErQDLaD1eAyuIjvOPxs
yuXK4Pfgpcx5mPFy+E7wEOO74DWgi/E9soEDjLdpfbCVcWMW624Dq8CfYIz1
/4DPlORyk2ACNBc5A9wAf89hVzIuY7wCv1k+62fYG7G/UYjzN4LN4Gb2aIer
4PVe5yB83v6ap72bwBz5e67WuJE53XDK4ixnwZWS2E/vdecbePcgXCqfFPE6
l8KnMx9n3MC7V+D1cIVt9aAPtIBW2zpsF+rATflYexlos5/8F4Aj7HEN/GmK
eNd5Xg2oBRuVD8/T/H72PgHvgFeBfvnB3zF/ieINt/F8UHvCwyliO5AiLpO+
u/acAuaDvbwrh59PsWe5z/Eo89+EH4M3+Tyyl3lc4xjPdtzHratrycUp9vhc
eQR58rQD7oGfZq238XsGnms9Km+N7P0OPqPFiMMm7zU/hYbWpDjvD4x/BK+l
4C54i8+hM8zm+Sj2sWLcbYrjfNRnGQBfpbB9kWI9+SgevzHnI54vw98Ww/8X
eCRF7C/AH6TIx/vw9daMtKP9tMfpYsRFeWs32pzDdrPea235K07jzPkQvlQM
LXa6Fi7wfBL7DPYatW71fLEYzz/DL6fQ4ksp1lJMdKd9KXT3IvwC+ZiObS98
3jqRXiZcm8pfO8//MN5j1jvV0HVZ+J/G/mWKmE6kuF+t81RvzStv1SliWJEi
NzpPW4o62+xa22/NH3EeWqzDCs9VHna7L6k/dbiuFJc660R66cLvVcYfOx6K
4bmSqFvV79dwIYt6+zdFz1Lv2u76GATH8lHTepbW1/KuB16XxdraS9o9UQzt
HFaeieNaxlMZd+J3WPc3j4BhQ7Upm3qcet0V5lUVo1/dVox4SLfS77wsYnq7
e+oW67k+i3EDXJPFnDr7NLl27s2itzfDM7PQWyXclEVPXg3fnUUcF7vu1AvU
B+5wbS+Eq7OI8RK4xT2z1f3mEBgCxx03Pff5nrJLK/rOSDt9vrvenbIe1Qum
FaI/lMGV4BLjqkLoTzqc417S6PV6vceQuddaWcqcGfhXw++6NlWjDTzPxF4P
j2Gbyngd41sL8T1aAN8Cxhn/7XUPeV2d9S3bnsxivBO+rxDrtMG1oJTxcnhh
iju1uK/OdS76eTcN++5CfJA1V2d5wNq7H17selwEd7vHqtf+5HpX3f+ej/j8
am0esz7b/e3Tt1S9UvqcLMb3+aoG8pGv477boGMyDD+exTpPZNF/1Ycf0f9C
Fv59to1Yt7qP9LPVemlyfspcI9P9PT3zv2/qWdfgVd35TBuz0Ex7Fn1tlrVy
0v6a3+G+oz7UnWKN1hTn05l6suhn+iaUOx6Dvmer9dbnd+pL6h2lzpFypXwr
73/BA87jAbjFOVKen3OspKNP/H/yeiFyqZzuKYQuhh0jnX3U913mmJT5nOrJ
9WbdV/1rn3W7H96VxRpP+T+t0pofsg6Vwwn3Ztn/AzFYFGE=
            "]], 
           PolygonBox[CompressedData["
1:eJwtlVlsjlkYx9/vfb9zbJMMtQ0mppLJULRolRaDFKHqYmhrptYuE8vUfjFj
iDFjxhZVSWUWtV1ME1pqS0wyZiwXuCLcuCCuSCxTWwY3tOH3z3MufsnvO9t7
znOe83yDqlfPWRVHUbQO0rDYRdGDVBR1onEzXgYP+X0FhuM/Qgd+F6rxmc78
H8jGt0A/5n4EP+GTfRRV4lUwAz9L22g8D07ij/noOeb+DY/wGbTdwd/CPPw7
6MPY3vAtPoI1KvB5MBJ3UB3W/wAf5a1vPuTib5kzBC+GmN9joBafCQk+CRbH
tsfpeEsSRc3Qzu8OuO9sr6VwT3v3tvYCyMd7eusrg17evqFvLYccfBwsxBfB
eHyCN9c3P8eLvO1dZyjGh8KX+FcwDB/uzXXmbHyst29rzQL8BnuahA+ES3gm
beX4XBiE19HWP7Y72YVfdHa3isk1vIYxrXidYor/xx38SewvQ0/6Z9O2jb6t
8AXeA2rCfj/EzzEmP7Y7/Qt/5yy2WXDd2Z3ofJOhXX3hvrRGCX7TWZ/OoLNs
hL6x3fkG/DNvZ1FMBuMHuZsD0AonYB/8AY2wH3KgB3vvrnzEC6CXzgJj8K2J
udp24B4cdIVusD6xuVrje3xDWC8DNuGv2ccz3slTeBXbNzRebZ/go8P6Gp+L
b07M1bYFL+cMO5i3XTmD3ybeTeqDFnw7VIbfTfgaxhyP7Y7W4h2sMZ6+CZCp
u0rM1XYBX8WYY7HNWY1Pg6nKGeUhZCW2d+13GJ4JT8J5Pk2sTX06Uy0+Muxf
MRiBv4xtrOb8rzdFWyrEULGsCvlyRDmiXIadsZ15Lr4MjuLNeiP4eu74Tcpy
VLmqN6+3r7YKfJ+z3FbNUe1ZGM5SiI9zFiPFSjl7C38R297a4HlsOaJcOQSH
Q440hhxSLu2BemiAvfALa/6sdwFfw1VnudwZfneGXDWxHt8PjWGO5hY7ezuq
oaqlqpmqnbrjj/UWvdUKvdEB3r6hb5XALFjiLXaK0VL8OWf6N9TXZ/iTtLlq
Zht+HnbjKyDG2+FEytqq8AxntVU1dYizGq35WjMHTzOmJMxP4b8Rg1/Dm9Lb
6p1YLBXT/niht9qmO9XdVnirHaqpE/Eu0DnknHLvjLParRqhWlHprZYoR5Qr
K1RzY8vZlfgPzv47VAM24aXe3orGz8G/8ZY7mlOL57HnXBgLBWm7w4ZwBp2l
LuSH3lQ5ngPZYY7mTmFMUaj5LSFHlCun4DTUpC02ilETv98DsfDNZA==
            "]], 
           
           PolygonBox[{{1498, 561, 1547, 1544, 1545}, {765, 764, 844, 266, 
            841}, {945, 944, 929, 315, 989}, {1614, 1613, 1612, 611, 1587}, {
            907, 276, 885, 910, 911}, {1061, 316, 993, 1069, 1070}, {1615, 
            645, 1624, 1613, 1614}, {1080, 1079, 1082, 352, 1105}, {1504, 
            1503, 1497, 561, 1505}, {779, 778, 777, 235, 784}, {1506, 595, 
            1549, 1503, 1504}, {1034, 331, 1028, 834, 835}, {1356, 1355, 1326,
             444, 1328}, {852, 266, 768, 769, 770}, {1472, 542, 1433, 1434, 
            1435}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.5826497030470066, 0.5084711416459129, 0.47655736306501856`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtlElIlVEUx7833EeBTWrDIooiyDYtdKMtGla+NqU2UZtH0QSB7spmdNOi
dob5sojKaBEYBZVENNC2UCvLJwhWRiMVPHsvh6jf6fwXh9/57j333DPdb8mu
pobGeBRFjUgCCckoqolFUYGPrako2s/mNjg3RNFr1sthFptz6B3wFnar0C/B
Ddjtxn4jLLI2EPMzA9i1wC54n/Pl2NyGXUgl+lU4yd5NbP7CMfgCeYnMCe5n
dvA4LJ4aeBa7dtbbYB3fe1ivh4Os3UNyyGX2Oiw2eB3Jol9Lus048gZp4Mxe
zm5KuT/LqwfZqXim4Cf5+Qw7ybMaPfu/WG7zgPVn6Mvx8wh2832e9RuwAF+p
FrPYewpXwD72rqB/hGv5zqM3Bc/Z7H8hpUmv7Th3xYPXZA0clH+7pxrJoFfB
KtXf+jCBXS16DD2D/gGb9XACu1701RY7UobNHfOpvH7Cevk0322qcy8swdc6
7IPVnzMp9IewInjNSnWn9Whf3PO0fGuD99VqZTWLcz7N/iT6geDxWFzWt3bV
/7ty/AE3p9zfFlihfi2DI5qfd/Cr+vsN5sihEn0o4T3+rTm0/ti9FuOQbPrh
n+B5jVosyGL0vuBzaLOaV12sPnk4rFhnYrNSuVhOx1QTq82ofPbbPCT8TV2E
nfL/GCbUU+vtjuAzm4Yn1a+M9i0Oi2F+8HzmwSn5t56cDj7PZ+CR4DN3FD5X
jlaPJ7r3Alyq97Io5XM2prfWErxWrcFrarV9L382v0W9mXHVtE5z0pr0fMy/
1c/mt6AZzuk99uj923/gFNyufC3vYf1D7F/yVveOKJaielcW/L184ezB4L4P
wel6M9OC52+xNcNGzXY3vKt/jv17FuqNLIDHg/s/Idu8+n1YdWtO+KykNdMz
lFsJ/Ae+kLwH
            "]], 
           PolygonBox[CompressedData["
1:eJwtlElIllEUhj/9/vuXTf5aWlmEhTZYNOzKFgUNmmSDadAigzINClsEFQ1W
lg0YFCSWRUiDBAktgoZNtmhZUFRmA60iGgnK5lB6Xs5ZPPB+9zv33HvPee8d
v35rRX16FEW1kIBUiKLutCh6CkPRQ+IoGgwpyIKVySjayIRaqEDfJWYSOgmt
6A8kOcPcNviEziUmB7IgG7qCxWrOfXQaYyXoOpiCfs5YD7yEVzAenpOrB0ai
x/n6NTA2aTmUSzn+Kp495kMBFMIgYjJgESyGG8QMJ3YE3ESXwgty34bJ6DnE
bOJfKUz3OZq7FqqTtsc6P/9kdBFrTIGpMA0ayPGLXL/hALogabHa8wR0LjE5
kAdjYquJapMJKajy/NrDavTypJ1V81egV3k+xVSiY3KkQxIGQJXXS2dag35D
D06nWU/eo8sZWwozYRYsZM4CuAqdMJGYQpgOM9Q/yIE+/vXDRubUeA7lKvRa
qwZFvoeke0beafV+v2X9feiP5Lqo2kA3+l+wWquHD9APGWvl3y14jT5GjqPQ
DMfhnc+/B5nEdyTMazrfBXQnnHX/XUGXMWcJlMMyOOP10Bot6AbG9sI+2B9b
j9XrYnLPhR3wg9ifsEv3IdjdeAIZ6Nxg3nwGOcFyKFcjHHRPyBubYQuMCBar
O5Ylv7KHfK+5ar/FY7fDDr9zKfeMvLMbdvmeG9xDee55eb8xmPf+QHOwM+vs
lfIGnIQTcApa1CfWHJQwD8gLO4PNlYfkpSqfK4/Ja02MHXIPyAsxc9NhA9TA
7mC10h3YG6wGqkUTHIbRjI2Cr8R+S5gHZ/qY/h1JmDfWwUp0UbBeq+fD0UuC
eUlj+tePb/rSrcdl7lF5VTVVbbvgju9Re21MWG6tcQm9lRy9afYm1AfbY5N7
Tt5rh2L+z4Frsc054Pt5hK72/cjje4LdId0l7Ul7ux7srflOzDb0wGDeeQxx
ME83e0/Umxqv5WV0hyOtHqlXJV4Pram1P7v/5fkv6GHB7o76p7ezxXvdCqf1
3gR763QH9Db0Mjbbzxf4bvf3W//bErZn7V13YDv6fGyxmnMutjdab7XeWL21
P/2/apbN/HnBzqoaz0f/B94dt2A=
            "]], 
           PolygonBox[CompressedData["
1:eJwt0DlKQ1EUBuDjkLSKkpBO3ICBpDAEEdyBuIEQsRO0Mw6tbkFx6LRU08cB
XEAwqUxhCnEBop0Ywe/hLb7333fuxLnz69trW+MRMUOOG59r3qmYuJJ9VoxH
8pUhpXzEhlpVFihSnoxYoEpjLGJVfk9E1I2HsuC/yB0dRrTN/cjLdN+bfGHA
iT3HnFKzbiC/rP3kg7OsJu/TOU35wCM1+xdZ4tncpmzZv8MuFbWuvFWfdW87
9Z31f8Gc2rk85Cj1nPXeS3NPcjmdnd3RSX3109l7cp8Dpr3NFLn8/zv+Wv8H
rJ4zng==
            "]]}]}, {
         EdgeForm[], 
         RGBColor[0.7172746344749784, 0.5557834178666058, 0.3974168282958594], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkztoVUEQhjees0GDmhh81GkSFUHFQkFQUbiCWEgsrEwRsBBDUsQgPpAg
mE6rKxHUQmIbwXhNo0YUFB8Ec1XixVcV0CKI0UrFx/czfzF8M3t2Z2f/mdPR
O9DdvyildAgrsEpzSt+aUmqBk/AOVsX+5JR2s7GN9Rni79gCdppDW2C9iFjr
7exrEG/FH4U/OVvRJZx9VqZ0nfU52MCu6Axck+O+DvjJOV8VEWt9OTzrdd35
1vnn4TK+3cZvg++cswYPwuNYN7aHeBAOw3XNUU8TvJGj3nHYgj1iTxf8hXWy
/iKHyZ+Cs5yvsec1fIzdwn8If5ehy124H+vBPyVaT+k675q/wi/W8w08Styq
WuFsEfVu4uwHv1d6HMuRZxuc4ttF/Htwmm+b8U/Av86p3Buccz1sEK9gfQxu
dG2d8CN2Cf9lGf1W/vfs2e67VHuVb0P4l8vIseD+/rDO0vu+9XmeQ3PVr5pG
iP/BPtifYzYGcmgkrXbgj+EP45+DZ4jndC/chdXxd8LC79W7H9jvdY66Z27G
eZSvx3n2KkcZszEND/jt0qDI0bvF8LzrvArXejY0I12eh0qO2dEsSa/WHDP8
uQw9pIv0GrFW++A155QGo+57Fa7K8U+tzvEvqV/t8LBrPql54/wE/hP3R/+f
7r9Qhv+0jFoGrXWfe62ea/+kz6gXQ6573HN+Ey7JkX8pPOI6pUHNPZ1Qr3PM
+Ur4H0YZjL0=
            "]], 
           PolygonBox[CompressedData["
1:eJwtlF9MzlEYx39v7zkJb1LolaIVtbmTOzfYkC0Ty5gbLowrVhcym6vIGJMx
uWAzQrHV8jdXNrIxtKbYwixXzG1hrNdWPt89z8Vn+77n95xzvs+f81bta2lq
zkuSZDcEKEknSTGUQhYusdiaSpIj0In+zNoOdB0MowtgFmSgEDbBRuiFPjjB
njZi98J29CpoQh+GDehdxOyENATYBo2+pm8zmJuGBvQWp8FjFDsD01DFWdVw
Fn0GzkGH56BcyqHCPWY8R+Varb1QA7VwLJhXeb4W7AyddQEuQlsw753QESxH
5SqP8pphbW6wGqgWv+EXRNby4TT6lHuU11Yo8noOoVP5SVLPObWQi0nyl7U/
8sreBZBDTykndDbYHu1VTcfS5lneu+AN+rg8Qzuc9BqnvWfq3dtod+nOKXRD
sF6rx2vQN+A6XIGrsJaYEb5NQo7fB2A/dHNWDyzFfwUshjJYTXwdlMESeEXs
Q/Y+gJfolay9cL9F6BnWRlN2xz/0TehyD/KSEHM/ZTGKXc4d1bAMKmEe35/w
7TKM8/0Wv4vJrQRuo++ydkd+oQcm8TzhPVKvKv0s5aBc+qPt/cl5zeh69/sN
9qAbYavnqFxVE9VmAg7y+3kwv+fhWbAaqVaakYzPhGZDPVavW6LdpfzWR+ux
ej3ts34P3Q+9mj2fCc2GZkKz8SXa3cr5E7ogWq1V89no9zAK4/A12pso9zeg
t/A0mFd5Vq0XwmP0ACyK1lP1thSy8C5YrfUfof+K+cQ8StmeYvTmaLVSzdTr
4WDf5WcomAd5GVRdo81ou78RvZXBYP7lR7XMRNurMwrReT4Pikmjv+s+z1G5
/gg2W3oTI97zbp8pzdbrYG9Z+X1EH/X3pDd5KG1rA57PGLqGnFf4zGn2+rwX
minNVmm0eM1gVl78fuU/h98fgp0l/6PoddF6rRyUy39PF6+0
            "]], 
           PolygonBox[CompressedData["
1:eJwtzz0vw1EUB+BD6SrpQHSraCNWg1gNJgzshkYHiTAZJCIsRiGpRIuvQGIn
4RtoJIqOtYoye3n+cYcnv5t77j333FJ1c2mjPyIKDPKai3jhgam+iI485og6
0/ae5MxAxLL1czqf3Yt8xJxmE3KcMq3UZ1fusc+jh2ad+5Zd3jihzi0VtRu5
zq+7NbnAYlZzv8wkQ2prsmh/lE8zndn7klUOrXNylRpjlKiwojYvR8w4TCH/
P9OPPvfccZ7ev5Dv6e9t+UGP7Wx+eztp9uwPTT0bnLKldiCv01xteckVf8/K
MZ8=
            "]]}]}, {
         EdgeForm[], 
         RGBColor[0.8518995659029501, 0.6030956940872988, 0.3182762935267003], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtks8rw3EYxz+273dW/gA5CLGTi4RyUMo4UFZLHJbLSkp+HDbkqIQmseSi
lJS5OLk4SLZpLLutbAdaQkmUUg4ueD19nsOn1/vzfJ7P83ye5/M0RefCsx5j
TC/Ly4q4xjxXGROHyxg60EW46hizgN6Dw5xV0NMwpLoH7rJcgi3BMn472PNw
nPs16AjMst9Gz8NT9q3oM/jLnT7u1vqMCXO2iD0E2zW+5Czj14VOwnP2Afzz
cEP95Z7DPoNugYdqT8Fqtcv5ur7tBl6yttBp+ELcTvQr/NT3fMBH7cMT7MZv
BD0IrzhrxOcI7qvOwjd95ztMsWbQE9IH7e2Aa+uXPsQcW7PkqoP3Xhtf8kw5
9q4fNnPWj0/AZ2uTWoKwhH8bugDrOQvi0wATWqPUmtYaM/BC/0j+qqB34zCh
ta957VslbxRWtK6ia2sTLTa//qkDS5pL/vzPY//0BHtM4+fgj/7XrWtnSGbp
AI5pHJmRFe2zzN2QzobES2o/N+G3a2v8cm0vpCfGZ3NIrjs4qTMjs/mg/ZS+
HmtMmbuc9v/asTXIG0bhP7x1YPo=
            "]], 
           PolygonBox[CompressedData["
1:eJwtk0tI1FEUh2/N//6FzBYpNPkgdEi3BdXSjaOLGBPCXbRxp/RYJIq5KYiE
wIr2RbQqKJJRVxExi0DtAdW4sZ35SCgldTB1Ud+PcxbfzJl77j2v35nmvusX
rx0MIbRDAuf56D0QwhDcxT6RhpDnQifksJ8m5huGZ9jTMAVFmIRRuAmP4Qnk
oQNuwW3oSeytYlxQwtRin4TdGEIX/MBXgjbsLHeOwb+MFVgDh6GT312wGa2+
DtjArsKXwg6+vzDPWRmWYQUm8L2Gl/AqsRpUi3pu9xpV6zjch9/E+AXrsAFz
0WqN8Bb7eGq5VUNTajWq1ha+c7CJ/Qe2oQJXOHtArqswgL3P2V7GelSvq9hn
8Z2DNezTnJ3yGWqWfYm9VYx3PmPNehbm4AY8dL9y5aPNUjO9hF1LzKPKB1k4
AjV+Jt+gz1/9PcL+TowF11haL8MSHMJXDeMZq1U138Ouw1ebWE/q7TP2J/gA
HxOb4brPRLNZhDP+fgn7K3e++Bu9rfjspGmV9zjrNagWaSytlVO5d6Ltk/So
RNvJomsu7Zu42yh9IAdt0Ar9MJAxzaRdAbphJNosNJPL0c4KvuPa9ZzHavVY
a9z56Tun3RtzPdXjHewZ3x/VqFoboB62iLXtO6ndfA4voAzffCaaTda1Uw/q
peT7JM3fJ6ZZ9P/Tm2gxt1xDafkfO+WCag==
            "]], 
           PolygonBox[CompressedData["
1:eJwt0D0vBFEUBuDLmthYq1LRUCk0iOhohEaxIkKh0wjxUZD4BySESNRKi0Sv
RoKEarEaWRpCrL8gnsnc4sl7cs7MvWeme35tarUxhNBOwk8uhKGGEF5knV8e
mkK454YDsyt5y6G6Kh954tMBH1Tocui1LNBCD5eeb5bHcX4kt9hmyT2LbNDn
uXV5Qa96QpaYZMQ903qv6hpvPMd3qmma95NnRa+s16ouMq4e4zyeeyLnKKjz
skhbLtsn3WuZmtlCkt2T3ldhUO9dDsf5gOygkzqjvu1PfvGdZHun+8/Eu2bl
mX1OKbOptyv32eMu/tsd+Q+SzzV5
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9138218046854508, 0.6545545117136271, 0.33284759452489754`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkb8rxHEYxz/u+3y7QZlsukE33KCUrJgsEiJ0TrfcQN1Ax+J75LpkoYg/
QFaDUspmYVCSgbuZG0y6rkRZlNfT8wzvXu/v8/k8Pz7Pt7+0PreWCiEMogjd
SAjVrhCO4TuBBfwbLPK9jJ+Ah2gLfwEP0Ab+CD6iGv4MTqEiPgvb5Ofxn3AT
9eDLcJ+zU/ye2D29H8Tqav1LOOL1EzgtNs8MfCV/Fj+AT6MC/ofYF1rCd+Ci
15mHu+gEvwNfvG8DPnn8GX6jW3xfbO/RvnU4LtZrCGZiu/OH7/Wd/Ea2I51t
TOz9uodtsRzNbXJ+hU/w12Iz6p7z3k9rjsJVr6n7bvicD/AeneNbYj20l+7j
zufXd5R9tzm44jsp6H5iy+2OTeo/iA97X31TyXMrkc2V+Gw5j2fhpP+jCvwH
7RpEOg==
            "]], 
           PolygonBox[CompressedData["
1:eJwtkjFPk2EQxx95nwYcoEMd7ACJiUx8BB2rTEbKAKWlDg7WqGjQYgQTiXGA
jUBHFxcoCwmhMZrohgM4OJjgB1BrpYHUYFASHPz9czf83lzuvXvu7n934eaD
0ftdIYRLEOE5n4dnQshDDnsaytjz8BL7WxLCV/gOTajiewT3YAo+pELYhlVY
gya+V57/EftpNFtvXsM+IeYvHMMfeIFvhX/L8Ax7F9+Oxyj2HzVP4Tz/stDA
3oI38BZaxPzwHtRL03ttwU8YJ2eWt5/AGPanaLVU8zP2Y5jxmTTbUDQtpMll
7I1ouXpjE7ugN6EMN7wH9TICeWh4vTl4jb0UzZ4Q2Cl6jHARBuEuvjvQA2ej
aSJtjuA3FPEVyS1BJVqOcnNwBYapeRXqsA7nICO9IJvYm3q7F/qi7Ui7WoBF
mCSmBH2Q9pnK7tO/Q2IOYB/aiocSVGEmZTVUqx8G4D2+d77DXe8x5zmTPpNm
68Av+AJ7vkPtcspvS5pIm7bX3vPYtPea8Vk7iWlbgMPEelJvK1CD21CB6zCS
spvWPepGt6PtRPnS+FY0Det+Yw2/Id3SPrSldbRa2rFu6zixXL1xlJjG0lo7
0W5OEtudYrqjzdxxTaVt3m9HN6XbWvTdVLz3ms8iTaXtf19NgRo=
            "]], 
           PolygonBox[CompressedData["
1:eJwtzz0OAWEQxvHBbnSiUFCQiCOoFRqJKJZdEolo9gAEIYhW4qPiBC5Bp5Hg
AKKi8FGh1SHx3+xb/PJMZuZdI27XzZpXRILQkdZESh6Ri0/khjtiiCKBADOb
tNgzYah9511DzVvkFjvk+aiBFNbMkuSA3Rn1hmyjgx6a9CbkCGM8ef/AC2Vm
GXpZVKhD5If+FxHqMARVZjnN/W3nhiMK9A7kmf4JS/TprcgrFtR+7tKg46e5
t77VvvOuiC69qfrflrrRuXWPObMh+QeBjCrO
            "]]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9353273847857658, 0.7083184619644145, 0.39951489283587394`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtkb9LA0EQhVf3Ugj+aGySQghY21lZiaiIVoncIaSQCGkkFwMKirWFlYKt
YKv/gFpYKuI/YCUWiij2ioWC32NfMXxv383OzO3U271GORhCmCIisZyF0BoI
oQp/Y9JL6JNKCBmJO/DGWt4m30pyunCUWEEPwZwo0AW8Ja9O/juc4dzHn87S
Wf4jXIzprmos+O4n3hp6H30EZ1UX3YRX9o/hW0z+K5yj1gs6hxeufwbvrOV1
fFe1C/dSz9L/UoNtao2gJ2DXeiumHuqlWc49s2bP3bcPxzkPo8f0fvbn4TUx
yQz38NDvsAd/7D9UUj/1qsb0/5rtAz6Rd4r+g5fW8pp+k9Us7UDzb8Nv11Tt
L+c/Z2mv2ql2u+E5OzHNKt2KaTeabRceWGvenu+uw3+11EBW
            "]], 
           PolygonBox[CompressedData["
1:eJwt0j0vw1EUx/GrvX+JhFgsJCQSutTGyDswtI14VonBQ0Tl3wQDamBg0l1n
XgChEhshZp0lmkiEkAovwPfnnuHTnJ57eu8957Z3YT1XSDjnUvBo4WO0ybkC
Vokfks7d4wk1FBFbTmvXqCKLHN4wwW/H8Up8gXOrUe0Be+6jhD10kmujthUd
xHVyL4gi55rxTFxhbRtXxHe4tRrVjvlw1v+ZxEP8ZhDd6MFiMuytM9aIj8gd
YhkrUbiz7j6JKZyRO7Ua1e6y5w42sWV3LllOa1/UfOIdH4hR5yzPUMvEj+hL
hO83xBtRiFUzaz2q136kdC/2XMIc8pjBtOW0duzDLDSTSx96UC8ZZFEhd2Iz
0qyKiC2ntS4f3lZv3E48gDSGMeLDDDSLPObxy54/aODbNKxn9V6z/0ba9ipb
f+q5anfK2Jvobf4AiHJMxg==
            "]], 
           
           PolygonBox[{{1439, 545, 1476, 1446, 1447}, {1085, 1084, 1145, 369, 
            1083}, {1515, 1514, 1494, 545, 1477}, {1310, 1309, 1277, 412, 
            1269}, {1143, 1142, 1140, 366, 1134}, {1039, 332, 936, 947, 
            948}, {880, 269, 866, 881, 882}, {863, 862, 860, 268, 867}, {1144,
             369, 1157, 1155, 1156}, {1120, 348, 1099, 1137, 1138}, {1168, 
            379, 1126, 1114, 1115}, {1118, 1117, 1097, 348, 1135}, {1479, 548,
             1526, 1523, 1524}, {1318, 1317, 1349, 482, 1347}}]}]}, {
         EdgeForm[], 
         RGBColor[
         0.9568329648860808, 0.762082412215202, 0.46618219114685044`], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxTTMoPymNiYGCQAmJmIK5nYWAoYGRgaAHSX1gZGJSBkseBtDMQHwCKqwFp
JSjbEUjnAdXlA9nlQPo1SA6o/h2Q3gnkzweKPwDSRUCD9YHsAiD9EWomyOwN
UPULgfQVqJrjzBAMYoP0lUPNrwXS26F6NwNpdai4LJC2BeIAIFsHSB+Fmgly
yxwgvw5kDpC2hqoBqT3PDGGrANlsrBB3PmKBqAOpTwDSR6BskBk/WSD+Bfnb
BBo+miyQMAKxK4A0ALx0KD0=
            "]], 
           PolygonBox[CompressedData["
1:eJwt0bEvQ1EUx/HLe8/aziQEKZFILPwfXAnRigqCJ9FXdsxM7WLVDZ0kSPs6
idgtZsQfIDFUYvP95Z7hk5zce8+55547vpX52qBzroQY7cS5W1yhhc3IuSq2
sWMU72IPj3hAjh6aFGmggnXcU2OSCyZwl4Qc5R6ihkvOnA5wH3LiG85c4xwX
SFnbxwaq+E5CLdX8IZ7Ck+UPWY5yUxxgAfMYxZhR3KfWLz7jkKsaf8QfeEcH
XXzZvnp8IT5BRlzHGXERhTjMQLNYhscaylGo0bGZaDYjGLacor1Jb8tQt5lV
7M16+ywWuWsOb9SbicPd6mHa3tC3ntV7y/5OM9QsPZZsBppFz/7KW69l61V/
rL9e5cwKjnBsM0ythrc17TXQxHMUelOPr1FY014XOf4BWFtLhA==
            "]], 
           
           PolygonBox[{{1060, 336, 1083, 1077, 1078}, {1136, 1135, 1120, 382, 
            1174}, {1465, 1464, 1479, 547, 1463}, {1345, 448, 1347, 1366, 
            1367}, {1053, 367, 1134, 1050, 1051}, {1441, 546, 1477, 1449, 
            1450}, {1078, 1077, 1144, 368, 1076}, {878, 877, 880, 303, 
            962}}]}]}, {
         EdgeForm[], 
         RGBColor[0.9783385449863958, 0.8158463624659895, 0.5328494894578268], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJxFjzEOAVEQhmftcwmNSJRKcQ0JnUgkOhJs1FxAIrLNditKN2DRbMklOAaN
+CYziWLyTeb/3/zzGuNFb14RkRoVU+tIZE+tqAeDLrzDooqOMYVHSugP8IrW
wlPGpqlnCU/e67tvEMnxvIPt0p11+kmwnCHsBJs3YRLsjhH8BLvnBTOfq156
7g2eff8Tbv22Gey75wKnPt/AtmdpZuJ37qqmqUf/V3hW5vl59L9VmcKB79ec
H5ogJ5w=
            "]], 
           PolygonBox[CompressedData["
1:eJwt0DkSAVEQxvEe3uQkEjuBJSfnCARklhqFhAtwCAegipCEshQpB+AIToHQ
v+u94Dc183VPz7zO9qeNSUhEYjBIcIkjgigOvsgea2ywIJt5Iktcjc20tsUO
KbKkm6Gzfsb2ruBR7/A89+yMMfdllFBAEb2wSBcBBmjyTgMVVPEgu+OJF6aY
uExrIwxdprU87+RQQ923MwPXo70ZsjQ+fPtrbI/2ttD27Q50F2d6L3gbexY9
w83Yf6q4GTrrhKPbme6u6M6mO9Hd/AFS+yfl
            "]], 
           
           PolygonBox[{{1451, 1450, 1440, 512, 1421}, {1423, 515, 1463, 1459, 
            1460}, {1368, 1367, 1394, 515, 1392}, {1055, 335, 1076, 1065, 
            1066}, {976, 975, 1060, 335, 970}, {1271, 1270, 1247, 413, 
            1278}, {950, 949, 954, 300, 955}, {1389, 512, 1386, 1362, 1363}, {
            956, 300, 858, 864, 865}, {1281, 414, 1273, 1314, 1315}}]}]}, {
         EdgeForm[], 
         RGBColor[1., 0.95, 0.75], 
         GraphicsGroupBox[{
           PolygonBox[CompressedData["
1:eJwtUDsOAVEUvW/mvQXoZRCNTEJpAXoK02hJJBqfjYg9aKeSiIZQTKeaHXhW
QSXOzT3FzTn3d+6ns9hON4mIZLAU9nIiEeYQbHiRMXgTeEmNa0zzSWI1S8T7
8OfAXRB5g8+Aw2BaBfAcrP4A3AfrK4E9aE1Qk3vr0d4R8Af/Dv7xZsrbiG8x
YwC+Aj7Ja2BFrvmHM53IvXXnzNv8yFzOuS3eonvqjG6wfgc8cWfdvaZ+Rf3I
+pK3HIFX/kf/VPD2dbC/6H9uqelq/xdz/1/uLkM=
            "]], 
           
           PolygonBox[{{1423, 514, 481, 1392}, {872, 302, 301, 869}, {1442, 
            513, 514, 1457}, {1272, 447, 446, 1278}, {1054, 333, 334, 1064}, {
            1312, 446, 479, 1334}, {956, 301, 334, 961}, {1055, 334, 301, 
            969}, {1389, 479, 513, 1421}, {969, 301, 302, 970}, {1346, 481, 
            447, 1315}, {961, 334, 333, 955}}]}]}}, {{}, 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{879, 872, 869, 865, 956, 961, 955, 950, 1041, 1052, 1054, 
            1064, 1066, 1055, 969, 970, 976, 963, 879}], 
           
           LineBox[{1278, 1271, 1312, 1334, 1363, 1389, 1421, 1451, 1442, 
            1457, 1460, 1423, 1392, 1368, 1346, 1315, 1281, 1272, 1278}]}, 
          "1"], Annotation[#, 1, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{858, 851, 954, 949, 1040, 1051, 1053, 1063, 1065, 1076, 
            1078, 1060, 975, 962, 878, 871, 868, 864, 858}], 
           
           LineBox[{1129, 1116, 1169, 1208, 1247, 1270, 1311, 1333, 1362, 
            1386, 1418, 1448, 1440, 1450, 1441, 1456, 1459, 1463, 1465, 1425, 
            1394, 1367, 1345, 1314, 1273, 1248, 1209, 1174, 1136, 1119, 
            1129}]}, "0.9`"], Annotation[#, 0.9, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{857, 850, 953, 948, 1039, 1050, 1134, 1143, 1149, 1151, 
            1156, 1144, 1077, 1083, 1085, 1068, 980, 967, 882, 880, 877, 870, 
            867, 863, 857}], 
           
           LineBox[{1128, 1115, 1168, 1207, 1246, 1269, 1310, 1332, 1361, 
            1385, 1417, 1447, 1439, 1449, 1477, 1515, 1518, 1521, 1524, 1479, 
            1464, 1424, 1393, 1366, 1347, 1318, 1286, 1250, 1220, 1180, 1138, 
            1120, 1135, 1118, 1128}]}, "0.8`"], 
         Annotation[#, 0.8, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{788, 783, 860, 862, 856, 849, 952, 947, 936, 839, 1038, 
            1033, 1131, 1133, 1140, 1142, 1148, 1150, 1155, 1157, 1161, 1145, 
            1084, 1067, 979, 966, 881, 866, 798, 793, 788}], 
           
           LineBox[{997, 995, 1089, 1107, 1108, 1110, 1111, 1094, 1002, 1000, 
            997}], 
           
           LineBox[{1049, 1020, 1097, 1117, 1127, 1114, 1126, 1113, 1167, 
            1206, 1244, 1277, 1309, 1331, 1360, 1384, 1416, 1446, 1476, 1511, 
            1494, 1514, 1517, 1520, 1523, 1526, 1528, 1481, 1468, 1427, 1397, 
            1372, 1349, 1317, 1285, 1249, 1219, 1179, 1137, 1099, 1049}]}, 
          "0.7000000000000001`"], 
         Annotation[#, 0.7000000000000001, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{787, 782, 859, 861, 855, 848, 951, 946, 935, 838, 1037, 
            1032, 1130, 1132, 1139, 1141, 1218, 1228, 1230, 1234, 1236, 1223, 
            1160, 1162, 1166, 1153, 1092, 1073, 981, 965, 883, 874, 807, 803, 
            797, 792, 787}], 
           LineBox[{992, 991, 1086, 1102, 1103, 1106, 1163, 1193, 1197, 1200, 
            1203, 1205, 1243, 1268, 1307, 1341, 1359, 1383, 1415, 1445, 1475, 
            1510, 1493, 1513, 1516, 1519, 1522, 1525, 1527, 1480, 1467, 1426, 
            1396, 1371, 1348, 1316, 1284, 1287, 1291, 1253, 1226, 1182, 1147, 
            1101, 1059, 1024, 1048, 1019, 1044, 1016, 1031, 1013, 1010, 1007, 
            1005, 1003, 1001, 999, 996, 994, 992}]}, "0.6000000000000001`"], 
         Annotation[#, 0.6000000000000001, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{786, 781, 776, 772, 854, 847, 843, 767, 940, 837, 1036, 
            934, 1125, 1122, 1215, 1216, 1217, 1221, 1222, 1227, 1229, 1233, 
            1235, 1238, 1239, 1224, 1165, 1152, 1091, 1072, 982, 971, 884, 
            873, 806, 802, 796, 791, 786}], 
           
           LineBox[{900, 897, 978, 990, 988, 987, 1081, 1098, 1158, 1178, 
            1184, 1186, 1190, 1192, 1196, 1199, 1202, 1204, 1242, 1267, 1306, 
            1330, 1358, 1388, 1414, 1437, 1474, 1502, 1490, 1509, 1492, 1512, 
            1534, 1559, 1561, 1565, 1567, 1571, 1573, 1536, 1529, 1482, 1469, 
            1429, 1401, 1373, 1350, 1319, 1290, 1252, 1225, 1181, 1146, 1100, 
            1058, 1023, 1047, 1018, 1043, 1015, 1030, 1012, 1009, 1006, 1004, 
            983, 913, 909, 906, 903, 900}]}, "0.5`"], 
         Annotation[#, 0.5, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwV0M8rJGAcwOGXWSzGr4lBpEaITcltS1mHjVIk5eogTsTRgSQiag/KFGpr
09AexD9Aas/SmtuguSnXbZXaleGZw9Ont9637/u+iamF8fmCEMIWn4tCmOX/
hxD69VxfeCNYX+glEaY5joRQrl/1hFxhCMM6ygQRSohSQ5wmErTziW7mWOSa
W+5Is8QKq6yzyTbf2CHJHhn+8ESR+zxrTP/lZ2ouP1M76GGMNVLc8EiV93Ux
xCTLJLnkKv8nFBTbQydttNJCMw3EiVHNq/0PpMnyi+9sMMMIvTTy1/wMZ5zw
M/+3HPKDA/ZJsstvslQ6m6CeOHXUUkM1FUQp5SMRCvnCAAvMc8YpR6TIcE+Z
dwwySZ/1O5tgP44=
            "]]}, "0.4`"], Annotation[#, 0.4, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwV0ctLlFEYB+DTpzOgCV1kIFwVFJhCCLNIxZ0ICqVpWiSIVO4EWwTjODIO
iqEwAy0CIUTcuJJIFGwRhP4BQm0iCAVrNt1QWjsDPt/i4ceBw3vhvfHsxdDU
hRBCibuJELr4WBtChad8IuI5GzUh1MtuuUk1CqFP3meYiCQXuUyKJq5zk9u0
MkmGLDPkyFNggVcsU+Q1b1jhLaus8Z51tjmKe5mrGveSt7hDmnYGWYrn5yt/
aLRnC32MU2CFPQ44I0qqQwePecQIwzxkiEEeMEA/aVJc4RIJGqiod8gXPrPP
KotMcI82rvHffKec8I+//OYXZa7600wvozxhhCwliiwwzxx5ZskxTYaX7MS3
5gO7bPGOMj855gff+E6dPXoYo9P7HP6sRa4=
            "]]}, "0.30000000000000004`"], 
         Annotation[#, 0.30000000000000004`, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           LineBox[CompressedData["
1:eJwVz8kqBXAUB+D/NWWIDSsUNpTZzXiNSZk3opAyz7PyCHayUCJJyYpSnkBW
dh7ASh7AkCEbxWfx9TudTqdzCqbWB9YiIYQdIgkhJNAeH8IFP3Eh9MlnGWSE
RFJJ4UX/lTfe+eCTL77JM1NGORVUEqWaWuqJsc0e+xxwxDEnXHHKNWfccM4t
T//73RuljhhtDLHLJQ88k5sYQimDTLLHIXfc80t8krtoYYRRpplhi002WGeN
VVZYZolFFphnjlmmmGSCcYbpp49eeuimnS7a6KSVZppoJEY9ddRQTZQqKqmg
jFJKKKaIQgrIJ4dsssgkg3Qe/f5AmjqZDsZo0PsDh783XA==
            "]], 
           
           LineBox[{1326, 1325, 1354, 1378, 1408, 1433, 1434, 1411, 1379, 
            1355, 1326}]}, "0.2`"], Annotation[#, 0.2, "Tooltip"]& ], 
        TagBox[
         TooltipBox[{
           Directive[
            GrayLevel[0], 
            Opacity[0.5], 
            CapForm["Butt"]], 
           
           LineBox[{721, 722, 733, 734, 735, 736, 737, 738, 739, 740, 741, 
            746, 745, 744, 743, 742, 747, 748, 753, 758, 760, 761, 762, 763, 
            808, 817, 819, 821, 823, 825, 827, 828, 829, 830, 831, 832, 833, 
            840, 892, 943, 928, 957, 930, 959, 964, 968, 972, 974, 998, 1087, 
            1090, 1093, 1095, 1096, 1112, 1170, 1173, 1175, 1201, 1254, 1264, 
            1323, 1327, 1376, 1382, 1432, 1438, 1486, 1491, 1540, 1542, 1601, 
            1603, 1627, 1543}], 
           LineBox[{723, 725, 726, 727, 728, 729, 730, 731, 732, 724}]}, 
          "0.1`"], Annotation[#, 0.1, "Tooltip"]& ], {}, {}}}], {{}, {{{}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          AbsoluteThickness[1.6], 
          GrayLevel[0]], 
         PointBox[CompressedData["
1:eJxN3Hk8lc3/P3DJLiLlOM5xDlHKkkhSocmSchJKJcoWkSWhUihSaJE1ScgW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          "]]}, {}}}, {}}}, {
    PlotLabel -> FormBox["\"Fitch 15:30 adv=1\"", TraditionalForm], 
     DisplayFunction -> Identity, AspectRatio -> 1, DisplayFunction :> 
     Identity, Frame -> True, FrameLabel -> {{
        FormBox["\"Latitude\"", TraditionalForm], None}, {
        FormBox["\"Longitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotRange -> {{6.53, 7.4}, {53.85, 54.18}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {Automatic, Automatic}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}}, {{0.31339984019106276`, 
              0.4138465892045269, 0.6348384326033369}}, {{
              0.44802477161903465`, 0.46115886542521983`, 
              0.5556978978341778}}, {{0.5826497030470067, 0.5084711416459129, 
              0.4765573630650185}}, {{0.7172746344749784, 0.5557834178666058, 
              0.3974168282958594}}, {{0.8518995659029501, 0.6030956940872988, 
              0.3182762935267003}}, {{0.9138218046854508, 0.6545545117136272, 
              0.3328475945248976}}, {{0.9353273847857658, 0.7083184619644146, 
              0.399514892835874}}, {{0.9568329648860808, 0.762082412215202, 
              0.46618219114685044`}}, {{0.9783385449863958, 
              0.8158463624659895, 0.5328494894578268}}, {{1., 0.95, 0.75}}}, {{
                Rational[-15, 2], 
                Rational[-225, 2]}, {
                Rational[15, 2], 
                Rational[225, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[225, 2]}}, {{7.5, -112.5}, {-7.5, -112.5}, {-7.5, 
                112.5}, {7.5, 112.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -92.04545454545453}, {
                    Rational[
                    15, 2], -92.04545454545453}}, {{-7.5, \
-92.04545454545453}, {7.5, -92.04545454545453}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -71.59090909090908}, {
                    Rational[
                    15, 2], -71.59090909090908}}, {{-7.5, \
-71.59090909090908}, {7.5, -71.59090909090908}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -51.13636363636363}, {
                    Rational[
                    15, 2], -51.13636363636363}}, {{-7.5, \
-51.13636363636363}, {7.5, -51.13636363636363}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -30.681818181818173`}, {
                    Rational[
                    15, 2], -30.681818181818173`}}, {{-7.5, \
-30.681818181818173`}, {7.5, -30.681818181818173`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -10.227272727272705`}, {
                    Rational[
                    15, 2], -10.227272727272705`}}, {{-7.5, \
-10.227272727272705`}, {7.5, -10.227272727272705`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 10.227272727272748`}, {
                    Rational[15, 2], 10.227272727272748`}}, {{-7.5, 
                  10.227272727272748`}, {7.5, 10.227272727272748`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 30.681818181818187`}, {
                    Rational[15, 2], 30.681818181818187`}}, {{-7.5, 
                  30.681818181818187`}, {7.5, 30.681818181818187`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 51.136363636363654`}, {
                    Rational[15, 2], 51.136363636363654`}}, {{-7.5, 
                  51.136363636363654`}, {7.5, 51.136363636363654`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 71.59090909090912}, {
                    Rational[15, 2], 71.59090909090912}}, {{-7.5, 
                  71.59090909090912}, {7.5, 71.59090909090912}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 92.04545454545456}, {
                    Rational[15, 2], 92.04545454545456}}, {{-7.5, 
                  92.04545454545456}, {7.5, 92.04545454545456}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               LineBox[{{7.5, -112.5}, {7.5, 112.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{7.5, -71.5909090909091}, 
                    Offset[{4., 0}, {7.5, -71.5909090909091}]}, {{
                    7.5, -30.681818181818176`}, 
                    Offset[{4., 0}, {7.5, -30.681818181818176`}]}, {{7.5, 
                    10.227272727272746`}, 
                    Offset[{4., 0}, {7.5, 10.227272727272746`}]}, {{7.5, 
                    51.136363636363654`}, 
                    Offset[{4., 0}, {7.5, 51.136363636363654`}]}, {{7.5, 
                    92.04545454545456}, 
                    Offset[{4., 0}, {7.5, 92.04545454545456}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["0.2`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -71.5909090909091}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["0.4`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, -30.681818181818176`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["0.6000000000000001`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 10.227272727272746`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["0.8`", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 51.136363636363654`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["1", TraditionalForm], 
                    Offset[{7., 0.}, {7.5, 92.04545454545456}], {-1, 0.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{False, False}, {True, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {Automatic, 225}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 
                 RowBox[{
                  "0.004484724253416061`", ",", "1.1669737100601196`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.1`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.2`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.30000000000000004`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.4`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.5`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.6000000000000001`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.7000000000000001`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.8`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.9`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8135751407009573`*^9, 3.8135866241629*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchD", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Wind Speed Fitch, adv=0\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.790425082171939*^9}, {3.7904251545992684`*^9, 3.7904251558237486`*^9}, 
   3.790425220305675*^9, {3.7904253561856956`*^9, 3.7904253654911857`*^9}, 
   3.7904254259902124`*^9, {3.813577654614634*^9, 3.8135776617207584`*^9}, {
   3.824361031271201*^9, 3.824361031657126*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3Hdczt3/B/CMmxRZ2ZsI3Q1CRjgUUXZaMhpKqChRkbtl76ys7D1um+yV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     "], {{{
        EdgeForm[], 
        RGBColor[0.148, 0.33, 0.54], 
        GraphicsGroupBox[{
          
          PolygonBox[{{1225, 79, 1245}, {1204, 80, 1224}, {41, 3, 2}, {41, 79,
            80}, {1187, 42, 1203}, {42, 3, 41}, {41, 1, 79}, {1171, 42, 
           1187}, {41, 2, 1}, {80, 42, 41}}], 
          
          PolygonBox[{{1172, 3, 42, 1171}, {1224, 80, 79, 1225}, {1203, 42, 
           80, 1204}}]}]}, {
        EdgeForm[], 
        RGBColor[0.40322906044943446`, 0.445415963736223, 0.5820314788412271], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFVTlPlFEUffPxvTc2GhWIsVIjgzFKLz9AG9EoIo2Ve6cBCqG0kl1ANFKA
MdHCCgdwACHRxEg0GhUNzIigLCUWKm4N4Dm5Z2JxuPO+t9x7zl3YdeZy5aXI
OTcOFADbgnNJfPjlnRtJOPcZ+AKMys4Dx3GuHqgEOrDOAMPADJDA3U+wjxJm
Z4Eh7eW/z+rOR8BFtteuc9znuw3ACeB+7FwVbCY2H4yHcS0AY8BjoBf7z4E+
IIf1ut5+rHgX5I9+54AcOD4A2eVgvvY547RfnOiX5+LI/HHvijhz7SPTIg00
Aw+BTmkwIj8Fkb3B2JYV3zw4TMCuwF7DXj/QmLA9nvkKtGI9CLQBHcjBBdgq
2DrE+hRvXoXtxPoivlfDLgBL+P0Hdii2WAdh33rj/w62AjiD30dg0+JODTLS
g3EXJ507hHt7k7aek9ZZYBVYU/6iyPidFfdzwLi3XEzCXgfOM4ew7d72j8G2
ebtzFLYpYfGQ+37pXeZMkynpcjO2b/dgb3vTdxR2UXyX6Et57VAtMM+LWg8r
JwPgeQp8n8EOqC6oL3Vtlc7Ycl75r8ViI853BdO4TbXZkrD7reKd1rd51dmo
zg7pfJPqIq9Rs86XiS9rulFcm4R+3ZmUnu+lZYv8tqs/yJvxxqrdvcrdgaTV
ZYgsrqzem9b9AXEnZhTrdb2ZEaeczk3rbr94Deo86zs/D/qVr2ndadEb+9RH
1POh4kgrP5wtGyLb84q/WfVEDf5A+4PgskPgb3LbjTuHgZLI4sjPkiA/Zer9
tPxdUL/UKe855T6rWs6J00dpMa06zyqn1JCxtiLI01gfVg81KVZyWBQn9gln
BedCLdBDv8Ad9T17/rxywLqrVv92wW4NNiu+q9epNff4ToU4l+PMHthNwWYH
3/M4v1nfuc+eZG8WaP5yDnPN2NlXrDVqWKM3OXd5l+eW1FOcJRn1Vbe3OVqq
s8Pe+uqWtzlbr5nId6kL/awFy1lR0jR4ElkO+qQD9aCmC9L4nGqG2hQm7S7f
mFIumJMPio1936leZk+PaCZwNjCfqcjivaPY6LNc3Blbvfzz/0qNYmOMr/X/
5VFsdeCkyar0KtGsZ26D1muKL6XfJdK1R/mf0l2eKQ527yfizAar79Vgs35C
unDWMm+soZex6fqC/RysjqphC4Pt//D2rUK+bsQ2B7rxZ3uwuvzt7Y1e6fAq
Nt6fY+PHmqdWRcF4rXjzwXdPwm4JVjvfvP1foo6FwE5vdoe+8zd5vPE2D8a8
1VaNYltXn+U14l5K9VSq+mvQrGB+gv/vJ6Xz5JlRjpirv944kmtK+6XCunLS
pRl+F/YfpWU3Ag==
           "]], 
          PolygonBox[CompressedData["
1:eJwtkz1MU1EUx28f797nIn60DWPjIgNxNLbuMkAxgnVisti6QaKDccRZhfLR
xMEQgg6MxA+KJdGEhAAmQHRw0jY66uAX1sXE3z+nw+/1d987595z7z09U54a
m4ycc+chhic8zvFbgqd4HYKzd4v4gnduJuXcLKzj9/j4mgmO9zh3C++FfsZn
4QL+iZy75C5BCz8k5xW5TdjEl4PljkMNr3ubuwYNvA2f8S/wHl9hjoFurfM8
rpFzm7UeQQX/RYzHY0gzfkbMqLMc5Y7wvcxcE/AAv+zNb8BDfBiupyymiL/z
VqtqUC1zcFOxMK+9QAPfgH2tDdus9Q0SfCvY3lZhDc/xLk1sAYbwVnd/x6j3
L/4bQmR7yBB/xDiJ7F2W8YvY7uYq7OEdb2ejOTTXD+ghNoJTxH/35ik4wfiP
t7U0Z1+wO9HdqOZ2bDWpNp3BffwfMR1qz/EtnTh3kXExsjPPBztznf0bqAZb
Q2upB07imcRyByGLf+T3MWvdgV18Oliueki9pD1pb+qZt/hPb3epPZ3m+9dg
Z6maPuBNb2evnjqQ+27vpOxu1IPqRdWs2nUnuhvdQcDHoIJX1dN4yZvrjmt4
PrHaL0EB34mtdvXUc/yKt97RHDPeekK9of/IS/w/OQto6A==
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.6251827166200739, 0.5234188460965116, 0.4515539301658352], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVllQ11UU/v3hdy8ICZZATMsY7UihPQQGrr2IFGuhOQPaOJVRbDZYM2YP
JfbUJttfBUvQegh9aFq0DTRs1JqswKaph6DGJK3Uygwlo+/zfMzwcObc9Szf
We7NWFVfXhcTBEFiJAhiwbt9EMzBoB38FOapWD8N/ibWvgb1gIbDINiOtSHw
F1wQ5OFMIfjhwM6eAe3CuY06T2qKNRnrArvbBZqG+QkoTwZ/Enwb6ClQEuZ3
xtr69LggGAW/CHue1r1ukIe+38HjnJ3j+Rzpop0DoHOh2RLvTDdt2CC7VmjO
MW19XvMerb3jbe2AOM/sBr3lTUY/+BbIrYHvW8HXwu7OGPOjVJy+NII6Ymyf
2KRFzCZiezAwH66GrNnYX+TNF/pBbLbrzITPxHcHKAoZH4N6QXcBn1r4OQf8
PO5ch/EF8AbwJaB60NFYWxuLtTPEZlRrg1rbBB8WQt794JXCqQr0MubzsV4K
fgXsmwk7/8Q4H2spEYv95VjPxPofjIk3PePgm2VjH6gbe1s4B0/F3u04/7cz
vxNAU2IMC8okNsThF+UC/T8kDNaLE4cHcb8W5zucxWilYtcGnwFH0B6aTurf
B0qG3lsh8wzOv4G9O3BmD/hrmK/Bfhd4AeYZoMWgVzBfgPVy8KPOZHwD/hzk
jEDOs+BDzmz/B/x13MmGzJ3gn3rLl+/A54HKcWY5+AJQNsbp3nJwo+wuVo6U
gOYLnzTWIqgI4zzwXOUt6/MBb/m1GnyTt/zvUnyYf2WgpcLrmcBqZwK/CvGl
Iu4vA30JH1rg44fO9FFvrrc8YE5WSvcK2bwV+/uV31XKmSbt5yp/jkBWM2R+
4Mx/4pCvfCmRresVT9qxEHuzsHYV+E5vet6WDROyGcNi3d+lHCbWRao37qXG
WS2kgDfi/gGsbfBmK8/Q9izhRJs+C603vcv6ga2JWLsW57NwvxBreXHWq1iX
J8GvVBzP4ewY6DKMZ2DtX4ynYpzhzY5GxbVU/aBMdq9Vj3jYmy0V4BdxNwnj
G4iB4sT4zBZnjNrVn3d4i0mVsM5Vz8hR3SSrt3ZKV4f0darPPiK91L9OPYY5
UjKph1VojfFp8uZ3i7c8yFHPPaRext5GHZ9IR4/6DOPDeb/0xgdWI/SPdcZ6
uz60WC1W7b0HHB5FzrSAl6j/3OhM3nnFe9YkbI5hbwRnfgZfBrob40wXXGoC
lJ2mN2RAbwN7DPsX37Yy1fhNzvrkbsnn3tyI9euPsNcK/pWz3tuu/purGkkC
/97b/d+8+RgnPw8KH+I0RX7TZvalzepNg8KJ9s2VXfmqGdbO+85w7VC98V5U
vZV0jL5HTMdpvRPT1OvY89i3jkcMo27ZclhvJ3uuA/8ptBo8G9p+l2z/1htm
v4JX4NwiyLgFfFy5ypylX/Hy7aRizdyLqsey1+7FuceInTNbaC9rJor54xiv
dNa7ylSXT6jHstcmCDviNiJfpkoHcWG+ZypnKeNevU/3OHv7+d5mgO8BVWO9
1Zl+4sY6L9QfZoYz7E/pHRrUG8m4pukflKr4tzEvQPfp3bzZGd4lsmVIf6Qf
wI+E1tt+DM0H1jFx+Vw9h70nS33oNr159In+7w3t/BehxX5E/vYJw+OqE9ZL
s+qA2DA2/ylG48qfE4rNPuXdRByIAWOxRnnF/OI5xpJ9s1dvd5+zeirQ34L1
Wqd5p2LBe8SVb3qi7OydZCv10L4C/U0op11YsqaIN3sA/xAz1XvTVcdj2ktQ
LhDDNuVVpbMYsX7mRazX9Mv+6d7w/QtnUrxhfNaZ/gL5wDec786lf1jE8Jzo
I+TLnem+oD8WsWoQXtV6X/jO9MoPYpCtHs66eMmZXcXO7tUrj150ZnORs7U6
5Va6fOf7wzeZ/5wa2UTbqiWjTXKatc9aWuVMTqf+R7zP/vWQdGzTfqvu71dO
MX7X6C/KP2mN5PL+oLMYDYOvlg+vEnv9nfiHYiz57yxUbtQK2wbZGJXOOvkz
LJkD4KP6R/E/9T9rkZFi
           "]], 
          PolygonBox[CompressedData["
1:eJwtlFlslUUYhqfnnJnGgg3aUpZgaEGURVEviJVSFm8IIAjVUiQkEGJkESii
iQnGCwPxSlRKKwWFsHlj4gUItMY2aigxBllUjMAFkVrSBCEByyqKPG/e/+LJ
ec78s3zzzTdTtbSxbk0uhLAKCjCxOISZyFqowVtjCK8XhbAS2vHLKYTT+RDu
whX8/2QfocH0b6bPCvouh8P4J9Fj1daGfw1NRZ5Tc99j/B3G34YyxjdFj50G
8/H3+N5LgN/Dm/grtD2fzbcQj3CFpX+APmIYwxzT+a2EgXh5sV1raK3dMAEv
hSa8otixz4BB+DTanmatp2Aqfp35n8CfhIH8/wt+ZuwXcAZflO1P+9mKL87y
tQq24d/CNvw7OI2PgAq8FkbiVXA1uE3fFmb505wt+A3i+jG4z018OG0T+VYO
lfg1GENsY+Hh5Jwpd1NhM34LHuBbCVzAH8++K4cN+KewGl8DS/HPor0RXsW3
R+9FfZbgv0XvpRd68G9gS5HP9ER0DpVL1dBYvJO21iLnYA9+gfZ32cte6Mav
F+zao/aqM9RZ7oI/8DrGTGHsZPgInxvtyt+Hyk/02YyHQex/Nv8n8a0GXsD7
YFzOZ1jO95vRfXW+Q/g/K7qvcvoBfjF6b6V8v4e/HJ1LxfAxfpiY6oltPHyO
z4mORWtuij4TnY1qMulsYXTOZ/SQaof/LXxvho7oGqjN9vci/nf0WSrmMvo/
B3NynmMAfip6rHJ+Ej9ODA3BOT2Bt8EzwW3t+KNZvhT/PHxUlk/t6SX8sWx/
qon66Duhu6E7tw7fAF34JdiIny/4bNbDMfxQwf4O/IT/yRw9zNUJ3XgDY+Yx
9m1YkFyDqkX1Ud872X/duWGqX3gLnw3V+HLYkXMMK/BlyXOpTd+2JMc2gJib
8QO6k3nf8c14CzyLV8MevB6257yG1tIYjVUf9S1NXls5V+6HJteKamYKXgN1
Oe9Je5uUXFtqq03OgXKhGlGtnKXty7zfzHP4EeU07xgVaxe8n3efo8lvit4W
9dmP7yQ/a8nVG3oT8Gru1OqC3zi9dfsKrkU0tOCDk2PVnZis3EXfZc2xDN8d
PZfupO7myORafxD+1V1ljpLgGtqqu5mcu8WwDx8O/enbD/6JPmOddQf8iv+X
/Jbrjfw9+c3W262cv5Z855RPvUm36f9I8lyqAdVCRXLsyqly+1Xy2srRQbwq
OVbFcJf+v0SvrTulu3UfxsvQUQ==
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.8471363727907132, 0.6014217284568002, 0.32107638149044343`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVltQVlUUPv/hnP1P44WSEoOaQkCwrCmRBwG7jLdKkUqIWxcBG00mKwVG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           "]], 
          PolygonBox[CompressedData["
1:eJwtlElsTlEYhu/9//+cGhaGRbVqqpqLmLow1NjWtDCWUkNVxZQYqhoWJGJa
WAo1lAUd2FiYbVBaQqIslBQbtCLGSMSCUs+b7y7e5Lnnfuc755tOevHWhVti
QRAUoQS65oOgJB4ER9B1eLULgtwwCHJQBVyD0RjsOqMKbcCmCw6y0ED4IjY7
sa1Ed+Gn2BRitg89g/dj8xnbBlQGV2IzC9uZqBiekBQE27GbizLh794uFkp8
V2GzA9syVAq387+Nuzahr/B51kpDs9kGv0/Y2bWoBb6CTRG241EVfBabOdjO
RuvhJ9jsxbYA3YRrUVZgMdyC72BzKvJ/G14vH8SyCxXAy1EBvBRN93amzm5E
rXCds9zcRy/gn6w95l8VegefYi0vtJyfhI/io1vccnYATmetB/9+YN8BPu0s
d9pT5GxN/+TzF/6a2XOJ/YdRA/waXYab0Ru4Cfu60GJ6Dm9wlgvlJMvZHXXX
enTPWcyKXTk+Bz/w1ivy+RCOJVmthqA4XO/tbOX8KjzRW652o2XwF2+10x1f
weuiftAdxsJro/i0NgpeE+VHayPhb95iUY+oV3qj0fgeg37zPxPNiPq3EE7m
ThkJ65kATsd+LLbjUBv/+3rbq7U/fPeJvlXTHPivs15Xz7fDg1BPfKeiRfBA
Z5yCFsAH2fMI2+/oENyTM4dy/nyUBg9wZquazoMHo7TQfOY726O9yaohPBh1
jc7X7KV56zXF3Ev+UT68BE2FU3RGwmIeBt9IWG9rhjXLHZ315k/UyVnPyt8e
VOhtTf90p86qhbf4la/+cJ43Vr76wblRPpUz5W6o+jdmdw7hapQdtzemBt6p
mY1ZjsrhD5zxKbQ9cW85VqwfWfsHVzubfb0x5fAKZ7VVjY/B07zFrhiUm5PE
2CWwGb4QvSl6W5QT5WZSktWiHGUnWc+qd1WjVHh45F/zuBI+js/ucZvJc3Cr
s7tphlpUS9YWx6wGU7y9cXrr9EZshCu81VI5OKHYvb1F8infm7zlXjnZDJ+J
5lH9X6L+ZW1RzM6YDGdE+VdN1JurovdaMzICfpuwt0VvWiP80tksK8fKtWZQ
syif2fB/kiStVA==
           "]], 
          
          PolygonBox[{{1322, 1321, 1369, 323, 1368}, {1440, 1439, 1441, 370, 
           1390}, {1320, 283, 1367, 1321, 1322}, {1389, 330, 1386, 1439, 
           1440}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9270111867350403, 0.6875279668376009, 0.373734678878625], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV1lsVVUUvX3v3vMcwLRAghRa0ERBOigaWyAKFVBB4IPBROmAgsgUKSi1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           "]], 
          PolygonBox[CompressedData["
1:eJwtlVuIVVUch/c5Z6+1jTLUBCln8kJespnpwXFGJXxorBx1HtSEckYpxTAV
R6FmCvEKU6lB9lLpoBmpM2pBdlErBLW8FF4y6eaYBmVhgpdKTPTB78dvP3yc
76z7+q//WnvAzObJC4pJkrRCCneEJLnG7wm4TsEi/k8sJEkDjMYfhv74ALgb
r45JUs8AN/nfHZ8Pnfw/AS/jH9LmJereha/wG4z5PWPfgLv4vya47ym4jDfD
hILnHIk/xhhPM9Y06I+3wRX8W2jBd9CmteA5luBPUNZIXRM8gLczX2/mGg3b
8Wfz9feDSvxPynYkXtP/+H76rCglyXD4CJ8R3PZ+mI6XZ8SAdlOhCr8PhuEl
SPER9BlXdEwUm8rMbRfDGPwRaMUnQQU+FObidVCLl0FV6jkyvFfmujIYkrmP
+mrOvvhrzPEfc/Vlvevwf+E3PKM+UN/B/0f5Xwft+A9wHO+AC/i21LF5Br7E
a9jjCJgH82GdyqjrAevxasqGwxx4Ht6jrIG6wbATr2TM3qznHgj4FhjDXH3g
HfwQvI7Phl34Z9GuNlvxLvik5DaHddYqw09Dgf1cina1ORMdc8W+CPfisyjb
y9xvwUJ8LmzGl0Ijvio6N49DK94EK4vOWeXu29FrVY69ir8YnWsaY150H/VV
zBX7OlhWdI6OxTdF5855/r8RjfwPWKvciM5NzTkdr4HmonNmCr4++ix1Zjq7
Yua9KQaKxd9wreQzvInfis4NlfWkbcx89soh5dI31L9J3R74Ff+H8guc1QEo
cX7jKatl7hoYjE+EUfhIGIY/GR1LrXEmPiG6Tn2GRt+xprz/IHxadKwVE8Xm
Y+Z7IXGOHEo9R01+P+vxX1jDQe7WRvhZdxlaoAM6YT9soK4F9uFdcBi/BKfx
x6PfBt35gXgWXacc7Ib/GJ3rutPLlS/06VFwDMqDc1S5qj1XKB8p+4D6NjiK
F/P99oIUXx1cNwM+DV6z1q41HsC3B69Vb9Ji/ME8vhpDYw3J96+yAt49+C3U
m6S3tSL4rSmHRnwsZ7g29Ruht+JY8FupNZ4NflP1tm6Cr/Gz0Wd9Dq7qvgXX
KWYH8a2wJY+xYr0oOjd1Z5ZF71F7vUj7UvQ3QN+CTjiPn0mdO+1wFf8i9dvx
CpzCHwpeexk8pbNK3VY50KU9BNfpG3Mnvkd3tOQcPYLPCv62KB5V+F+px26D
k3gHNCV+kzrxbdFvm8bYHb1n7V1v4DndddqsTNznc/z9/Humb8wCxRpqC86J
cXh98NmqbBW+Ofjbpz4L8d9Tx0Jjfoc/R9ns/E2szt/EOfkbqrdUa9ba9Y3R
t+an4Ngq55X7twFNjOX2
           "]], 
          
          PolygonBox[{{1330, 289, 1328, 1381, 1382}, {1388, 1387, 1389, 331, 
           1335}, {1397, 333, 1394, 1445, 1446}, {1448, 1447, 1449, 374, 
           1401}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9624670423533533, 0.7761676058833833, 0.48364783129539524`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFV2lslUUU/dr3zTxWURNwAywoaoxKy6aRxQ1bQEVFo0Bka9VoKNQlRlGg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           "]], 
          PolygonBox[CompressedData["
1:eJwtlmlsVkUUhm/5ZuZrsaVggolCkYJFo4JtpUXFWBciIAhSjVHDLiYSl4L+
EEqhVTSVotUYjWETwcTQltKCGrUSFmUHE0OLRja3xFaiVlCMtMb4vJz58eZ7
7syZc++cM+fMlz+3ovzpPkmSvIkcejUkSVEqSfqid+Bj6Ev4L9QLf47eT9nY
L3BHnNdYJ1yC8nE4HmXDi9Df8FeoEnY+SXIzkqQUTYA/QE3wi+gQ3IDNOHzl
oU1wFWP3MTcN3Q53oT/gy/CXxXydt7XycQS+IdjcragQPozextcO9D08GJsS
bPuhu+HdjD3MXI0ET0DLWTsDTYR7Cco3xOU/lIt9KWMK2FtoLvwuuoS1xWge
fBT7ZmxrUTv8PGsqeddGtByeiU0ta5vRU/BkNAueja6DQzpJMln3A/48fJg1
R+P+TsKPYrMd259QNXyCsQPMbUB74R8Z28nan5UzuAlNhBegT+GuYLlUznqC
xVixHozWwJ+gJ1KWg4/hc6hNa9F3cAuqhh9CO+HfeecF3t2DuuGV3lhnIIf5
J3m+iufhyrm3PWqvt6DrtV80Fh6IMnWW4n7lU76XBTuL2u8r8Kn4Ptn8Cq8P
9i06s1vg1cH2ch77VfB6YnkPuRiOWuCFwXzJZ71yF+ysDkXF8EfxPMr/afg4
a3axdhXqhtdhMyxlMW2ER8Xvn4OmwAfRGymL4QH4AmvaWbsZ/QNvR/PgOnRM
3xbsrM1E18Dng+Uuh7lM8t/A7xxsx6JGuIJvKsiwmI6BJwVbqzN0LVwR96cz
sjTYmdTZ1BlvhTfiowBfk9FWeL+3s/keegme7y1Xw9Bo1Rs2rYnVQA9cxFiv
GPWDh3ir5RloBXwOm67EajyP5xdQObwY1cB3sad6bB5HI+ChaDT8CCpMm41s
VTMtcGOs/6nyAY/DZj62r6FSeI2z2AxEa53VlGqrAy2B9zrL3TPoW/iBYLWr
+CyA1zF2OXNlyhG8ydu7pqDn4KpgvnpRHbwi2NlST1Nvq4/nUz3gdfhKvqkQ
P1loCFzsLZaKmWKXy9gVzmpQtXgpz3c629MY+Eysz0E8D+C5P7rD2ZoC+N9g
c1pzNc/bvMV+OtoK9/HW2zp53yD1w7TFtgaVwW3BeoF64iH1hrhePfRD+OXY
TzUm35tj/tR/l6o2vLFysgQe7+3d6qm18EjeUcW7HkSj4OaYT/mQry2xH2ps
j7cYKVbqeem0nQmdDe25BC6P+VLPnQ1npa02dGby4WXxe+S/Gi7C5myG3RG6
K/Zjt5pY7EZn4Q3Ozv6zaB98b7DaVU+eBd8Y+7t6wjQ4Haw3dSum+Ot0Vsvq
8er1eWnbq3Ku3E8NdveoJ6g3HPRWW/qmM97uQN2FDWgx/DXrHkusJ6g3TA82
d/EOgm+O9T4CDYA7nPUO1aRqMzv2L33z/XB/b3eV1mhtm7O7SD3kM3ibs70r
JifgkcF6sb5XvbjVWa1MQnvUe+J9czEH8G/eeqV6cF+eK2O96DyUwfu83UXK
sXK9K/5f0J3Rrv0Gu2s1pv8Si7zVmnzc5i3GirXutOO6652dZfXgDJ4XeouF
9ncTfNJZbtVzUjzneOtN6rnZ3vagvegO+AI+HewuU48+Ba8MVtvq6WvVO1Rr
ifUE9YYmZ71BOdrh7D+E/kvojj0C/xnsrtYdqbvyfwwUL28=
           "]], 
          
          PolygonBox[{{1340, 294, 1338, 1395, 1396}, {1396, 1395, 1397, 334, 
           1341}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9979228979716662, 0.8648072449291656, 0.5935609837121654], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmWmUlcURhu/c+b6+oCC4JBFkkSCbKCBG0XMiDKhoYiAnoGLEBY2yD4Sg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           "]], 
          PolygonBox[CompressedData["
1:eJwtlUlsjVEUx+/r+777tIKah0oMJcZEaa1QqlRIzG0tmhiDxGxnrJilQ2Jh
UQmtBBu0JRIJSouYioihprAwxzzHrH7/nLf45/2+O5x77jnnntdt9tIpSxKc
cwtRgKZ453YwcBItgdegBrgKrYYHokx4OHoVOjfd29w2NAO+jlZFnVuJrsEV
aBpciGrhFezpHXGuFxoGt0H94P5oFJwdGmtsHbwJ5cJ5qD38Fycf4meU71Z8
t4g59wXbHRn/if2Loa3Vno3wKtQnYmdmwmtQ34iNDYeHIAc38tMSzorP6/yR
8G5spmL/D/fbBY9mLI25JOTgLfHz8lEH+BlrLrC+Df40xbelfD9hbyJjJXCl
YgrnoVPwFVQGL0f1cAI2mmErA+XAhd72pqFyuNQbK6ZV8GXW7Iuffym0nCg3
n/l+A5/wZnscOg4f9Ma60wF4lrdcy8e18oc9N9j7A72F73CPYq5agk7BdazZ
z96r6CWcjhYnWM3MhMd7q4XZaIIYGxuxdQDVh+Zjfjyfm+HuxGgwdpujbjHz
Wb7rTq/hxJjNveS8JvBtb2cr57/gt8wtitdvHVztrdbk4y34MdoZtRhfhb95
s1WHvsI3UT28Fz2HX6BPURv7Dr8JzPYCVAsfDe0uitFD+DDaELE7Hgktp8pt
LqrxJrHexCHFWm8gajXyFJ6E5hCrYSjN25vR29EarV0fr/+pqBoe4G2t3mAi
/Ci0XHXhO4nvpignwXIyGR7DfEHEfJSvnUOrLY1thd9xpx3OYngmsBpWflTj
HTUfmm3ZHIS9id5yK5/leyN7ath7Ev2D7wXGsinb51GZYoc+wK/QdvgYeg13
JacFgdWAamEkKobnoh5wFb9ZrE1B5WLGigJbo7V7tI+5saga3hBarNRD1Euy
WTOf8VKUEbMeoV4xAvWMWU2rtueh03BFYLaWobOB5Vy5l8934UrtdeaTfNMa
rV2OzsEHA7OlNYfgVM7IVFzRD84+7a3W1ANuwMXeeot6bBF8ODBbitl9eAD7
1wcWozT4ibfaVU2rtluH1gvVs9S7fisH7D2CfsFJMetFs9BAvZ/A5vSmG+A/
geVCPVW9VT1Nve0p2An+yNgLZz0phe/kmMVOMR0MPwgst1oTYf59YHtVE6qN
oaH1evVY9VrFQLHQG2vO/uTQeq98bgG3jfd/1Xy70GpAtaAYpsOF8f8L3XcE
/B+KRtxn
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtUr0yQ2EQ3ci93w1mFLhJ6AwvYLRJkQwv4BEiNQ+gNZ6D1NQkfkIlKTKG
hobC34y/REfh75zZU5w5u3t39zu7e2dqa8urQ2ZWBbLASWTWBL+Bj4LZOoK7
4DL8ApAHXoA95DyDF2OzOGM2Cf6Bf4P4N7hl3ifJeM0H+gyAPPICYin4XXnX
4PHYa9nDYA8jZwn8Ffzd2cSsCD+H+Ca4CkSwK+BG1nVuA4fSTO3sd2uudSXy
GUrAH3CHWF8zURs13qNmC/ZB8Hzm1oD5xHkEXAXqsCvgOdmMjSXei3oXFOd3
zkoN3BH1RPLr0sN3dqSZ2lvaGefk/lifqIb2vuahT/tUO+Qu2TtWLufhvlPw
mXbD2R7xRhd8GXxOxnrBcztAH7iKvHcb/Bl8P0/Bew2Uw1hXN63oFhOx+131
mtK9irp5U5p/tX/eoSNt1FjW/8W98/7MyYlbsqf1b/AfKSk/VZ+GehVi39lG
7Fo76t/WXK+Ra2zoW097OAePJl7zAPsieM4x+B/G8mvF
           "]], 
          PolygonBox[CompressedData["
1:eJwlkLlOgkEURi8yiwtaqEDUyvgG2GqiRl7ARwBqeQBa4nOotdYuhdHK2Cja
aGPjQuISYiWNMZybrzj5z8w/97tzZ7nR3tkdM7MlCNBPZj9FsyqLmWz2wfeE
/VN4xL+C/Awu8e8gP4crvB7NJgpm47CA70V5hir+x5lnU+Ynfku/a/rtwyt+
l+QH0MPnqAkF1cziA2peTD0WWZe44xp7Zfjl/DF0qD2E+6QMz/K9I/wp6K6e
8e91ZCSyImzj81HuPbfwlay3WIdp/CIp+wbe8W7UbJ5RwR+S/vkbDvE3GBQ1
o8+6QUaTrAbUsu7sd/czU1k9vFcLVvHJrLM+o8+6mfXPMzxrBLB6OFc=
           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1841, 1802, 1804, 1782, 1803, 1764, 1742, 1763, 1723, 1741,
            1743, 1744, 1708, 1724, 1725, 1709, 1745, 1726, 1765, 1746, 1783, 
           1766, 1806, 1784, 1827, 1805, 1843, 1828, 1858, 1857, 1856, 1842}], 
          
          LineBox[{1260, 1217, 1261, 1240, 1278, 1279, 1262, 1306, 1280, 1349,
            1305, 1304, 1414, 1303, 1412, 1302, 1301, 1348, 1300, 1346, 1345, 
           1299, 1298, 1277, 1276, 1258, 1257, 1239, 1215, 1259, 1216, 
           1260}]}, "15"], Annotation[#, 15, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNzqtOAmAAhuGfzWNS70C8AMHoPMBGBpl02exgMTBkHmeBWwAuQESzTqyC
EMEsJtQqRYtPePbG74seHu0XIyGEHM2ZEO5o0+CWFs90eOOJEUMm/PLH0mwI
y2yywhbbHLNDiV3KJKiQ5JQzUlxyzj0XXPHCNV16fPHNJxtzPuiixoiTZY91
MqTJc0CBEypUqVGnwQ0tHnjklT7vDBjzwQ9TFubtEmWNVeLESPAPIpousA==

           "]], 
          
          LineBox[{1184, 1199, 1183, 1218, 1219, 1220, 1200, 1241, 1221, 1263,
            1242, 1281, 1264, 1307, 1282, 1350, 1308, 1415, 1351, 1456, 1457, 
           1458, 1416, 1482, 1459, 1500, 1483, 1516, 1501, 1546, 1517, 1586, 
           1547, 1617, 1587, 1632, 1618, 1646, 1633, 1661, 1647, 1676, 1662, 
           1694, 1677, 1710, 1695, 1727, 1711, 1747, 1728, 1767, 1748, 1786, 
           1768, 1807, 1785, 1829, 1808, 1845, 1830, 1859, 1844}]}, "14"], 
        Annotation[#, 14, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzrsugwEYANBPov0NeAKXWERQQgQxmOsymVlIJJJGIyJVYucRqJm2Lith
dAkjNoJNZyxsjuHsp2M+P7NcFxEL7NdHlKhS4ZILnnikxgMf/PBLYyqiiX6a
GWCQRYZYYpgcI+QZZYUxVlnjgAJlilTZ5IgtjjnhimtOueWGF56pkaQjGkiT
IUUvPUzTzRRdTNLJBFnmmCVHkQ3W2aHANrvscUiJMhXOOOeOe15545N3vvj+
/yRutJDQRjut9JFhnD+CvDNu
           "]], 
          
          LineBox[{1186, 1201, 1185, 1222, 1202, 1243, 1223, 1265, 1244, 1283,
            1266, 1309, 1284, 1352, 1310, 1417, 1353, 1460, 1418, 1484, 1461, 
           1502, 1485, 1518, 1519, 1419, 1549, 1588, 1589, 1548, 1619, 1590, 
           1634, 1620, 1648, 1635, 1663, 1649, 1678, 1680, 1679, 1696, 1636, 
           1712, 1729, 1664, 1750, 1730, 1769, 1749, 1787, 1770, 1809, 1788, 
           1831, 1810, 1847, 1832, 1860, 1846}]}, "13"], 
        Annotation[#, 13, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzj0rBAAcwOH/uUP4BCgh8nakZDuL190kF4Wu5HKk3DfAR/AyKc7xASgb
BkYmL7F5GbFZPTc8/dZf2+LadCERETkOUhH7nFLmknseeOeDT/6oq46op4Fu
epmhjyxp5pinnwUGWGKQHEMsM0yeVQ4pcMQ6x2xQokiZM6645pEbnnnhiS+S
NREpqughQRdBJx1M0c4krUzQwjhjzDJKlhXybFJki2122GWPEiecc8Etd7zy
xjc/lZfaiN/KmyZpJEUTzaTJMMI/aZIwEg==
           "]]}, "12"], Annotation[#, 12, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzssqBGAAhuFfOV0Bk0Max3AHxvEKhDRGiiY1KGzcAXfAGOOYITdAscGG
JSsW7IgdO5TjeGbx9C6/L5qcH5wrCiHMslYcQoYDjjnhimseeOSNdz4oLwkh
Sj0N9NPIAE0M0cwwLcRpJcEoacbIME6WdSbYIMkmk2yRYpsZdtjllBxnnHPD
LU8880ee38LH0hB+Cp/1W+v0S2v1U2u0mj56qaKHCN1U0EkXCWLEGSHFFNMs
sMgSy6yQJscqe+xzyBEXXHLHPS+8kieU2aWSNiK000GMf2xyOpU=
           "]]}, "11"], Annotation[#, 11, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxbkuA2AAAOBfou3mapvGhNETaD2CK9LQB5BUTCQ8AbOrRWOV8AAkrTo2
G+IcmLQYLahrIb7hy9czMZOdbgohTFFqDmGDbXaocE6ZU854oEadBpFICDGi
dNPFAIsMMsQwS4ywzCgrZFlljAI5iqxRYZ19SlTZ5IBDLjjikiuOueaGOrc8
8cwj39T4oTMawpdT/nTSH0644bjf3eE3t/vVrW4jQwt99JMmxzh5JpljngVm
KbJFgT1O2OWeF+74JR4L4c8JJ+klTYZ/9C08pw==
           "]]}, "10"], Annotation[#, 10, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[{1172, 1171, 1187, 1203, 1204, 1224, 1225, 1245}]}, "9"], 
        Annotation[#, 9, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"Wind Speed Fitch, adv=0\"", TraditionalForm], 
     PlotRange -> {{53.85099411010742, 54.37454605102539}, {7.449102839198681,
       668.490728131371}}, PlotRangeClipping -> True, PlotRangePadding -> {
       Scaled[0.02], 
       Scaled[0.02]}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.40322906044943446`, 
              0.445415963736223, 0.5820314788412271}, {0.6251827166200739, 
              0.5234188460965116, 0.4515539301658352}, {0.8471363727907132, 
              0.6014217284568002, 0.32107638149044343`}, {0.9270111867350403, 
              0.6875279668376009, 0.373734678878625}, {0.9624670423533533, 
              0.7761676058833832, 0.4836478312953951}, {0.9979228979716662, 
              0.8648072449291656, 0.5935609837121654}, {1., 0.95, 
              0.75}}}, {{-100, 
                Rational[-15, 2]}, {100, 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{-100, 
                  Rational[-15, 2]}, {-100, 
                  Rational[15, 2]}, {100, 
                  Rational[15, 2]}, {100, 
                  Rational[-15, 2]}}, {{-100, -7.5}, {-100, 7.5}, {
                 100, 7.5}, {100, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-75., 
                    Rational[-15, 2]}, {-75., 
                    Rational[15, 2]}}, {{-75., -7.5}, {-75., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-50., 
                    Rational[-15, 2]}, {-50., 
                    Rational[15, 2]}}, {{-50., -7.5}, {-50., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-25., 
                    Rational[-15, 2]}, {-25., 
                    Rational[15, 2]}}, {{-25., -7.5}, {-25., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{0., 
                    Rational[-15, 2]}, {0., 
                    Rational[15, 2]}}, {{0., -7.5}, {0., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{25., 
                    Rational[-15, 2]}, {25., 
                    Rational[15, 2]}}, {{25., -7.5}, {25., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{50., 
                    Rational[-15, 2]}, {50., 
                    Rational[15, 2]}}, {{50., -7.5}, {50., 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{75., 
                    Rational[-15, 2]}, {75., 
                    Rational[15, 2]}}, {{75., -7.5}, {75., 7.5}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               
               LineBox[{{-99.99999999999999, -7.500000000000002}, {
                100.00000000000001`, -7.500000000000002}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-74.99999999999996, -7.500000000000002}, 
                    
                    Offset[{
                    0, -4.}, {-74.99999999999996, -7.500000000000002}]}, \
{{-24.99999999999999, -7.500000000000002}, 
                    
                    Offset[{
                    0, -4.}, {-24.99999999999999, -7.500000000000002}]}, {{
                    25.000000000000053`, -7.500000000000002}, 
                    
                    Offset[{0, -4.}, {
                    25.000000000000053`, -7.500000000000002}]}, {{
                    75.00000000000003, -7.500000000000002}, 
                    
                    Offset[{0, -4.}, {
                    75.00000000000003, -7.500000000000002}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["9", TraditionalForm], 
                    
                    Offset[{
                    0., -7.}, {-74.99999999999996, -7.500000000000002}], {0., 
                    1.}, Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["11", TraditionalForm], 
                    Offset[{
                    0., -7.}, {-24.99999999999999, -7.500000000000002}], {0., 
                    1.}, Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["13", TraditionalForm], 
                    
                    Offset[{0., -7.}, {
                    25.000000000000053`, -7.500000000000002}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["15", TraditionalForm], 
                    
                    Offset[{0., -7.}, {
                    75.00000000000003, -7.500000000000002}], {0., 1.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {200, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{"8.212663420918085`", ",", "15.263684913426497`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"9.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"10.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"11.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"12.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"13.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"14.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"15.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7904243465056243`*^9, 3.790424372721182*^9}, 
   3.7904248201547146`*^9, 3.7904248876753135`*^9, 3.7904250139535465`*^9, {
   3.7904250597461376`*^9, 3.7904250829201508`*^9}, {3.790425156689357*^9, 
   3.790425162468549*^9}, 3.790425223615613*^9, 3.79042536657777*^9, 
   3.790425441409998*^9, 3.7904901766384296`*^9, 3.790490268593161*^9, 
   3.812877344925907*^9, 3.813577663068453*^9, 3.824361062773608*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X1", "=", 
   RowBox[{
    RowBox[{"xlatlongd03", "[", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"PL2", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ";;", 
        RowBox[{
         RowBox[{"PL2", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", "NLA", "-", "1"}]}], ",", 
       RowBox[{"PL2", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Y1", "=", 
   RowBox[{"Take", "[", 
    RowBox[{"z", ",", "39"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Z1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"X1", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"Y1", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "X1", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"Length", "[", "Y1", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7904244359100437`*^9, 3.79042454348353*^9}, {
  3.790424586903467*^9, 3.7904246151183257`*^9}, {3.7904249193160133`*^9, 
  3.7904249288616333`*^9}, {3.790425545864244*^9, 3.7904255506182556`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"XXf", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Z1", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "All", ",", "2"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Transpose", "[", 
        RowBox[{"LredFitchABlue", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListContourPlot", "[", 
  RowBox[{"XXf", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Latitude\>\"", ",", "\"\<Height m\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Wind Speed Fitch\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"1", "/", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7904243342772856`*^9, 3.790424372013522*^9}, {
   3.7904248194527607`*^9, 3.790424819599991*^9}, {3.7904250276949253`*^9, 
   3.790425082171939*^9}, {3.7904251545992684`*^9, 3.7904251558237486`*^9}, 
   3.790425220305675*^9, {3.7904253561856956`*^9, 3.7904253654911857`*^9}, 
   3.7904254259902124`*^9, {3.7904255033112087`*^9, 3.7904255034805574`*^9}, {
   3.813579820993947*^9, 3.813579823284566*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJxt3HlcTtv3B/BUpMlQZAoRCZE5itqFUIZGhGiWkhSV8TYJESJjpiSZM5OQ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     "], {{{}, {
        EdgeForm[], 
        RGBColor[
        0.23895798538982202`, 0.3805322141054567, 0.6251828752063413], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNULsNwkAUewccBdS0SIyRKZDYAAqggjGORAIRwQJMcAlDUNMQGmo+QyBh
61xQWH7P7/yek9FsPVm1zGwItIHKmxXOrARfOmZjaA9wr2v2hf6EfgVq1G/w
HMhQD3wC6wW4At9deneEH2QncOPSHs4CEIGNeno4zzSbAn3d5f2tT9oS/PHJ
81KWQv5S+WtwVH5+R0SfQ99rR9Ddm/I02svZzqcZs+VC/MtXqY/yUzvoFm/m
esMcZ+XjPwt6T98Pxqg5AA==
           "]], 
          
          PolygonBox[{{1511, 471, 509, 1547}, {1512, 433, 471, 1513}, {1185, 
           1, 79, 1171}, {1510, 509, 469, 1579}, {1457, 394, 433, 1458}, {
           1383, 313, 353, 1421}, {1422, 353, 392, 1423}, {1423, 392, 393, 
           1455}, {1424, 393, 394, 1456}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.4474845255674782, 0.46096900259559936`, 0.5560154865673611], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVDtwjFEYvbv571V4zohBacSYJIY+j0KMygzJtkYThMiIobE9nexjxKtJ
DCoVslm2U2VE6VFklyi94lmhEec4x0hx5tz7/fd+j/N99982fKYwng8hjAFt
QCUXwkOgCvQBR4F+YF8Uj4HvR9mrXGchFHDvCXgWthbwCriMb8fBp8GTwAjW
4+Be8LB9c90O9ADLwALwGwhIqGnbJPx2wnQL3J1C2I5vb6PO8jvPlYBaTvEn
gBnvefYA0AF8w9398LFplfK69O9s1PqBecb2mn23bFvwfh5+fkCo70nxWGvd
elG3R8DqpDreRd1t2l/ZOda9b63Yv/b9ivdcjziXkvvQZ+1qUb6ugW8i1mHk
UwN3QachoBu4molvZ7KdB4pBeTP/BB0Gg+5QX+pCfXaCL+LMWpyp2mebz3R6
nXeMzPfveAY4C5nP0F7wOcYfdA5DRpdto4jxGA6LSfPBmq94diasQdMzQb3u
RWlQAdejdL8BPuae8t5slI7Xbe+3fnX3i1o/Rby7SHQRPAX3c8A0cAj7c4h1
JCnfKdufw1cD9xpRsZlDOSr2395H1VV03Zy9s56/r777IsrfkuNtjZr/veBf
EO4TbFuwvuCesrfzmXwugkejZmAAvCGpjqWoWduR13vYk6TVGvBBa0uNe/zW
NuYUn8x4u5Pu7kqqs+g+rU/S6qNnre7Z/OC39x780nWxvpOeGc7OZtfF+uib
+XX4HVIP2kpROZ2IslEr6l7ymyiveIe0Dbgv7M8618hap91H9vNzlCbUpuHc
mOOcNWe9X6Le6DPwm0zffoJPxf//uT/6tqlS
           "]], 
          PolygonBox[CompressedData["
1:eJwtkztMVUEURefinUsCIgXfloAFUeloABN5iRWJIbRECkAERY022lMS4Cm/
ypegFRV/pKNSKVEbIx87QUBjpzbK2tmv2Mm6M+fsOWfm3Ib+Rz0PS0IIrShF
nTGE6iSEdnQDfsfiU9a70RL8FRXgt+gQXstC6L0QwiIqwPPkTJGbRxtwLapK
7FkH9xHzmAO30S34IHPub7QD3yfmOrGDaBQejq6lDU3Ak6i/WJ/2aor+p9Qz
BGel9rpJbb/wex7tNYCW4bnUfV5Bs8CzzLVUkDMMzxAzpLPQLJzPvKcex+B8
tJdqWIIfoDuJc6bhCmK+wAHPS/Cf1Hd1hv7Cp8Tss7+HKtk/43sz8doP+I0E
b6GP8Kdo1tpP+Bh9hlfRLvyhGC8PeZ1Ee6sG1fIqda896HXqntTbJFqDO4np
otYnKAfPRe/pDdfhI/Qv8Znf4QU8mt1emIEPdIfBM6HZuIrH5RJ7ylszo9lR
zjS8gsd48X31NupBvWhtFa6Pviu9qWbnbvTb61tvfQ3P/4nPaIE3o2dNd6C7
u5i5OMUodp8zXwbPsGb5GzGN7DehMvbfp74b9bAD3858F5pRzWqO+I7EM3kv
Oke5upPyzDOqXjQDL6L/Gc2mckbgc2rDbxw=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.6644934581706143, 0.5372341226797686, 0.42844474024475077`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNVktQlmUY/b7//94XFqXVxC/VlOHCtAFsKmtXgiLaKDVeWknNtBGRSxdt
EttRrTMQE0iBagNtGlNHLk60ELI2yEy14dYmqDRSF6bTTOfMOc24eOa8l+d9
7s/zfWVvtO5qySVJchWUBx3CZifoHdBKHCwCVwDvAy35jPuNea3bou4+jNo/
Z17K6QEdtqyToG7LoszfLGuj3yx6v2R+8lJGnZFySqBjIU2S5ZAkf4JmsJ4C
VuF8B+7LgcM4m0/FV4n9WpxXAGexD1jPAS+kQvJRRpbTfVOU/iPAGtCTWD8F
LBQlyfYsSdYBX4vypT5KRsxJzlXbQ7vuxV2K89+xXol1Dus/sB633/R13Pgd
6Fuf8ywPWp+TbjxN8CwpB13G5ivE5xxwHe5eNl8x7mBWUgk6hbt28Jyx/idy
4p3E3TXQX4lyy5gwXm3Y94OOWgb1VSR6V+e3OSN1MaYjqWI8CD0f5KXveeec
eey2H8z9kv1b9J7rXtCuKHw96qzHbwaiZJ4F1jnOjHePa4Cy26Nq5mNgQ1Tc
3ovyYQD0fqJ4drvmel07lPFRlK3HgP8AVyOnj2fy6Tio0zRsPzsQ/BeBzcBL
7pEJ0KqgdQH4CegF1g5wOq8cXQFNQscUcAZ4y2fcTzgXzMmPUW9mgSucM9ZO
hev2HtqZSfct4MPQsYz1v1h3Y90EvT3AM6D99AF4FnQA6xNBfOR/JEjnhH34
BvsG8HQF2cVYTNu2vkT6yF+SqmYawVfAujpozzXlHsa+GeveoJgytn1RvvVb
323Lpo5fwHcR/D8H7ambsSFPGWy9A+xyLkZBn9KPVG9+9RnzcjHobjToPfNI
efNRMm5E8S343bxzesHyqGMMtNf18iqow/fkuxY0D6ZtJ2uENl6hnzg/H9Sn
7FHOjkHndsg0Zd/Su3roum2jjSfx/iDkHAqaIZxLnCND7qlB9zlr6QfPj/We
DUOWzbtZzy6+vx7k69+eQ3nbttf9TT/Xerazv9mr9e5dxn4baA3oZhQWFcnv
2kz3/Y75WFD8Rh3DvqCYjhjHnK/oucV5Uub4UV6ba4z1sRyVuwhds8DTOJsD
fpkpJ18DW9yTrIk99oU+labqO/bnpqBarQI+9P+Za5S1uiqVr/R5X14xYqwK
UfbtTiR7q+fBasfijmPzbpAdn7HfU/Ud80c/jiSy+/NM/g5kmqUVnsmVtndD
ohiXOaZvQlY1ZGwP0tvs8/OusXNBNdlsfYxBi/esU97RllrbTBljzhH7Y4P1
Mo5N5u2w3ce8pz2tmb5tlY4B3xT7e8fvXrF9oLzTzv1wkH97fFfuGPLsRCbe
LzLNROboYFD+Rlw3a1xv1MF3bZZV4/w9Bnw2qiceiPKxxW9qHasW18sl19MB
1wBroc+zhzVWlWrWMdYv4W4z8O2gvPVZ95ao7+krUXycn5udb8b8FLDRcWP8
xv194Xem4BlZ4vpsc41uCarRR62TMinjqO0aMO9u11Cz88M8t9pX+ljvbyzn
Qp17lz38TFTf3x9V0+3u532uc34jd/hfivzV/keq8v9Dnf8hjmf6x+gCPu1/
nhr/R3Xapp13/YvV+XvKt61B8d0GfND5Yt4K/j6WBn3j+Q1ujOLd73xs8rrK
+WbetwIXMsXmdqbvBGfJzaAeZi0xppOZYjaRaUawxr8H/hQ0f264txoc98uZ
5t98pthPOv6lnhXU/ZbzxBqZc23NZPqm0s5O4H9Vul5+
           "]], 
          PolygonBox[CompressedData["
1:eJwtlElsTlEUx+/7vnffZyFVQ0sNERaoNGqI2KGD0kQMlViphY3ONVVU7Axr
U7Wl6YQNFhKtKCViQVs2VcSmk40gHVQX1Vr4/XO6+OX7fffed969551zVx2r
LKiIOeeOQginvHM5gXMlcBrfH/HLgr2QjR+A/XgVHMQ/saaDtdfhGf6PIGPE
GYel/P8DL5nrhM94NqTiKVCsdxEjPWYxc/E0xkZ5dgQW4yWMNTD3BkrxjbA+
Zs/oWY1p7geU4Tk8sziwd5TgxYy9Zq4e9uHljO1gbrv2jFfAzsDGbuCT8Cqw
PX/xdkadVXsowBdAhHvYgs+PzEPYhC+EocDWLMKvwta4c0lwKbI1WqszbNb+
ve1Fe9be+8lfE2evhi45a47ELcZFPMtb7pQj5UoxFfs78YrwAejj/zQM4pch
Gd8GV/BueKBY0IjvIUYW8bLhBN7NOw8T+wL04FPw1tmeBvCh0OZaYRhfwTNL
eDYNduHvifkobnv4gP+GKbwXuvA7rCljbTlU4W2MPYzbMz14vre9qAZPeqtB
1WIp1OPvQsvNIXgcGvIMuIvvnv2eOlMl3kLMQuUeWvEOxmqYuwVNeKNqILAx
zT33NlcLzapfnpnh2dXEnsRfeJurgxad3VutKkd/WTMDXc56QL0wHVquNKa5
e5DpLMf3NRfa3gnjavDls/WrnObiZ7ydXTm7jY/BYGA9p95r8JZLneEsfhOO
B5YD1XZ7ZGdXjpXrlIRzebxnJYzzv47fOc72VBtaj6pXv8EE/hMCaisG81if
CWtjNpYkJ155aDEV+5e3tXFIVvzZ71cM7d7uCN0V1+Cjcg1Fge35iXLrba3G
2vDqyHpbNXwe7/SWe/XoV/ypt1h6h94VJexsqjnVXmpkZxnWnYOPe3P1qHr1
XGS9oztCd0Wet1pW/lRLGZHdfWtgA94cWS+pplRb/ZHVtnpKvVUY2V2jO1N3
55PIek09rF6eG1ks5VC5VI+qV1VjE5HlTLnr5/0jvL8PBgL75vr2vd7mNDaK
JxJWm/n6jvi6hHklpOPLvN3FqinV1n8Sz7/3
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.8815023907737504, 0.6134992427639379, 0.30087399392214037`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV0lwlkUQ/f78/8xvCB7YFNkpkKCAsomK3EAQAggRyqhVhsDNLUAiJGEJ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           "]], 
          PolygonBox[CompressedData["
1:eJwtlElsjlEUhr+//3/v3xILYmg6mkKjREMNC8u2qoZUVSQkxtgInVSptolN
ETsshCodqJVFiSGoproQLVaGEhG0SCxER7N63pwu3nzPvd85995zzzl3xs7i
gqKYIAh2owj67YKgMxQED9BreIkPgnEYxKFp8HWMtmC3GXXDddjkYJuNzsFl
KAtORnnwWWwmYJuJWrQBc8N8RtB0eJS5ocDmUhlXscdX9poSDoJqeBKaz3gB
yoRPoRX824VOw9/wifIvVj6MLzAuZu9cVA+XOzubznQWHkS9cB96Af9i/0fs
3YzewydZYzlrT0RH4Q1oI2tXoUI4H58ZY+sfhCtRHrwaFcK13ny/YH8YfoJa
Gfegp9585LsKrYebvcVyAl2Cs9F6fNPRIngdNtNDtucceKK3f7qTxXClt706
0V54yFlsH9FL+ErE7l45uwYfcra3zlwA31eO4DLUBv/FpiuwO0nQ+dB+/pWj
Gvg8WhmynB+ALzv7V4fa4XlRzswa5Sgd7uZMV3WX6Cbcy3wLaz9BffAHdCSw
Of3bhk09sVSgAm85V+6V48lwDnsksNcg9inwHVQSspxfhF+hDvgz+gFP9VYb
qt9+xtu95bIR7RA7y53ib1JundWm6nemszn90x1Uw0ne1v6ERhg3MN4atppR
7ezxlgvFoFg6dGch66k3cDIaYP1+lOUsBsWiuWx4GT7jY6zn4uFEZ7bKiXLz
LmK1WqM5OAebhTFWoyu99ahi1dxSbzFrrJofgFvx2YRvBroM53u763yUBWd4
Y9WgajHRW6yqp2H8fzp7G3THuuvv/J/LOmkojnz/i1hu1dPq7fqxelfNVMBF
2D+MsR4v1nmj5quaiYenojx4FoqFo1HjP9zvEPY3UG3Y7rwJfhSxu1BMik01
r7O2ox5nb5BymYRK4bUoNWQ9NdvZG6a3TDX4GB7x9hAqJsU2PLaecpLAeJ+3
2lEMiqVtrD5KUaN6y9leiajEWQ1p/xS9EfA7fJ5z9mdoAL7rzFc13AB/YG40
bGcYhm95exv0htz21kPqJd1BF/ze29siH/mqB9WLqrkWeI2zvRXzLPiYt7dV
b+hx+K23s6hHH8O5zs6uHiuG7zm7S70ReisGveVCMSiWNPJTErGcKXeXIlZb
cegM/B/h0NAe
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9317110740218668, 0.6992776850546669, 0.38830432946778703`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV2lslUUU/dr3zTyJrIHIKvvaIipLiybsiUpkKVsBLUUNUMEImlBapKyl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           "]], 
          PolygonBox[CompressedData["
1:eJwtlVlslUUYhuf85585LogaiCJLoEKrrQRXFE2ERBOVSClCaRSJC8EYTRRN
RKAULDXEBRNxiwkGIQqtRCFaF9QrRUAvpEW9skUUbV0TuYFSKAGeN+9/8eY8
Z2a+b2a+Zf6qRUvmPp6FEJpRjuoqISwFGtAouC6GcJLxiaUQ5sHvphAWl0O4
Gb0GH2NsOA7+Zn4QfpGxMczdgl6Hp6HrmF+AZsLjktdr7Ea4jM2P+D+OquHV
jB3J7OMFODDWzU8XGg/PR5PYqxpNhqtY8x/8LzrJ/wnJ/A86wf+R6AL9x346
fCq3rw7UBzdF+6pBU+DHsP+O/d9BD8IbWHMha6eh9+C3UT1cg7bDnazp4Kyt
aC98Ezo/8x1114fweR++b0Dr4A5spmI7HLXDHYwtY245elaMTT+2b6KH4Z1o
Xdkx36J4577LLjSC9a2oAds5aCE8Cw0ydwzdCd+b7Gsmqofro2OtNRPhT/C3
MPhMnblzrFwrxlfAz6DZJe+xAL4EH9fgaxgaDc+IvptivBh+mbFry75DG7ya
sfqSfdwD3x0da41p7lvWdJUdw154B2d4KjjGu+HTrNnL2j3oIDyWNecV8VXt
zUGXMjfE+gb4MPNjsTuKv5z6/YP/PfDP6Ci8j7m24Dvr7luK++k8q+CIza25
fYyAz0VT4EY0Gh7ARym3T/n+FL4fX2tRN9ybOzdvoQH4HGxq+c3QIOsPJZ+l
E3XBW9lzaREfneU5xi5i7jD3a4FnM3ai6I9J8J7cvhWjHngk/h/NfebqimOk
WKknTsE70AfwWrRP/VvkYxZqgW9jjyb2ugpdnxxDxVJ71sB3JPduK2qCq6Jr
az8qRfeYek01P5753uj+241+gT9kbE3ZNbERPpCcG+X8f7i56D/VWyM8j7GW
zGe6PTlmip1ifjb328WaTazdjL6BVxTvgWp2Lvw12gg/jb6Ca7Ef0luA6uDl
RX2rZu6C30h+qx5BW7UWVXLnfBj79Ufb/oTOYq6GsVdyx/xKeEZyb2kP7XV5
ET+9mQl+UjWX+U1bBf+JfmWvhP1xzSXXgnr8c/iyIt/yEeG26N7WG6G3orro
X63J1XvYXJ25J9Wbv+d+29ag7+Exyb2qnhmQbfRbrZz1wFOTcy8fo+BFqD3z
mZ+AP87tSz2j3lkZXTvKmXI3VORfOVfuVROqDb3ZE+B+bN4PfuMz/l9c8bel
tuiN+cm1pT2192/RuVXPH9J7U3HvNaPJ8Mrk3tAbvSS5xlRryvkB+KXoWteb
uz26BlQL6rF2eFvut1w9+5m+Bbl7V2fUWb/E53pysRN1w/uT+SDqS86Zcqca
+Qt+IPlboZpthF9N/jaqh5/X2xZdO+rBPvij5G+FekK9IZ/yrZr4Ad4W/S1Q
javW25NrU2f6Aj4D6ZsAHw==
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.9663770376964892, 0.7859425942412229, 0.4957688168591164], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNV2lQllUUfvm+994X0bEEa6aShJKsbCIoFdemQrTRfpRBhKIC7YW0N02G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           "]], 
          PolygonBox[CompressedData["
1:eJwtlllsVlUUhe//955ToIi2JSYCUSpUSrFUQZBiAYcHUfBBlKEURCk4PViF
qDFGqYhoBQWNQgQxzoClOCQqVTEq04NCFXAATASlFBOBF9CIDH4r6z6s5Ltn
2ufss/c+t2xm44T78kmSvIhS1DUmyTIaNqK74CEhSXK5JKlA9XAhbX3p+5fv
S+B61Jj3HM19HJ2Ad6DH4HbmjM17zE18X4Vq4BnoRngMKst7jMZOQQNYO0GT
4Y5gW7JZwdj32GQt3Q2oDX4g2tZqdD88MZqfQJPgqegL+GU0Gx4b3VePboDH
R/fJCXXw5zp/QZIsR2vhAej6vO2Pgj/G5kJs344+hS+kbTh956GL4IHs9yf6
fkQRHhFtaxiqgS9GpXn7oBZez5gWzrcTHYSvpu0gfUXYnw9/j41m1voAHUrt
A+1FPquMMpIkR3Jesx+8XGdkbiNaDd+J/sjbBw/COXSM8UdROTw6+uw64ziN
zfyt/US+N2HzFczMQb/AlfSfTnxGnXVH8FjN6cL4OWg3a51E8+B9zPmasYdR
KWP7R9vWnrX3E/R3gl+hYvo/pK2Ovc9Dr8LfZevLR7/LNiph7b/4PgM/HB2r
8pl8dza4T+v/Bq+J9oXuVHfbu5CYwGYTqoK30badvuPoKNyTOecydziaBY8K
ZrXNhG9DlfAgNAO+LDhWlSNFwTGt2F6IJuv+0AbWfgG1w++jd7PzbYZXRvMU
tB7ezxrbWOsNtFl7YY9DU++5j/ZL21v0vY2egSehs2zhDLoUXhIdO0PQNMU6
uhzuhp5TfgSP1R0OCh6jsfL5KuUCug7ug16CH4qeqxhqghcrXwscY8uic1Tn
1x4Gw89Gz1UNaIY/iz77vagNbmDM9My/zcF3rPPLJ1vhLbS9mXOMpnyX8N0j
5xiphYcF+/4WdCW8LnVsjkPfpM5J5WYN+gQ+zRrdU/uwB/5bm7qvBK1J7WP5
+hG0SfGCJsA3oyfhDalrjXJQufg0bRNzvgPdxWu0jadvLtoM/4m9jgLbPAXP
zs67ALXKP8GsthZ4Veq990ct8MjoWqGaotryOm3liW20wl2Y83N231XBManY
lI/ugBdn6ytftss/WX1R27fBOanc1B0ugvdGx75y4IhiM/quFAPvKH6yeB+I
psE98eE97GMpqoY3RtfKL9FO1UvG7GZvu/SeqD4wbl3imtkOf5TFv+ztg/ek
zn3VmOPwliwfNWaP4oG2FYlryN/wrmhb8vFh+Bz2UC2/oO7wSdoO0LcfdcK/
ZufrTX9KfwffbQXOyR/ggui7VMwp9v6LXktraK2C4LPoDPngmqLaohw9AFcE
13qdOcB5bPRKbVO+1ZtZkflvKByic1c2t/L9FLo155gaCT8fXQuUsytkn/Wu
Sb1mMVyEJqY+s84+PzhWdUe6q+nBtvR9he47s683tQ5eybzzE7+heksPRftK
PpFvxmT1TvG5CO5M/fYo5gr5bsrW15pT4bXBuaOcUe5UZfVF9aArPIs1W/N+
E+bC1Vm9Us3opveAMyzBxt1oMHwBejT1GXvBx6Lv7lpUyncoNCsGy+GSQs+V
j/rBC4Jrg3w6Av4n9dujHBnNdxnrFef9hugt6Rv9dqvtlP4/omu39tyg9zl1
bisG98L/AyOmIjs=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.8733376043875569, 0.6062580082266693], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmWmwlcURhs/2zbmggGsBsolsLqBEWRLZLmqQxfxxAwVcLojgdUEUSCyV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           "]], 
          PolygonBox[CompressedData["
1:eJwtlElslVUYhk//e/5zQa0MYogRQVrAnaKAMseVCejKoCCCCkUFBQpOEWKI
RAZFYUWggIQFIUiLJSxIhLa0UCVQu2GotKibkjCDlCExUdDnzXsXz73Pf4bv
jN8ZOrf61cVZCGERRPiNn2r+F0MHfjwP4VZZCO3Qho+BHI/wNt4OJ/G/IaUQ
yuBRAk6CDC8UQ3iROO9DJX4+d9sh1I+gvi/f5xmrCc7Spphc95Ji4Gei56L5
ncYfJ8ZK/t+EJ/BfaNNeCOE2XMfvQTl1F/j+F++EHrwNruIV9JlH/WQow4fA
XLwKnsSzomM9xvc12j/L/H5n7HPwYO4y1WlN/Wg7MnddFzyAD6N+QOY9GJ48
hsYaCH3xPrTpDl6z1r4WXmc/esEavII+4zPHqMRD0X21Bq1laNFz1Rq0li7+
m2l2Afrl3nPt/U2dEd6HNqOj9+Rh/Jncc+2E3nj/os9mAzyND4Y50XvyH/3f
oc1oYo2BOXghOXYPHFN/KC9zG7V9K/fdKKgMn6AYmdc0EZ8BazOXTcfvwyPR
Y2rsKvrMou9XUIe/R303bXuz/i/xzTAFr4BN+EfwD/Ud8Al+lTgfsLYF0IjX
EmMXsVbACfwMbY4VPKbGXpd7rFr4Ff8uObZifot/ljz2SFiPn9JeEfsAXIqO
qdg6w6/xy8l3rxku4ftgV8F3tAufB/WZ96AKf4g+fxDrTyjH91L2Gm2nQR3e
AsvxZXA4GfnnUItPhkXE2ghv4Jej56aYiv0jZTtp+wUcxbfBioLn9HNyDMXS
nnTgTyXnnmK+jLcm545inMX35t4r5Xw33kjZUuqWwB78dPLaa+BU8puht0Nn
oLNQzip3dScH4Tf4/zD4zJrwCbQplvKhh+8fkmPrzHfjrySvtQHexZuSx9Ic
NJdW+tQE58Sd6JxSLMUcj69MPsvpsBVfXRovwVh8du67m8Eo/G50bumOT9Tb
l3z39SbqbdxG/STqB8L30W+Y3rJNcDt6DRpfOX8L36F3EJ8KddFvmt62hdCC
H1JuB8c8iI/LPTfN8S++G6Lv9nw4qbFz56Zy5hvdH8qWBu9BJ34kei7Vpbdd
fdRXd1h3eVUpvt70F/DnS++7yq5TfxH203ad3hh8ZvLeKyc/xX+KrtOcNfft
0WvTHI7iz+XeS72heku3JN9F3XHd9ZvRa9cdOIxfic4FzeGa9i73W6U5FHPn
uHJdOfQxviH5LHWn65NzRrmjnKnB/wcsxd0H
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1Uj1SQmEMjPLxaHSkEEoVDuEMg17CI3gAPQCHoNEZ7ZRStPUHkEEtfJQq
CEdQ0MdDe3V3shaZzcuXbDbJK+3u7+wtmlkFloH1gtkB8AW4kTPbAq4DR8AO
4vmsG/0VYAHxGQoTWBl52/guAbuR2QliPeCZfMYWlMPcc3zXED8GLoPrEpxL
wCe81+G3gUPVkoO92GcV2FQtOX4jj62Bcwo/RXwMvIc14F8Aj5Tf1Hs/47pp
sfQn8h9hRc31P19fb4ynqhuLy3Leh/ynsA/kXCE80c4OOYuMPvf7rTfutQu7
gZ8Gz+F7y1wH+Tj/V/DYPLiWhvT8aPYB8DU4/13wu1FrQbvkbqkpVi15uS/W
kmMUOe9D5Ddg/nvw/4B6BsHvVhT3s3h5q7xuytsOpYFaYvXhHDPNWAH3J/xr
+JtZ56JG6phrxirit8pJuCftcwp8U1/2/wP4/mt6
           "]], 
          PolygonBox[CompressedData["
1:eJwtkD1OgkEQhjcyu1SoBbGgES5hQpRLcAQPgAfgEDSYaCf0tIh+/Gph7AGv
ICJo5AD4TF6KJ/vO785M5fqm3jgKIZTAIORD+M2FcIbxlYD3EXcfCpEY9hP6
GSboKTkP5Hdghp7jaxO7hQW6GpU/gA32+tDP7RF6Zerdgk/0kh5ber3BBP0K
7znNtEZfRv3tPX/In+Mrmmq81mf22Wtwyi7ncGXK2RPLTH/5DEPTDt7PZ56i
K3nVek0ZPTPtMoSdaUfftQl36IuoXbzft89hsn2+MfokqjaDY/R9Um0XXpJ8
2eGef+T3kmK+80fSDfwWfuMF+h9lIkWJ
           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          
          LineBox[{1233, 1211, 1212, 1259, 1213, 1262, 1214, 1264, 1215, 1216,
            1235, 1236, 1237, 1238, 1217, 1267, 1239, 1296, 1295, 1294, 1266, 
           1265, 1339, 1263, 1337, 1261, 1334, 1260, 1258, 1293, 1292, 1257, 
           1256, 1234, 1233}], 
          
          LineBox[{1707, 1688, 1729, 1728, 1726, 1706, 1749, 1727, 1750, 1748,
            1790, 1822, 1791, 1823, 1824, 1825, 1826, 1793, 1808, 1770, 1792, 
           1752, 1771, 1731, 1751, 1709, 1730, 1689, 1708, 1707}]}, "15"], 
        Annotation[#, 15, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxTsuAwAYAOC/tOqR1AHKQBkbz6YNTmAUCYmUBDMJdosiaWcGdvQEXh3V
Y2q4Q9UdNOk3fPkmdg/XDhIRsc5tMuKGOk8880iLNr+kUxGD5BlihmFmGWGO
ebZYoMwi2+xQoMgZJSoscc4F71zySZ0vPkgNRDTd7zcn3UeCaaYIckyywjKr
bLDJHvscc8IRp1SpccU1d9zzwgOvNPjmhw5//NMlk44YZYxxsuTpAaI7J3E=

           "]], 
          
          LineBox[{1183, 1195, 1181, 1218, 1196, 1240, 1219, 1268, 1241, 1297,
            1269, 1340, 1298, 1376, 1377, 1378, 1341, 1417, 1379, 1451, 1418, 
           1483, 1452, 1506, 1484, 1542, 1507, 1574, 1543, 1597, 1575, 1611, 
           1598, 1625, 1612, 1637, 1626, 1653, 1638, 1664, 1654, 1677, 1665, 
           1690, 1678, 1710, 1691, 1732, 1711, 1753, 1733, 1773, 1754, 1794, 
           1772, 1809, 1795, 1827, 1810, 1838, 1828}]}, "14"], 
        Annotation[#, 14, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzTkyAwAYgNEfSRThADFjSZGxZdQ4AS2TWCZVDmA5gNgqamnSIzkAhpLU
wgWIGeEMdi/Fm6/8suXNpY2eiChRS0TUaXDJFRe0uKdDbzKijxwJxkkyQYpJ
plhmmgJ5isywwioV1thlnT1K7HPAOYfUaXDLHU3avPDMH0/88kM2FfGtY/qp
ozrCPMPMMcsiCxQpUGaLbXaocMQxJ1Q55YxrbmjxwCuPdHjjg/funy8G+iMG
STNEhjz/pDAxkA==
           "]], 
          
          LineBox[{1184, 1197, 1182, 1220, 1198, 1242, 1221, 1270, 1243, 1299,
            1271, 1342, 1300, 1380, 1343, 1419, 1381, 1453, 1420, 1485, 1454, 
           1508, 1486, 1544, 1509, 1576, 1578, 1577, 1599, 1487, 1613, 1627, 
           1545, 1639, 1655, 1600, 1666, 1679, 1628, 1693, 1712, 1713, 1692, 
           1734, 1714, 1755, 1735, 1774, 1756, 1796, 1775, 1811, 1797, 1829, 
           1812, 1839, 1830}]}, "13"], Annotation[#, 13, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwVzr0uA2AYhuGvCRVOoPWTUBoDM86AAUX1AJAY2470x8zMZNWqHQmbmqt2
yqB1CpRIcHW4ck9v3iexk0/nIiGEXU77QqhxwSXXNLmiwQNtOrzzyx/j/Y6Z
IEKCSZZZYYpVkqSYZo119thgnzQFMhQpcUaZCgdUOeeOGnXueeGVFj88880T
X3QZi4bwqaP6oSM6zAJx5ogxzyJLbJJhi22y5MhToswhRxxzQoUqN9zS5JE3
2r3fdHpb6DI4YKMOaYw4M8zyDyGCOOI=
           "]]}, "12"], Annotation[#, 12, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxrkuA3AAwOG/BLUqOiiSbmyuN9BSJvoCEosEUXfCzm5y0woPIEHi3JXV
MVFvQNvJkfQbvvx+iYlsZrYmhDDJdm0IW5xwyhkPFCjyyQ+//NFaF8K/xrWN
JO2k6GCQIbKkmWOYeUZYYJEdlthlj2X2WeGAQ6444pocN+S5455b3nilwgtl
ninxTaw+hBa+fJM200+UPhrpoZcU3QyQZJQxMowzxTQzrLLGOhtskiPPMRec
U+CSR55454MSRcpUiERCaCBGJ11UAQQqOmo=
           "]]}, "11"], Annotation[#, 11, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwNxT0zwgEcAOCfO/4WYfE2Nlm8fAXVrqtdg0lestr5AK4UE3d8AXeVfAMZ
yRq7SmxsnuG5J717XKxMRESBxmREnVvuuOeJLn0+eOeXP5anIhZZYoUMW5TJ
sk+OAw6pckSNChfUadKgxSVtrnigwyuPvDGmxxcvDBkxn0QMPOdPpzzLJjOs
s8EaGbLk2aHENmVO2OOMc065ock1z/Tp8kMyHfHtBa/yD/I+LjU=
           "]]}, "10"], Annotation[#, 10, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[{1172, 1185, 1171, 1199, 1222, 1244}], 
          
          LineBox[{1382, 1301, 1383, 1421, 1384, 1422, 1423, 1455, 1424, 1456,
            1425, 1457, 1458, 1488, 1512, 1513, 1511, 1547, 1546, 1510, 
           1579}]}, "9"], Annotation[#, 9, "Tooltip"]& ], {}, {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> NCache[
       Rational[1, 2], 0.5], DisplayFunction :> Identity, Frame -> True, 
     FrameLabel -> {{
        FormBox["\"Height m\"", TraditionalForm], None}, {
        FormBox["\"Latitude\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotLabel -> FormBox["\"Wind Speed Fitch\"", TraditionalForm], 
     PlotRange -> {{53.85099411010742, 54.37454605102539}, {
      3.7245514195993406`, 646.199220740953}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {
       Scaled[0.02], 
       Scaled[0.02]}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{
             
             RasterBox[{{{0.148, 0.33, 0.54}, {0.23895798538982202`, 
              0.3805322141054567, 0.6251828752063413}, {0.4474845255674782, 
              0.46096900259559936`, 0.5560154865673611}, {0.6644934581706143, 
              0.5372341226797686, 0.42844474024475077`}, {0.8815023907737504, 
              0.6134992427639379, 0.30087399392214037`}, {0.9317110740218668, 
              0.6992776850546669, 0.38830432946778703`}, {0.9663770376964892, 
              0.7859425942412229, 0.4957688168591164}, {1., 
              0.8733376043875569, 0.6062580082266693}, {1., 0.95, 0.75}}}, {{
                Rational[-225, 2], 
                Rational[-15, 2]}, {
                Rational[225, 2], 
                Rational[15, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[-225, 2], 
                  Rational[-15, 2]}, {
                  Rational[-225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[15, 2]}, {
                  Rational[225, 2], 
                  Rational[-15, 2]}}, {{-112.5, -7.5}, {-112.5, 7.5}, {112.5, 
                7.5}, {112.5, -7.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-87.5, 
                    Rational[-15, 2]}, {-87.5, 
                    Rational[15, 2]}}, {{-87.5, -7.5}, {-87.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-62.5, 
                    Rational[-15, 2]}, {-62.5, 
                    Rational[15, 2]}}, {{-62.5, -7.5}, {-62.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-37.50000000000006, 
                    Rational[-15, 2]}, {-37.50000000000006, 
                    Rational[
                    15, 2]}}, {{-37.50000000000006, -7.5}, \
{-37.50000000000006, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{-12.5, 
                    Rational[-15, 2]}, {-12.5, 
                    Rational[15, 2]}}, {{-12.5, -7.5}, {-12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{12.5, 
                    Rational[-15, 2]}, {12.5, 
                    Rational[15, 2]}}, {{12.5, -7.5}, {12.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{37.49999999999994, 
                    Rational[-15, 2]}, {37.49999999999994, 
                    Rational[15, 2]}}, {{37.49999999999994, -7.5}, {
                  37.49999999999994, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{62.5, 
                    Rational[-15, 2]}, {62.5, 
                    Rational[15, 2]}}, {{62.5, -7.5}, {62.5, 7.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{87.49999999999994, 
                    Rational[-15, 2]}, {87.49999999999994, 
                    Rational[15, 2]}}, {{87.49999999999994, -7.5}, {
                  87.49999999999994, 7.5}}]]}}}, {Antialiasing -> False, 
              StyleBox[
               
               LineBox[{{-112.50000000000001`, -7.5}, {
                112.49999999999999`, -7.5}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{-62.49999999999997, -7.5}, 
                    
                    Offset[{
                    0, -4.}, {-62.49999999999997, -7.5}]}, \
{{-12.50000000000002, -7.5}, 
                    Offset[{0, -4.}, {-12.50000000000002, -7.5}]}, {{
                    37.49999999999999, -7.5}, 
                    Offset[{0, -4.}, {37.49999999999999, -7.5}]}, {{
                    87.49999999999994, -7.5}, 
                    Offset[{0, -4.}, {87.49999999999994, -7.5}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox["9", TraditionalForm], 
                    Offset[{0., -7.}, {-62.49999999999997, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["11", TraditionalForm], 
                    Offset[{0., -7.}, {-12.50000000000002, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["13", TraditionalForm], 
                    Offset[{0., -7.}, {37.49999999999999, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox["15", TraditionalForm], 
                    Offset[{0., -7.}, {87.49999999999994, -7.5}], {0., 1.}, 
                    Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{True, False}, {False, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {225, Automatic}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 RowBox[{"7.979396577785343`", ",", "15.19108128231342`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"8.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"9.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"10.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"11.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"12.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"13.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"14.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"15.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "\[InvisibleSpace]"}], 
                    "GrayLevel[0]"], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}, {
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Below"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.7904255208710814`*^9, {3.790425553626294*^9, 3.7904255817612944`*^9}, 
   3.7904256262493687`*^9, 3.7904903383158927`*^9, 3.812877394761292*^9, 
   3.813579824204688*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1263, 621},
WindowMargins->{{Automatic, -3}, {Automatic, 29}},
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (September 9, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 277, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[860, 27, 244, 3, 70, "Section"],
Cell[1107, 32, 163, 3, 30, "Text"],
Cell[1273, 37, 1830, 51, 132, "Input"],
Cell[3106, 90, 110, 1, 30, "Text"],
Cell[3219, 93, 1887, 55, 72, "Input"],
Cell[5109, 150, 316, 6, 30, "Text"],
Cell[5428, 158, 4801, 105, 192, "Input"],
Cell[10232, 265, 293, 6, 30, "Text"],
Cell[10528, 273, 4820, 103, 232, "Input"],
Cell[15351, 378, 235, 5, 30, "Text"],
Cell[15589, 385, 5061, 106, 212, "Input"],
Cell[20653, 493, 287, 6, 30, "Text"],
Cell[20943, 501, 4753, 96, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25733, 602, 141, 2, 70, "Section"],
Cell[CellGroupData[{
Cell[25899, 608, 672, 11, 79, "Subsection"],
Cell[26574, 621, 987, 16, 31, "Input"],
Cell[CellGroupData[{
Cell[27586, 641, 194, 3, 31, "Input"],
Cell[27783, 646, 596, 10, 31, "Output"]
}, Open  ]],
Cell[28394, 659, 426, 10, 31, "Input"],
Cell[28823, 671, 301, 8, 31, "Input"],
Cell[29127, 681, 399, 10, 31, "Input"],
Cell[29529, 693, 94, 1, 31, "Input"],
Cell[29626, 696, 1034, 23, 31, "Input"],
Cell[CellGroupData[{
Cell[30685, 723, 724, 12, 31, "Input"],
Cell[CellGroupData[{
Cell[31434, 739, 386, 7, 23, "Print"],
Cell[31823, 748, 414, 7, 23, "Print"],
Cell[32240, 757, 508, 11, 23, "Print"]
}, Open  ]],
Cell[32763, 771, 384, 7, 31, "Output"]
}, Open  ]],
Cell[33162, 781, 94, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[33281, 786, 203, 4, 31, "Input"],
Cell[CellGroupData[{
Cell[33509, 794, 168, 4, 23, "Print"],
Cell[33680, 800, 202, 4, 23, "Print"],
Cell[33885, 806, 293, 8, 23, "Print"]
}, Open  ]],
Cell[34193, 817, 170, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34400, 826, 420, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[34845, 840, 362, 6, 23, "Print"],
Cell[35210, 848, 392, 6, 23, "Print"],
Cell[35605, 856, 482, 10, 23, "Print"]
}, Open  ]],
Cell[36102, 869, 363, 6, 31, "Output"]
}, Open  ]],
Cell[36480, 878, 191, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[36696, 887, 476, 10, 31, "Input"],
Cell[CellGroupData[{
Cell[37197, 901, 262, 5, 23, "Print"],
Cell[37462, 908, 290, 5, 23, "Print"],
Cell[37755, 915, 378, 9, 23, "Print"]
}, Open  ]],
Cell[38148, 927, 265, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38450, 937, 199, 4, 31, "Input"],
Cell[38652, 943, 14792, 300, 74, "Output"]
}, Open  ]],
Cell[53459, 1246, 746, 13, 31, "Input"],
Cell[54208, 1261, 797, 14, 31, "Input"],
Cell[55008, 1277, 314, 8, 31, "Input"],
Cell[55325, 1287, 87, 1, 52, "Input"],
Cell[55415, 1290, 299, 9, 31, "Input"],
Cell[55717, 1301, 905, 15, 31, "Input"],
Cell[56625, 1318, 391, 9, 31, "Input"],
Cell[57019, 1329, 351, 8, 31, "Input"],
Cell[57373, 1339, 87, 1, 52, "Input"],
Cell[57463, 1342, 903, 15, 31, "Input"],
Cell[58369, 1359, 394, 9, 31, "Input"],
Cell[58766, 1370, 298, 7, 31, "Input"],
Cell[59067, 1379, 89, 1, 52, "Input"],
Cell[59159, 1382, 338, 8, 31, "Input"],
Cell[59500, 1392, 395, 9, 31, "Input"],
Cell[59898, 1403, 87, 1, 52, "Input"],
Cell[59988, 1406, 905, 15, 31, "Input"],
Cell[60896, 1423, 391, 9, 31, "Input"],
Cell[61290, 1434, 351, 8, 31, "Input"],
Cell[61644, 1444, 87, 1, 52, "Input"],
Cell[61734, 1447, 903, 15, 31, "Input"],
Cell[62640, 1464, 394, 9, 31, "Input"],
Cell[63037, 1475, 298, 7, 31, "Input"],
Cell[63338, 1484, 89, 1, 52, "Input"],
Cell[63430, 1487, 343, 8, 31, "Input"],
Cell[63776, 1497, 343, 8, 31, "Input"],
Cell[64122, 1507, 342, 8, 31, "Input"],
Cell[64467, 1517, 385, 9, 31, "Input"],
Cell[64855, 1528, 438, 9, 31, "Input"],
Cell[65296, 1539, 299, 7, 31, "Input"],
Cell[65598, 1548, 292, 7, 31, "Input"],
Cell[65893, 1557, 1984, 42, 172, "Input"],
Cell[CellGroupData[{
Cell[67902, 1603, 346, 8, 31, "Input"],
Cell[68251, 1613, 116, 1, 31, "Output"]
}, Open  ]],
Cell[68382, 1617, 499, 12, 31, "Input"],
Cell[68884, 1631, 501, 12, 31, "Input"],
Cell[69388, 1645, 375, 10, 31, "Input"],
Cell[69766, 1657, 96, 1, 31, "Input"],
Cell[69865, 1660, 516, 11, 31, "Input"],
Cell[70384, 1673, 520, 11, 31, "Input"],
Cell[70907, 1686, 518, 11, 31, "Input"],
Cell[71428, 1699, 87, 1, 52, "Input"],
Cell[71518, 1702, 418, 10, 31, "Input"],
Cell[71939, 1714, 367, 9, 31, "Input"],
Cell[72309, 1725, 417, 10, 31, "Input"],
Cell[72729, 1737, 368, 9, 31, "Input"],
Cell[73100, 1748, 548, 16, 31, "Input"],
Cell[73651, 1766, 1050, 21, 52, "Input"],
Cell[74704, 1789, 1013, 21, 52, "Input"],
Cell[75720, 1812, 1009, 21, 52, "Input"],
Cell[76732, 1835, 961, 20, 52, "Input"],
Cell[77696, 1857, 1096, 21, 52, "Input"],
Cell[78795, 1880, 1068, 22, 52, "Input"],
Cell[79866, 1904, 1064, 22, 52, "Input"],
Cell[80933, 1928, 1014, 21, 52, "Input"],
Cell[81950, 1951, 1314, 40, 72, "Input"],
Cell[83267, 1993, 2032, 50, 152, "Input"],
Cell[85302, 2045, 605, 15, 52, "Input"],
Cell[85910, 2062, 2168, 52, 172, "Input"],
Cell[88081, 2116, 711, 17, 52, "Input"],
Cell[88795, 2135, 433, 10, 31, "Input"],
Cell[89231, 2147, 381, 9, 31, "Input"],
Cell[89615, 2158, 1325, 22, 31, "Input"],
Cell[90943, 2182, 423, 9, 31, "Input"],
Cell[91369, 2193, 567, 12, 31, "Input"],
Cell[91939, 2207, 96, 1, 31, "Input"],
Cell[92038, 2210, 87, 1, 52, "Input"],
Cell[92128, 2213, 337, 9, 31, "Input"],
Cell[92468, 2224, 335, 9, 31, "Input"],
Cell[92806, 2235, 1226, 21, 31, "Input"],
Cell[94035, 2258, 295, 7, 31, "Input"],
Cell[94333, 2267, 365, 9, 31, "Input"],
Cell[94701, 2278, 138, 3, 31, "Input"],
Cell[94842, 2283, 874, 23, 52, "Input"],
Cell[95719, 2308, 874, 23, 52, "Input"],
Cell[96596, 2333, 872, 23, 52, "Input"],
Cell[97471, 2358, 874, 23, 52, "Input"],
Cell[98348, 2383, 869, 23, 52, "Input"],
Cell[99220, 2408, 876, 23, 52, "Input"],
Cell[100099, 2433, 823, 22, 52, "Input"],
Cell[100925, 2457, 821, 22, 52, "Input"],
Cell[101749, 2481, 913, 23, 52, "Input"],
Cell[102665, 2506, 924, 23, 52, "Input"],
Cell[103592, 2531, 870, 23, 52, "Input"],
Cell[104465, 2556, 874, 23, 52, "Input"],
Cell[105342, 2581, 240, 5, 31, "Input"],
Cell[105585, 2588, 899, 23, 52, "Input"],
Cell[106487, 2613, 899, 23, 52, "Input"],
Cell[107389, 2638, 897, 23, 52, "Input"],
Cell[108289, 2663, 901, 23, 52, "Input"],
Cell[109193, 2688, 894, 23, 52, "Input"],
Cell[110090, 2713, 899, 23, 52, "Input"],
Cell[110992, 2738, 845, 22, 52, "Input"],
Cell[111840, 2762, 843, 22, 52, "Input"],
Cell[112686, 2786, 940, 24, 52, "Input"],
Cell[113629, 2812, 951, 24, 52, "Input"],
Cell[114583, 2838, 895, 23, 52, "Input"],
Cell[115481, 2863, 897, 23, 52, "Input"],
Cell[116381, 2888, 975, 23, 52, "Input"],
Cell[117359, 2913, 927, 22, 52, "Input"],
Cell[118289, 2937, 926, 22, 52, "Input"],
Cell[119218, 2961, 922, 22, 52, "Input"],
Cell[120143, 2985, 89, 1, 52, "Input"],
Cell[CellGroupData[{
Cell[120257, 2990, 833, 20, 31, "Input"],
Cell[121093, 3012, 218, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121348, 3019, 811, 20, 31, "Input"],
Cell[122162, 3041, 221, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122420, 3048, 830, 20, 31, "Input"],
Cell[123253, 3070, 220, 2, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123510, 3077, 833, 20, 31, "Input"],
Cell[124346, 3099, 221, 2, 31, "Output"]
}, Open  ]],
Cell[124582, 3104, 1022, 23, 52, "Input"],
Cell[125607, 3129, 976, 23, 52, "Input"],
Cell[126586, 3154, 971, 23, 52, "Input"],
Cell[127560, 3179, 971, 23, 52, "Input"],
Cell[128534, 3204, 485, 11, 31, "Input"],
Cell[129022, 3217, 429, 10, 31, "Input"],
Cell[129454, 3229, 480, 11, 31, "Input"],
Cell[129937, 3242, 477, 11, 31, "Input"],
Cell[130417, 3255, 485, 11, 31, "Input"],
Cell[130905, 3268, 481, 11, 31, "Input"],
Cell[131389, 3281, 487, 11, 31, "Input"],
Cell[131879, 3294, 1105, 30, 152, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133021, 3329, 218, 4, 49, "Subsection"],
Cell[133242, 3335, 300, 7, 31, "Input"],
Cell[133545, 3344, 335, 8, 31, "Input"],
Cell[133883, 3354, 1009, 25, 52, "Input"],
Cell[134895, 3381, 1345, 33, 52, "Input"],
Cell[136243, 3416, 1343, 33, 52, "Input"],
Cell[137589, 3451, 1396, 34, 52, "Input"],
Cell[138988, 3487, 498, 13, 31, "Input"],
Cell[139489, 3502, 552, 13, 31, "Input"],
Cell[140044, 3517, 1138, 28, 52, "Input"],
Cell[141185, 3547, 1119, 32, 52, "Input"],
Cell[142307, 3581, 1117, 32, 52, "Input"],
Cell[143427, 3615, 550, 13, 31, "Input"],
Cell[143980, 3630, 550, 13, 31, "Input"],
Cell[144533, 3645, 214, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[144772, 3653, 604, 11, 31, "Input"],
Cell[145379, 3666, 645, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146061, 3680, 475, 10, 31, "Input"],
Cell[146539, 3692, 1587, 23, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148163, 3720, 529, 11, 31, "Input"],
Cell[148695, 3733, 1097, 16, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149829, 3754, 271, 7, 31, "Input"],
Cell[150103, 3763, 1069, 16, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151209, 3784, 420, 9, 31, "Input"],
Cell[151632, 3795, 1488, 22, 152, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153157, 3822, 517, 10, 31, "Input"],
Cell[153677, 3834, 1277, 21, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154991, 3860, 199, 4, 31, "Input"],
Cell[155193, 3866, 13413, 284, 74, "Output"]
}, Open  ]],
Cell[168621, 4153, 1032, 18, 31, "Input"],
Cell[169656, 4173, 1092, 19, 31, "Input"],
Cell[170751, 4194, 460, 10, 31, "Input"],
Cell[171214, 4206, 1084, 19, 31, "Input"],
Cell[172301, 4227, 511, 11, 31, "Input"],
Cell[172815, 4240, 1090, 19, 31, "Input"],
Cell[173908, 4261, 1133, 20, 31, "Input"],
Cell[175044, 4283, 1194, 20, 31, "Input"],
Cell[176241, 4305, 562, 12, 31, "Input"],
Cell[176806, 4319, 1094, 19, 31, "Input"],
Cell[177903, 4340, 1154, 20, 31, "Input"],
Cell[179060, 4362, 519, 11, 31, "Input"],
Cell[179582, 4375, 1146, 20, 31, "Input"],
Cell[180731, 4397, 568, 12, 31, "Input"],
Cell[181302, 4411, 1150, 20, 31, "Input"],
Cell[182455, 4433, 1146, 20, 31, "Input"],
Cell[183604, 4455, 1202, 20, 31, "Input"],
Cell[184809, 4477, 567, 12, 31, "Input"],
Cell[185379, 4491, 87, 1, 52, "Input"],
Cell[185469, 4494, 511, 11, 31, "Input"],
Cell[185983, 4507, 310, 8, 31, "Input"],
Cell[186296, 4517, 564, 12, 31, "Input"],
Cell[186863, 4531, 310, 8, 31, "Input"],
Cell[187176, 4541, 611, 12, 31, "Input"],
Cell[187790, 4555, 310, 8, 31, "Input"],
Cell[188103, 4565, 570, 12, 31, "Input"],
Cell[188676, 4579, 316, 8, 31, "Input"],
Cell[188995, 4589, 618, 12, 31, "Input"],
Cell[189616, 4603, 320, 8, 31, "Input"],
Cell[189939, 4613, 619, 12, 31, "Input"],
Cell[190561, 4627, 316, 8, 31, "Input"],
Cell[190880, 4637, 250, 6, 31, "Input"],
Cell[191133, 4645, 661, 16, 31, "Input"],
Cell[191797, 4663, 712, 17, 31, "Input"],
Cell[192512, 4682, 714, 17, 31, "Input"],
Cell[193229, 4701, 572, 15, 31, "Input"],
Cell[193804, 4718, 605, 17, 31, "Input"],
Cell[194412, 4737, 795, 23, 31, "Input"],
Cell[CellGroupData[{
Cell[195232, 4764, 725, 21, 31, "Input"],
Cell[195960, 4787, 326, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196323, 4799, 718, 21, 31, "Input"],
Cell[197044, 4822, 330, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197411, 4834, 695, 21, 31, "Input"],
Cell[198109, 4857, 281, 6, 31, "Output"]
}, Open  ]],
Cell[198405, 4866, 1962, 62, 132, "Input"],
Cell[200370, 4930, 963, 30, 72, "Input"],
Cell[201336, 4962, 980, 30, 72, "Input"],
Cell[202319, 4994, 978, 30, 72, "Input"],
Cell[203300, 5026, 2411, 45, 72, "Input"],
Cell[205714, 5073, 2408, 45, 72, "Input"],
Cell[208125, 5120, 2462, 46, 72, "Input"],
Cell[210590, 5168, 2415, 45, 72, "Input"],
Cell[213008, 5215, 2521, 47, 72, "Input"],
Cell[215532, 5264, 2521, 47, 72, "Input"],
Cell[218056, 5313, 2475, 46, 72, "Input"],
Cell[220534, 5361, 2583, 48, 72, "Input"],
Cell[223120, 5411, 2583, 48, 72, "Input"],
Cell[225706, 5461, 2525, 47, 72, "Input"],
Cell[228234, 5510, 2631, 48, 72, "Input"],
Cell[230868, 5560, 2579, 48, 72, "Input"],
Cell[233450, 5610, 2465, 46, 72, "Input"],
Cell[235918, 5658, 2465, 46, 72, "Input"],
Cell[238386, 5706, 2519, 47, 72, "Input"],
Cell[240908, 5755, 881, 25, 72, "Input"],
Cell[241792, 5782, 881, 25, 72, "Input"],
Cell[242676, 5809, 883, 25, 72, "Input"],
Cell[243562, 5836, 939, 26, 52, "Input"],
Cell[244504, 5864, 892, 25, 52, "Input"],
Cell[245399, 5891, 880, 25, 52, "Input"],
Cell[246282, 5918, 882, 25, 52, "Input"],
Cell[247167, 5945, 941, 26, 52, "Input"],
Cell[248111, 5973, 945, 26, 52, "Input"],
Cell[249059, 6001, 937, 26, 52, "Input"],
Cell[249999, 6029, 939, 26, 52, "Input"],
Cell[250941, 6057, 993, 26, 52, "Input"],
Cell[251937, 6085, 997, 26, 52, "Input"],
Cell[252937, 6113, 987, 26, 52, "Input"],
Cell[253927, 6141, 987, 26, 52, "Input"],
Cell[254917, 6169, 1305, 36, 72, "Input"],
Cell[256225, 6207, 673, 16, 72, "Input"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[256947, 6229, 265, 5, 111, "Section"],
Cell[CellGroupData[{
Cell[257237, 6238, 3847, 85, 112, "Input"],
Cell[261087, 6325, 114249, 2110, 371, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[375373, 8440, 1510, 34, 72, "Input"],
Cell[376886, 8476, 72170, 1362, 282, "Output"]
}, Open  ]],
Cell[449071, 9841, 1362, 40, 72, "Input"],
Cell[CellGroupData[{
Cell[450458, 9885, 1509, 34, 72, "Input"],
Cell[451970, 9921, 73811, 1398, 282, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
